import React, { useState, useEffect } from "react";
import { storiesOf } from "@storybook/react-native";
import Kanban from "./";
import { v4 as uuidv4 } from "uuid";
import { action } from "@storybook/addon-actions";
import { boolean, object, withKnobs } from "@storybook/addon-knobs";
import { IKanbanCustomTitleComponent } from "./types";
import KanbanCard from "./KanbanCard";

const kanbanStories = storiesOf("Kanban", module);
kanbanStories.addDecorator(withKnobs);

const defaultData = [
  {
    id: uuidv4(),
    name: "List1",
    cards: [
      {
        id: uuidv4(),
        name: "List1Card1",
        description: "List1Card1Description",
      },
    ],
  },
];

kanbanStories.add("all", () => {
  const TitleComponent = (props: IKanbanCustomTitleComponent) => {
    const [title, setTitle] = useState(props.title);

    useEffect(() => {
      if (props.title != title) {
        props.onTitleUpdate(title);
      }
    }, [title]);

    useEffect(() => {
      if (props.title != title) {
        setTitle(props.title);
      }
    }, [props.title]);

    return (
      <>
        <input
          type="text"
          value={title}
          onChange={(e) => {
            setTitle(e.target.value);
          }}
        />
      </>
    );
  };

  const onChangeAction = action("onChange", { clearOnStoryChange: true });
  const onDragAction = action("onDrag", { clearOnStoryChange: true });
  const onDropAction = action("onDrop", { clearOnStoryChange: true });
  const onCardIsDraggingAction = action("onCardIsDragging", {
    clearOnStoryChange: true,
  });
  const onCardCreateAction = action("onCardCreate", {
    clearOnStoryChange: true,
  });
  const onCardChangeAction = action("onCardChange", {
    clearOnStoryChange: true,
  });
  const onCardDeleteAction = action("onCardDelete", {
    clearOnStoryChange: true,
  });
  const onListIsDraggingAction = action("onListIsDragging", {
    clearOnStoryChange: true,
  });
  const onListChangeAction = action("onListChange", {
    clearOnStoryChange: true,
  });
  const onListCreateAction = action("onListCreate", {
    clearOnStoryChange: true,
  });
  const onListDeleteAction = action("onListDelete", {
    clearOnStoryChange: true,
  });

  return (
    <Kanban
      title="All Props"
      style={{}}
      data={defaultData}
      canAddList={boolean("canAddList", false)}
      canAddCard={boolean("canAddCard", false)}
      readOnly={boolean("readOnly", false)}
      titleComponent={TitleComponent}
      cardComponent={KanbanCard}
      onChange={(payload) => {
        onChangeAction(payload);
      }}
      onDrag={(payload) => {
        onDragAction(payload);
      }}
      onDrop={(payload) => {
        onDropAction(payload);
      }}
      onCardIsDragging={(payload) => {
        onCardIsDraggingAction(payload);
      }}
      onCardCreate={(listId, newCard) => {
        onCardCreateAction({ listId, newCard });
      }}
      onCardChange={(listId, updatedCard) => {
        onCardChangeAction({ listId, updatedCard });
      }}
      onCardDelete={(listId, cardId) => {
        onCardDeleteAction({ listId, cardId });
      }}
      onListIsDragging={(payload) => {
        onListIsDraggingAction(payload);
      }}
      onListChange={(payload) => {
        onListChangeAction(payload);
      }}
      onListCreate={(newList) => {
        onListCreateAction(newList);
      }}
      onListDelete={(listId) => {
        onListDeleteAction(listId);
      }}
    >
      Children Not Supported
    </Kanban>
  );
});
