import React, { useEffect, useState } from "react";
import { Board, BoardRepository } from "react-native-draganddrop-board";
import {
  IKanbanListObject,
  IKanbanProps,
  IKanbanNativeListObject,
} from "./types";

const parseDataToLibraryDataStructure = (
  data: Array<IKanbanListObject>
): Array<IKanbanNativeListObject> => {
  return data.map((list) => {
    return {
      id: list.id,
      title: list.name,
      rows: list.cards.map((card) => {
        return {
          id: card.id,
          title: card.name,
          description: card.description,
        };
      }),
    };
  });
};

export default (props: IKanbanProps) => {
  const [data, setData] = useState(parseDataToLibraryDataStructure(props.data));

  useEffect(() => {
    setData(parseDataToLibraryDataStructure(props.data));
  }, [props.data]);

  return (
    <Board
      boardRepository={new BoardRepository(data)}
      open={() => {}}
      onDragEnd={() => {}}
    />
  );
};
