import React from "react";

export interface IKanbanCardObject {
  id?: string;
  name: string;
  description?: string;
}

export interface IKanbanWebCardObject {
  id?: string;
  title: string;
  description?: string;
}

export interface IKanbanListObject {
  id?: string;
  name: string;
  cards: Array<IKanbanCardObject>;
}

export interface IKanbanWebListObject {
  id?: string;
  title: string;
  cards: Array<IKanbanWebCardObject>;
}

export interface IKanbanWebListObjectDS {
  columns: Array<IKanbanWebListObject>;
}

export enum ChangeTypes {
  TITLE_CHANGE = "titleChange",
  DATA_CHANGE = "dataChange",
}

export interface IKanbanDragObject {
  sourceId?: string;
  type: string;
  from: number;
  parentFrom?: number;
}

export interface IKanbanDropObject extends IKanbanDragObject {
  to: number;
  parentTo?: number;
}

export interface IKanbanCustomTitleComponent {
  title: string;
  onTitleUpdate(title: string): void;
}

export interface IKanbanCustomListComponent
  extends IKanbanCustomTitleComponent {}

export interface IKanbanCardComponent {
  id?: string;
  listId: string;
  title: string;
  style?: any;
  data?: {
    description?: string;
  };
  onTitleUpdate(title: string): void;
}

export interface IKanbanProps {
  title: string;
  style?: any;

  data: Array<IKanbanListObject>;
  canAddList?: boolean;
  canAddCard?: boolean;
  readOnly?: boolean;
  // not speced but since listComponent isn't too much
  titleComponent?: React.FC<IKanbanCustomTitleComponent>;

  // not supported at the moment
  // listComponent?: React.FC<IKanbanCustomListComponent>;

  cardComponent?: React.FC<IKanbanCardComponent>;
  children?: any;

  onChange?(payload: Array<IKanbanListObject>): void;

  onDrag?(payload: IKanbanDragObject): void;
  onDrop?(payload: IKanbanDropObject): void;

  onCardIsDragging?(payload: IKanbanDragObject): void;
  onCardCreate?(listId: string, newCard: IKanbanCardObject): void;
  onCardChange?(listId: string, updatedCard: IKanbanCardObject): void;
  // not supported at the moment
  // whats the significance
  // onCardSelect?(listId: string, cardId: string): void;
  onCardDelete?(listId: string, cardId: string): void;
  // not supported at the moment
  // whats the significance
  // onCardOpen?(listId: string, cardId: string): void;

  onListIsDragging?(payload: IKanbanDragObject): void;
  onListChange?(updatedList: IKanbanListObject): void;
  onListCreate?(newList: IKanbanListObject): void;
  onListDelete?(listId: string): void;
}

// not being using

export interface IKanbanNativeListObject {
  id: string;
  title: string;
  rows: Array<{
    id: string;
    title: string;
    description: string;
  }>;
}

export interface IThemeObject {
  top: Number;
}
