import React, { useState } from "react";
// also exported from '@storybook/react' if you can deal with breaking changes in 6.1
import { Story, Meta } from "@storybook/react/types-6-0";
import { v4 as uuidv4 } from "uuid";
import { action } from "@storybook/addon-actions";
import Kanban from "./index";
import { IKanbanData, IKanbanProps } from "./types";
import { useArgs } from "@storybook/client-api";
import "./styles.css";

let defaultData: IKanbanData = {
  columns: [
    {
      id: uuidv4(),
      title: "Tops",
      cards: [
        {
          id: uuidv4(),
          title: "Product Name 1",
          description: "$100",
          image: "https://picsum.photos/200/300",
        },
        {
          id: uuidv4(),
          title: "Product Name 2",
          description: "$100",
          image: "https://picsum.photos/200/300",
        },
      ],
    },
    {
      id: uuidv4(),
      title: "Shirts",
      cards: [
        {
          id: uuidv4(),
          title: "Product Name 1",
          description: "$100",
          image: "https://picsum.photos/200/300",
        },
        {
          id: uuidv4(),
          title: "Product Name 2",
          description: "$100",
          image: "https://picsum.photos/200/300",
        },
      ],
    },
  ],
};

const onDragAction = action("onDrag", { clearOnStoryChange: true });
const onDropAction = action("onDrop", { clearOnStoryChange: true });
const onCardIsDraggingAction = action("onCardIsDragging", {
  clearOnStoryChange: true,
});
const onCardCreateAction = action("onCardCreate", {
  clearOnStoryChange: true,
});
const onCardChangeAction = action("onCardChange", {
  clearOnStoryChange: true,
});
const onCardDeleteAction = action("onCardDelete", {
  clearOnStoryChange: true,
});
const onColumnIsDraggingAction = action("onColumnIsDragging", {
  clearOnStoryChange: true,
});
const onColumnChangeAction = action("onColumnChange", {
  clearOnStoryChange: true,
});
const onColumnCreateAction = action("onColumnCreate", {
  clearOnStoryChange: true,
});
const onColumnDeleteAction = action("onColumnDelete", {
  clearOnStoryChange: true,
});

export default {
  title: "Example/Kanban",
  component: Kanban,
  argTypes: {
    data: { control: "object" },
  },
  args: {
    data: defaultData,
    title: "Products",
  },
} as Meta;

const Template: Story<IKanbanProps> = (args) => {
  const [_args, updateArgs] = useArgs();
  const onChangeAction = action("onChange", {
    clearOnStoryChange: false,
  });

  return (
    <Kanban
      {...args}
      onTitleUpdate={(updatedTitle) => {
        updateArgs({ title: updatedTitle });
      }}
      onChange={(payload) => {
        onChangeAction(payload);
        updateArgs({ data: payload });
      }}
    />
  );
};

export const KanbanComponent = Template.bind({});

KanbanComponent.args = {
  theme: {
    backgroundColor: "#fafafa",
  },
  canAddColumn: true,
  canAddCard: true,
  readOnly: false,
  onDrag: (payload) => {
    onDragAction(payload);
  },
  onDrop: (payload) => {
    onDropAction(payload);
  },
  onCardIsDragging: (payload) => {
    onCardIsDraggingAction(payload);
  },
  onCardCreate: (columnId, newCard) => {
    onCardCreateAction({ columnId, newCard });
  },
  onCardChange: (columnId, updatedCard) => {
    onCardChangeAction({ columnId, updatedCard });
  },
  onCardDelete: (columnId, cardId) => {
    onCardDeleteAction({ columnId, cardId });
  },
  onColumnIsDragging: (payload) => {
    onColumnIsDraggingAction(payload);
  },
  onColumnChange: (payload) => {
    onColumnChangeAction(payload);
  },
  onColumnCreate: (newColumn) => {
    onColumnCreateAction(newColumn);
  },
  onColumnDelete: (columnId) => {
    onColumnDeleteAction(columnId);
  },
};
