import React from "react";
import { IKanbanData, IKanbanProps, IThemeObject } from "./types";
import KanbanBoard from "./KanbanBoard";
import defaultTheme from "./theme";
import deepmerge from "deepmerge";
import styled, { ThemeProvider } from "styled-components";
import { v4 as uuidv4 } from "uuid";
import KanbanHeader from "./KanbanHeader";
import { addColumn } from "react-kanban";

const Wrapper = styled.div`
  background-color: ${(props: { theme: IThemeObject }) =>
    props.theme.backgroundColor};
  padding: 20px;
`;

const Board = styled.div`
  margin-top: 10px;
`;

export default (props: IKanbanProps) => {
  const onChange = (updatedData: IKanbanData) => {
    if (props.onChange) {
      props.onChange(updatedData);
    }
  };

  const readOnly = !!props.readOnly;
  const canAddColumn = readOnly ? false : !!props.canAddColumn;
  const canAddCard = readOnly ? false : !!props.canAddCard;
  const theme = props.theme
    ? deepmerge(defaultTheme, props.theme)
    : defaultTheme;

  return (
    <ThemeProvider theme={theme}>
      <Wrapper>
        <KanbanHeader
          title={props.title}
          theme={theme}
          readOnly={readOnly}
          canAddColumn={canAddColumn}
          onAddColumn={() => {
            const newColumn = {
              id: uuidv4(),
              title: "New Column",
              cards: [],
            };
            if (props.onColumnCreate) {
              props.onColumnCreate(newColumn);
            }
            onChange(addColumn(props.data, newColumn));
          }}
          onTitleUpdate={props.onTitleUpdate}
        />
        <Board>
          <KanbanBoard
            theme={theme}
            data={props.data}
            readOnly={readOnly}
            canAddCard={canAddCard}
            titleComponent={props.titleComponent}
            cardComponent={props.cardComponent}
            onChange={onChange}
            onDrag={props.onDrag}
            onDrop={props.onDrop}
            onCardIsDragging={props.onCardIsDragging}
            onCardCreate={props.onCardCreate}
            onCardChange={props.onCardChange}
            onCardDelete={props.onCardDelete}
            onColumnIsDragging={props.onColumnIsDragging}
            onColumnChange={props.onColumnChange}
            onColumnCreate={props.onColumnCreate}
            onColumnDelete={props.onColumnDelete}
          />
        </Board>
      </Wrapper>
    </ThemeProvider>
  );
};
