import React from "react";
import { IKanbanCardProps, IThemeObject } from "./types";
import styled from "styled-components";
import KanbanMenuIcon from "./KanbanMenuIcon";
import KanbanRename from "./KanbanRename";
import KanbanMenu from "./KanbanMenu";

const Card = styled.div`
  display: grid;
  border: 1px solid #ddd;
  width: 100%;
  min-height: 150px;
  border-radius: 5px;
  grid-template-columns: 40% 60%;
  margin-bottom: 10px;
  background-color: #fff;
`;
const Image = styled.div`
  background-image: ${(props: { src: string }) => {
    return `url(${props.src})`;
  }};
  background-size: cover;
  border-top-left-radius: 5px;
  border-bottom-left-radius: 5px;
`;

const Header = styled.div`
  display: flex;
  justify-content: space-between;
  alignitems: center;
`;
const Content = styled.div`
  display: flex;
  padding: 10px;
  flex-direction: column;
`;
const Title = styled.h3`
  margin: 0;
`;
const Description = styled.p``;

export default (props: IKanbanCardProps) => {
  return (
    <Card>
      <Image src={props.image} />
      <Content>
        <Header>
          <KanbanRename
            style={props.theme.board.card.header.title}
            onChange={props.onTitleUpdate}
            title={props.title}
            readOnly={props.readOnly}
          />
          <KanbanMenu
            menuId={`column-menu-${props.id}`}
            menuItems={[
              {
                title: "Remove Card",
                action: props.onCardRemove,
                isVisible: true,
              },
            ]}
            menuSize={"10"}
            isVisible={!props.readOnly}
          />
        </Header>
        <Description>{props.description}</Description>
      </Content>
    </Card>
  );
};
