import React, { useEffect, useRef, useState } from "react";
import { IKanbanColumnHeaderProps, IThemeObject } from "./types";
import styled from "styled-components";
import KanbanRename from "./KanbanRename";
import KanbanMenu from "./KanbanMenu";

const Header = styled.div`
  background-color: ${(props: { theme: IThemeObject }) =>
    props.theme.board.column.header.backgroundColor};
  display: flex;
  align-items: center;
  justify-content: space-between;
  padding: ${(props: { theme: IThemeObject }) =>
    props.theme.board.column.header.padding};
  margin-bottom: 10px;
`;

export default (props: IKanbanColumnHeaderProps) => {
  return (
    <Header>
      <KanbanRename
        style={props.theme.board.column.header.title}
        onChange={props.onTitleUpdate}
        title={props.title}
        readOnly={props.readOnly}
      />

      <KanbanMenu
        menuId={`column-menu-${props.id}`}
        menuItems={[
          {
            title: "Add Card",
            action: props.onAddCard,
            isVisible: props.canAddCard,
          },
          {
            title: "Remove Column",
            action: props.onRemoveColumn,
            isVisible: true,
          },
        ]}
        menuSize={props.theme.board.column.header.menuSize}
        isVisible={!props.readOnly}
      />
    </Header>
  );
};
