import React, { useEffect, useRef, useState } from "react";
import { IKanbanHeaderProps, IThemeObject } from "./types";
import styled from "styled-components";

import KanbanRename from "./KanbanRename";
import KanbanMenu from "./KanbanMenu";

const Header = styled.div`
  background-color: ${(props: { theme: IThemeObject }) =>
    props.theme.header.backgroundColor};
  display: flex;
  align-items: center;
  justify-content: space-between;
`;

export default (props: IKanbanHeaderProps) => {
  return (
    <Header>
      <KanbanRename
        style={props.theme.header.title}
        onChange={(updateTitle: string) => {
          if (props.onTitleUpdate) {
            props.onTitleUpdate(updateTitle);
          }
        }}
        title={props.title}
        readOnly={props.readOnly}
      />

      <KanbanMenu
        menuId={`header-menu`}
        menuItems={[
          { title: "Add Column", action: props.onAddColumn, isVisible: true },
        ]}
        menuSize={props.theme.header.menuSize}
        isVisible={props.canAddColumn}
      />
    </Header>
  );
};
