import React, { useEffect, useRef, useState } from "react";
import { IKanbanColumnHeaderProps, IThemeObject } from "./types";
import styled from "styled-components";
import KanbanMenuIcon from "./KanbanMenuIcon";
import { usePopper } from "react-popper-2";

const MenuButtonWrapper = styled.div``;
const MenuButton = styled.div`
  display: ${(props: any) => (props.isVisible ? "block" : "none")};
  cursor: pointer;
  &:hover {
    opacity: 0.5;
  }
`;

const MenuWrapper = styled.div``;
const Menu = styled.div`
  background-color: #fff;
  display: ${(props: any) => (props.isVisible ? "block" : "none")};
  min-width: 100px;
  border: 1px solid #ddd;
  box-shadow: 0px 10px 35px -10px #ddd;
  padding: 10px 10px;
  font-family: Helvetica;
  border-radius: 2px;
`;

const List = styled.ul`
  list-style: none;
  margin: 0;
  padding: 0;
`;

const ListItem = styled.li`
  border-bottom: 1px solid #ddd;
  display: ${(props: any) => (props.isVisible ? "block" : "none")};
  padding: 10px;
  cursor: pointer;
  &:last-child {
    border: none;
  }

  &:hover {
    background: #eee;
  }
`;

export default (props: {
  menuId: string;
  menuSize: string;
  isVisible: boolean;
  menuItems: Array<{
    title: string;
    isVisible?: boolean;
    action: () => void;
  }>;
}) => {
  const menuRef = useRef(undefined);
  const menuButtonRef = useRef(undefined);
  const [menu, setMenu] = useState(false);
  const menuId = props.menuId;

  const popper = usePopper(menuButtonRef.current, menuRef.current, {
    placement: "bottom-end",
  });

  const handleClickOutside = (event: any) => {
    const targetId = event.target.getAttribute("id");
    if (targetId) {
      if (!targetId.includes(menuId)) {
        setMenu(false);
      }
    } else {
      setMenu(false);
    }
  };

  useEffect(() => {
    document.addEventListener("mousedown", handleClickOutside);
    return () => {
      document.removeEventListener("mousedown", handleClickOutside);
    };
  }, [menuRef]);

  useEffect(() => {
    if (popper.update) {
      popper.update();
    }
  }, [props]);

  return (
    <>
      <MenuButtonWrapper ref={menuButtonRef}>
        <MenuButton
          onClick={() => {
            if (!menu) {
              setMenu(true);
            }
          }}
          isVisible={props.isVisible}
        >
          <KanbanMenuIcon width={props.menuSize} height={props.menuSize} />
        </MenuButton>
      </MenuButtonWrapper>
      <MenuWrapper
        id={menuId}
        ref={menuRef}
        style={popper.styles.popper}
        {...popper.attributes.popper}
      >
        <Menu isVisible={menu}>
          <List id={`${menuId}-list`}>
            {props.menuItems.map((menuItem, idx) => {
              return (
                <ListItem
                  key={idx}
                  id={`${menuId}-listItem-addCard`}
                  onClick={() => {
                    menuItem.action();
                    setMenu(false);
                  }}
                  isVisible={menuItem.isVisible}
                >
                  {menuItem.title}
                </ListItem>
              );
            })}
          </List>
        </Menu>
      </MenuWrapper>
    </>
  );
};
