import React, { useEffect, useState } from "react";
import { IThemeObject } from "./types";
import styled from "styled-components";

const Title = styled.h2`
  margin: 0;
  font-size: ${(props: { style: any }) => props.style.fontSize};
  font-weight: ${(props: { style: any }) => props.style.fontWeight};
  font-family: ${(props: { style: any }) => props.style.fontFamily};
`;

const Rename = styled.input`
  border: none;
  background: transparent;
  font-size: ${(props: { style: any }) => props.style.fontSize};
  font-weight: ${(props: { style: any }) => props.style.fontWeight};
  font-family: ${(props: { style: any }) => props.style.fontFamily};
`;

export default (props: {
  title: string;
  style: {
    fontSize: string;
    fontWeight: number;
    fontFamily: string;
  };
  onChange: (updatedTitle: string) => void;
  readOnly?: boolean;
}) => {
  const [isRenaming, setRenaming] = useState(false);
  const [title, setTitle] = useState(props.title);

  useEffect(() => {
    if (props.title != title) {
      setTitle(props.title);
    }
  }, [props.title]);

  return isRenaming ? (
    <Rename
      type="text"
      value={title}
      onChange={(e: any) => setTitle(e.target.value)}
      onBlur={() => {
        setRenaming(false);
        props.onChange(title);
      }}
      style={props.style}
    />
  ) : (
    <Title
      style={props.style}
      onClick={() => {
        if (!props.readOnly) {
          setRenaming(true);
        }
      }}
    >
      {title}
    </Title>
  );
};
