import React from "react";

export interface IKanbanCardObject {
  id: string;
  title: string;
  description?: string;
  image?: string;
}

export interface IKanbanColumnObject {
  id: string;
  title: string;
  cards: Array<IKanbanCardObject>;
}

export interface IKanbanData {
  columns: Array<IKanbanColumnObject>;
}

export enum ChangeTypes {
  TITLE_CHANGE = "titleChange",
  DATA_CHANGE = "dataChange",
}

export interface IKanbanDragObject {
  sourceId?: string;
  type: string;
  from: number;
  parentFrom?: number;
}

export interface IKanbanDropObject extends IKanbanDragObject {
  to: number;
  parentTo?: number;
}

export interface IKanbanCustomTitleComponent {
  title: string;
  onTitleUpdate(title: string): void;
}

export interface IKanbanCustomColumnComponent
  extends IKanbanCustomTitleComponent {}

export interface IKanbanCardComponent {
  id?: string;
  columnId: string;
  title: string;
  style?: any;
  data?: {
    description?: string;
  };
  onTitleUpdate(title: string): void;
}

export interface IKanbanBoardProps {
  theme?: any;
  data: IKanbanData;
  canAddColumn?: boolean;
  canAddCard?: boolean;
  readOnly?: boolean;
  onTitleUpdate?: (updatedTitle: string) => void;

  // not speced but since columnComponent isn't too much
  titleComponent?: React.FC<IKanbanCustomTitleComponent>;

  // not supported at the moment
  // columnComponent?: React.FC<IKanbanCustomColumnComponent>;

  cardComponent?: React.FC<IKanbanCardComponent>;
  children?: any;

  onChange(payload: IKanbanData): void;

  onDrag?(payload: IKanbanDragObject): void;
  onDrop?(payload: IKanbanDropObject): void;

  onCardIsDragging?(payload: IKanbanDragObject): void;
  onCardCreate?(columnId: string, newCard: IKanbanCardObject): void;
  onCardChange?(columnId: string, updatedCard: IKanbanCardObject): void;
  // not supported at the moment
  // whats the significance
  // onCardSelect?(columnId: string, cardId: string): void;
  onCardDelete?(columnId: string, cardId: string): void;
  // not supported at the moment
  // whats the significance
  // onCardOpen?(columnId: string, cardId: string): void;

  onColumnIsDragging?(payload: IKanbanDragObject): void;
  onColumnChange?(updatedColumn: IKanbanColumnObject): void;
  onColumnCreate?(newColumn: IKanbanColumnObject): void;
  onColumnDelete?(columnId: string): void;
}

export interface IKanbanProps extends IKanbanBoardProps {
  title: string;
  readOnly?: boolean;
}

export interface IThemeTitleObject {
  fontFamily: string;
  fontSize: string;
  fontWeight: number;
}

export interface IThemeHeaderObject {
  backgroundColor: string;
  menuSize: string;
  title: IThemeTitleObject;
}

export interface IThemeObject {
  backgroundColor: string;
  header: IThemeHeaderObject;
  board: {
    column: {
      header: IThemeHeaderObject;
    };
    card: {
      header: IThemeHeaderObject;
    };
  };
}

export interface IKanbanHeaderProps {
  theme: IThemeObject;
  title: string;
  readOnly?: boolean;
  onAddColumn: () => void;
  canAddColumn?: boolean;
  onTitleUpdate?: (updatedTitle: string) => void;
}

export interface IKanbanColumnHeaderProps extends IKanbanColumnObject {
  theme: IThemeObject;
  readOnly?: boolean;
  canAddCard?: boolean;
  onAddCard: () => void;
  onRemoveColumn: () => void;
  onTitleUpdate: (updatedTitle: string) => void;
}

export interface IKanbanCardProps extends IKanbanCardObject {
  theme: IThemeObject;
  readOnly?: boolean;
  onTitleUpdate: (updatedTitle: string) => void;
  onCardRemove: () => void;
}
