import * as _ from "lodash";
import * as fs from "fs-extra";

import { generateDbTypeBlock } from "../../generators/classBlocks";

export const generateDatabaseTypes = (data: any) => {
  const { database, templateFolder, dbFolder } = data;

  // grab template (templates/db/types.graphql.template)
  fs.readFile(
    `${templateFolder}/db/types.graphql.template`,
    "utf8",
    (err, data) => {
      if (err) return console.error(err);

      // loop through database array
      // generate a gql_block for each
      const templateString = `type <%= name %> {
<%= types %>
}
`;

      const gql_block = _.join(
        _.map(database, type =>
          _.template(templateString)({
            name: type.name.replace(/ /g, ""),
            types: generateDbTypeBlock(type["schema"])
          })
        ),
        "\n"
      );

      // parse into template
      const typesGraphQl = _.template(data)({
        gql_block
      });

      // save result in outputPath/db/types.graphql
      fs.outputFile(`${dbFolder}/types.graphql`, typesGraphQl);
    }
  );
};
