import _ from 'lodash'
import express from 'express'
import md5 from 'md5'
import path from 'path'
import fs from 'fs'
import { prisma } from "@sc/api/db/prisma/generated/prisma-client";
import generator from 'generate-password'

import { prismaClient } from '../client'
import { getUserIdFromToken, getUserInfoFromToken } from '../sessions'

const curPath = path.join(process.cwd(), "./")
const iframes = express.Router()

/**
 * @swagger
 * /{token}/login:
 *  get:
 *    tags:
 *      - "iFrames"
 *    summary: "Shows a login screen"
 *    description: ""
 *    consumes:
 *    - "application/json"
 *    produces:
 *    - "application/json"
 *    responses:
 *      "200":
 *        description: ""
 */
iframes.get('/:token/login', async (req, res) => {
  const { params } = req;
  const { token } = params;
  const { host } = await getUserInfoFromToken(token);
  res.redirect(`https://${host}/r/${token}/login`);
});

/**
 * @swagger
 * /{token}/dashboard/campaigns:
 *  get:
 *   tags:
 *     - "iFrames"
 *   summary: "Shows a list of all user campaigns"
 *   description: ""
 *   consumes:
 *   - "application/json"
 *   produces:
 *   - "application/json"
 *   responses:
 *     "200":
 *       description: ""
 */
iframes.get('/:token/dashboard/campaigns', async (req, res) => {
  const { params } = req;
  const { token } = params;
  const { host } = await getUserInfoFromToken(token);
  res.redirect(`https://${host}/r/${token}/dashboard/campaigns`);
});


/**
 * @swagger
 * /{token}/catalog:
 *  get:
 *    tags:
 *      - "iFrames"
 *    summary: "Shows a list of pre-built campaigns a user can use as their starting point"
 *    description: ""
 *    consumes:
 *    - "application/json"
 *    produces:
 *    - "application/json"
 *    responses:
 *      "200":
 *        description: ""
 */
iframes.get('/:token/catalog', async (req, res) => {
  const { params } = req;
  const { token } = params;
  const { host } = await getUserInfoFromToken(token);
  res.redirect(`https://${host}/r/${token}/catalog`);
});


/**
 * @swagger
 * /{token}/campaign/{campaignId}/edit:
 *  get:
 *   tags:
 *     - "iFrames"
 *   summary: "Shows the campaign builder"
 *   description: ""
 *   consumes:
 *   - "application/json"
 *   produces:
 *   - "application/json"
 *   responses:
 *     "200":
 *       description: ""
 */
iframes.get('/:token/campaign/:campaignId/edit', async (req, res) => {
  const { params } = req;
  const { token, campaignId } = params;
  const { host } = await getUserInfoFromToken(token);
  res.redirect(`https://${host}/r/${token}/campaign/${campaignId}/edit`);
});

/**
 * @swagger
 * /{token}/campaign/{campaignId}/{pageId}/builder:
 *  get:
 *   tags:
 *     - "iFrames"
 *   summary: "Opens a page for editing"
 *   description: ""
 *   consumes:
 *   - "application/json"
 *   produces:
 *   - "application/json"
 *   responses:
 *     "200":
 *       description: ""
 */
iframes.get('/:token/campaign/:campaignId/:pageId/builder', async (req, res) => {
  const { params } = req;
  const { token, pageId, campaignId } = params;
  const { host } = await getUserInfoFromToken(token);
  res.redirect(`https://${host}/r/${token}/campaign/${campaignId}/${pageId}/builder`);
});

/**
 * @swagger
 * /{token}/settings/domains:
 *  get:
 *   tags:
 *     - "iFrames"
 *   summary: "Shows a list of all user domains"
 *   description: ""
 *   consumes:
 *   - "application/json"
 *   produces:
 *   - "application/json"
 *   responses:
 *     "200":
 *       description: ""
 */
iframes.get('/:token/settings/domains', async (req, res) => {
  const { params } = req;
  const { token } = params;
  const { host } = await getUserInfoFromToken(token);
  res.redirect(`https://${host}/r/${token}/settings/domains`);
});

/**
 * @swagger
 * /{token}/settings/integrations:
 *  get:
 *   tags:
 *     - "iFrames"
 *   summary: "Shows a list of all user integration profiles"
 *   description: ""
 *   consumes:
 *   - "application/json"
 *   produces:
 *   - "application/json"
 *   responses:
 *     "200":
 *       description: ""
 */
iframes.get('/:token/settings/integrations', async (req, res) => {
  const { params } = req;
  const { token } = params;
  const { host } = await getUserInfoFromToken(token);
  res.redirect(`https://${host}/r/${token}/settings/integrations`);
});

export default iframes;
