import dotenv from "dotenv"

import express from 'express'
import cors from 'cors'
import bodyParser from "body-parser"
import http from "http"
import https from "https"
import fs from "fs";

import clear from 'clear'
import chalk from 'chalk'
import figlet from 'figlet'

import swaggerUi from 'swagger-ui-express'
import { swaggerDocs } from './swagger.js'

import sessions, { checkToken } from './sessions'
import campaigns from './campaigns'
import users from './users'
import domains from './domains'
import integrations from './integrations'
import pages from './pages'

import objects from './objects'
import catalogItems from './catalogItems'
import mediaItems from './mediaItems'
import iframes from './iframes'

dotenv.config();
const app = express();

app.use(cors());
app.use(bodyParser.json());

// CORS Middleware
app.use((req, res, next) => {
  // Enabling CORS
  res.header("Access-Control-Allow-Origin", "*");
  res.header("Access-Control-Allow-Methods", "GET,HEAD,OPTIONS,POST,PUT");
  res.header(
    "Access-Control-Allow-Headers",
    "Origin, X-Requested-With, contentType,Content-Type, Accept, Authorization"
  );
  next();
});

// Routes
app.use(checkToken)

app.get('/', (req, res) => res.redirect('/v1/docs'))

app.use('/v1/sessions', sessions)
app.use('/v1/campaigns', campaigns)
app.use('/v1/users', users)
app.use('/v1/domains', domains)
app.use('/v1/integrations', integrations)
app.use('/v1/pages', pages)

app.use('/v1/objects', objects)
app.use('/v1/catalogItems', catalogItems)
app.use('/v1/mediaItems', mediaItems)
app.use('/v1/iframes', iframes)

app.use('/v1/docs', swaggerUi.serve, swaggerUi.setup(swaggerDocs))

const startServer = () => {

  clear();

  console.log(
    chalk.blue(
      figlet.textSync("Sandcastle", {
        horizontalLayout: "full",
        font: "Slant"
      })
    )
  );

  console.log(
    `  
    
              🚀    The Sandcastle (Rest) API server is 
                    running on http://${process.env.SERVER_ENDPOINT}:8091
              

    `
  );

}

// Setting up servers
const options = {
  key: fs.readFileSync(`/etc/letsencrypt/live/api.tenminutefunnels.com/privkey.pem`),
  cert: fs.readFileSync(`/etc/letsencrypt/live/api.tenminutefunnels.com/fullchain.pem`)
}

const httpsServer = https.createServer(options, app);
httpsServer.listen(48091, startServer)

const httpServer = http.createServer(app);
httpServer.listen(8091, startServer)