import gql from 'graphql-tag';

// getPages;
export const getPage = gql`
  query getPages($pageId: ID!, $userId: ID!) {
    pages(where: { id: $pageId, user: { id: $userId } }) {
      id
      name
      content
      publishedAt
      pageSettings
      slug
      type
      homePageForDomain {
        id
      }
      errorPageForDomain {
        id
      }
      object {
        id
        campaign {
          domain { id }
        }
        connectTo {
          id
          deleted
          page {
            id
            slug
          }
        }
      }
    }
  }
`;

// publishPage
export const publishPage = gql`
  mutation publishPage(
    $pageId: ID!
    $slug: String!
    $subdomain: String!
    $launchDate: DateTime
    $content: String!
    $seoPayload: String!
    $emailPayload: String!
    $merchantPayload: String!
    $trackingPayload: String!
    $cssPayload: String!
    $exitPayload: String!
    $type: String!
    $nextPage: ID!
    $parentDomain: String!
    $isHomePage: Boolean!
    $is404: Boolean!
    $cloudfrontDistribution: String
  ) {
    publishPage(
      pageId: $pageId
      slug: $slug
      subdomain: $subdomain
      launchDate: $launchDate
      content: $content
      seoPayload: $seoPayload
      emailPayload: $emailPayload
      merchantPayload: $merchantPayload
      trackingPayload: $trackingPayload
      cssPayload: $cssPayload
      exitPayload: $exitPayload
      type: $type
      nextPage: $nextPage
      parentDomain: $parentDomain
      isHomePage: $isHomePage
      is404: $is404
      cloudfrontDistribution: $cloudfrontDistribution
    ) {
      webSiteUrl
      message
      statusCode
    }
  }
`;

// makeThisMyHomePage;
export const makeThisMyHomePage = gql`
  mutation makePageAHomePage($domainId: ID!, $pageId: ID!) {
    updateDomain(
      where: { id: $domainId }
      data: { homePage: { connect: { id: $pageId } } }
    ) {
      id
      homePage {
        id
        name
      }
    }
  }
`;

// makeThisMyErrorPage;
export const makeThisMyErrorPage = gql`
  mutation makeThisMyErrorPage($domainId: ID!, $pageId: ID!) {
    updateDomain(
      where: { id: $domainId }
      data: { errorPage: { connect: { id: $pageId } } }
    ) {
      id
      errorPage {
        id
        name
      }
    }
  }
`;