import swaggerJsDoc from 'swagger-jsdoc'

// Extended: https://swagger.io/specification/#infoObject
const swaggerOptions = {
  swaggerDefinition: {
    info: {
      version: "1.0.0",
      title: "10 Minute Funnels API",
      description: "This is the api for the 10 Minute Funnels API server.",
      contact: {
        email: "support@tenminutefunnels.com"
      },
      servers: ["http://localhost:5000", "https://api.tenminutefunnels.com"],
    },
    basePath: "/v1",
    tags: [
      { name: "Sessions" },
      { name: "Campaigns" },
      { name: "Users" },
      { name: "Domains" },
      { name: "Integrations" },
      { name: "Pages" },
      { name: "iFrames" },
    ],
    definitions: {
      Campaign: {
        type: "object",
        properties: {
          name: { type: "string", example: "My Campaign Name" },
          scriptTags: {
            type: "object",
            example: {
              head: "<script type=\"text/javascript\">alert(\"CAMPAIGN - HEAD\");</script>",
              body: "<script type=\"text/javascript\">alert(\"CAMPAIGN - Body\");</script>",
              bodyEnd: "<script type=\"text/javascript\">alert(\"CAMPAIGN - /Body\");</script>"
            }
          },
          domainId: { type: "string", example: "ck5ba4z5h213y0814r56opqm7" },
        }
      },
      Domain: {
        type: "object",
        properties: {
          name: { type: "string", example: "newdomain.com" },
          campaignId: { type: "string", example: "qv5bz4v5h243y0814r56osdv1" },
        }
      },
      Integration: {
        type: "object",
        properties: {
          type: { type: "string", example: "aweber" },
          setting: {
            type: "object",
            example: {
              api_key: "29zd1c1a50e2207cd9d33cd10e6fd91g",
              app_id: "3548974"
            }
          },
        }
      },
      Page: {
        type: "object",
        properties: {
          name: { type: "string", example: "John's Lead Capture Page" },
          objectId: { type: "string", example: "lm4bz4v5h243y0814r56osdr6" },
          pageSettings: {
            type: "object",
            example: {
              tracking: {
                head: "<script type=\"text/javascript\">alert(\"Script ~ HEAD\");</script>",
                body: "<script type=\"text/javascript\">alert(\"Script ~ Body\");</script>",
                bodyEnd: "<script type=\"text/javascript\">alert(\"Script ~ /Body\");</script>"
              },
              seo: {
                title: "My Page Title",
                keywords: "Page Keywords",
                description: "Page Descriptions"
              },
              css: "body { background-color: blue; }",
              exitPopup: {
                id: "ji4uxr3sqh"
              }
            }
          },
          slug: { type: "string", example: "page-slug-name" },
          type: { type: "string", example: "lead", enum: ["blank", "content", "home", "launch", "products", "lead", "legal", "event", "checkout", "order", "sales", "oto", "thank", "webinar"] },
          theme: { type: "string", example: "event", enum: ["blank", "content", "home", "launch", "products", "lead", "legal", "event", "checkout", "order", "sales", "oto", "thank", "webinar"] },
          content: {
            type: "array",
            example: [
              {
                id: 2540,
                type: "Body",
                parent: false,
                properties: {
                  height: "100%"
                },
                canHaveChildren: true
              },
              {
                id: "a4v537npyce",
                type: "Paragraph",
                parent: 2540,
                html: "<p>My Headline Goes Here...</p>",
                properties: {
                  textAlign: "center",
                  fontSize: 40
                }
              }
            ]
          },
        }
      },
      User: {
        type: "object",
        properties: {
          firstName: { type: "string", example: "John" },
          lastName: { type: "string", example: "Smith" },
          email: { type: "string", example: "jsmith23@gmail.com" },
          company: { type: "string", example: "Acme Inc." },
          password: { type: "string", example: "1254737c076cf867dc53d60a0364f38e" },
          subdomain: { type: "string", example: "johnsmith" },
        }
      },
    }
  },
  apis: ["*/*.js"]
};

export const swaggerDocs = swaggerJsDoc(swaggerOptions);
