const express = require("express");
// const fs = require("fs-extra");
const bodyParser = require("body-parser");
// const shell = require("shelljs");
const AWS = require("aws-sdk");
const fs = require("fs"),
  http = require("http"),
  https = require("https");

const settings = require("../config");

const app = express();

const rootLocation = __dirname.substring(0, __dirname.indexOf("sandcastle"));

var options = {
  key: fs.readFileSync(
    // `${rootLocation}sandcastle/platform/server/.ssl/privatekey.pem`
    `/etc/letsencrypt/live/api.funnels.cc/privkey.pem`
  ),
  cert: fs.readFileSync(
    // `${rootLocation}sandcastle/platform/server/.ssl/certificate.pem`
    `/etc/letsencrypt/live/api.funnels.cc/fullchain.pem`
  ),
  ca: fs.readFileSync(
    // `${rootLocation}sandcastle/platform/server/.ssl/__10minutefunnels_com.ca-bundle`
  )
};

const awsDetails =
  settings.state === "staging"
    ? {
      bucketName: "sandcastlesites-staging",
      bucketBaseURL:
        "https://s3-us-west-2.amazonaws.com/sandcastlesites-staging/"
      // distributionId: "EH53PO6Z5NUP4",
    }
    : {
      bucketName: "sandcastlesites",
      bucketBaseURL: "https://s3-us-west-2.amazonaws.com/sandcastlesites/"
      // distributionId: "E31QPSUQXMU2CW",
    };

app.use(bodyParser.json());

// Setting up server
// Setting up server
const httpsServer = https.createServer(options, app);
const httpServer = http.createServer(app);

httpsServer.listen(process.env.PORT || 48083, () => {
  const port = httpsServer.address().port;
  console.log("(Https) App now running on port", port);
});

httpServer.listen(process.env.PORT || 8083, () => {
  const port = httpServer.address().port;
  console.log("(Http) App now running on port", port);
});

// CORS Middleware
app.use((req, res, next) => {
  // Enabling CORS
  res.header("Access-Control-Allow-Origin", "*");
  res.header("Access-Control-Allow-Methods", "GET,HEAD,OPTIONS,POST,PUT");
  res.header(
    "Access-Control-Allow-Headers",
    "Origin, X-Requested-With, contentType,Content-Type, Accept, Authorization"
  );
  next();
});

app.get("/", (req, res) => {
  res.send({ message: "Server is running!", statusCode: 200 });
});

app.post("/addDomain", (req, res) => {
  console.log("ADDING DOMAIN TO CLOUDFRONT");

  const domainName = req.body.Domain.node.name.toLowerCase();
  const distributionId = req.body.Domain.node.cloudfrontDistribution;
  // add to cloudfront
  const cloudfront = new AWS.CloudFront();

  const params = { Id: distributionId };

  console.log(params);

  cloudfront.getDistributionConfig(params, (err, data) => {
    if (err) console.error(err, err.stack);
    else {
      const aliases = data.DistributionConfig.Aliases.Items;

      const updatedConfig = {
        ...data,
        Id: distributionId,
        IfMatch: data.ETag,
        DistributionConfig: {
          ...data.DistributionConfig,
          Aliases: {
            Quantity: aliases.length + 1,
            Items: [...aliases, domainName]
          }
        }
      };

      // Remove ETag
      const { ETag, ...newConfig } = updatedConfig;

      cloudfront.updateDistribution(newConfig, (err, data) => {
        if (err) console.error(err);
        else {
          console.log(data);
          res.send(req.body);
        }
      });

      console.log(newConfig);
    }
  });
});

app.post("/deleteDomain", (req, res) => {
  console.log("DELETING DOMAIN FROM CLOUDFRONT");
  // console.log(req.body);
  const domainName = req.body.Domain.previousValues.name.toLowerCase();
  const distributionId = req.body.Domain.previousValues.cloudfrontDistribution;

  // add to cloudfront
  const cloudfront = new AWS.CloudFront();

  // const params = { Id: awsDetails.distributionId };
  const params = { Id: distributionId };
  console.log(params);

  cloudfront.getDistributionConfig(params, (err, data) => {
    if (err) console.error(err, err.stack);
    else {
      const aliases = data.DistributionConfig.Aliases.Items;
      const aliasItems = aliases.filter(alias => alias !== domainName);

      const updatedConfig = {
        ...data,
        Id: distributionId,
        IfMatch: data.ETag,
        DistributionConfig: {
          ...data.DistributionConfig,
          Aliases: {
            Quantity: aliasItems.length,
            Items: aliasItems
          }
        }
      };

      // Remove ETag
      const { ETag, ...newConfig } = updatedConfig;

      cloudfront.updateDistribution(newConfig, (err, data) => {
        if (err) console.error(err);
        else {
          console.log(data);
          res.send(req.body);
        }
      });

      console.log(newConfig);
    }
  });
});

module.exports = httpServer;
