const express = require("express");
const bodyParser = require("body-parser");
const fs = require("fs-extra");
const shell = require("shelljs");
const _ = require("lodash");
// const https = require("https");
const http = require("http");
const app = express();

// const settings = require("../config");
const {
  available_sites_folder,
  enabled_sites_folder,
  server_reset_command,
  proxy_root
} = require("./config");

app.use(bodyParser.json());

// Setting up server
const httpServer = http.createServer(app);

httpServer.listen(process.env.PORT || 8089, () => {
  const port = httpServer.address().port;
  console.log("(Http) App now running on port", port);
});

// CORS Middleware
app.use((req, res, next) => {
  // Enabling CORS
  res.header("Access-Control-Allow-Origin", "*");
  res.header("Access-Control-Allow-Methods", "GET,HEAD,OPTIONS,POST,PUT");
  res.header(
    "Access-Control-Allow-Headers",
    "Origin, X-Requested-With, contentType,Content-Type, Accept, Authorization"
  );
  next();
});

app.get("/", (req, res) => {
  console.log({
    available_sites_folder,
    enabled_sites_folder,
    server_reset_command,
    proxy_root
  });
  res.send({ message: "Server is running!", statusCode: 200 });
});

/**
 * Creating a new domain name
 */
app.post("/createDomain", async (req, res) => {
  const body = req.body;

  const { domain, ssl, email, proxyPass } = body; // the provided domain name

  console.log(body);

  const domain_folder = domain.replace(/\./g, "_");
  const conf_file_path = `${available_sites_folder}${domain_folder}`;

  const symlink_command = `sudo ln -s ${conf_file_path} ${enabled_sites_folder}`;

  // generate nginx server file content
  fs.readFile(`./nginx/nginx.conf.template`, "utf8", (err, data) => {
    if (err)
      return console.error("** ERROR Fetching Conf Template File **", err);

    const conf_content = _.template(data)({
      SERVER_NAME: domain,
      // PROXY_PASS: `${proxy_root}/${domain}/`,
      PROXY_PASS: `${proxyPass}/`,
      DOMAIN_FOLDER: domain_folder
    });

    // create the nginx server file
    console.log(conf_file_path, conf_content);

    // process.exit(1);

    fs.writeFile(conf_file_path, conf_content, async error => {
      if (error) {
        console.log("** ERROR Writing Server File **", error);
        return false;
      }

      // Trigger symlink to connect the file to the sites-enabled folder
      const response = await shell.exec(symlink_command);

      // Reset the server
      await shell.exec(server_reset_command);

      console.log("Create Domain Response", response);

      // create SSL if flag is on
      if (ssl) {
        const ssl_command = `sudo certbot --nginx -d ${domain} -n --redirect --agree-tos --email ${email}`;
        const response = await shell.exec(ssl_command);

        console.log("Create SSL Response", response);
      }

      res.send({
        statusCode: 200
      });
    });
  });
});

/**
 * Delete a domain name
 */
app.post("/deleteDomain", async (req, res) => {
  const body = req.body;
  const { domain } = body; // the provided domain name

  const domain_folder = domain.replace(/\./g, "_");
  const conf_file_path = `${enabled_sites_folder}${domain_folder}`;
  const unlink_command = `sudo unlink ${conf_file_path}`;

  // Unlink the file from 'sites-enabled'
  const response = await shell.exec(unlink_command);

  console.log("Domain Delete Response", response);

  res.send({
    statusCode: 200
  });
});

/**
 * Creating an SSL Certificate for a domain name
 */
app.post("/createSSL", async (req, res) => {
  const body = req.body;
  const { domain, email } = body; // the provided domain name

  const ssl_command = `sudo certbot --nginx -d ${domain} -n --redirect --agree-tos --email ${email}`;

  // trigger the command to create the ssl for the provided domain name
  const { stdout, stderr } = await shell.exec(ssl_command);

  console.log("Create SSL Response");
  console.log(stdout);

  res.send({ stdout, stderr });
});

module.exports = httpServer;
