const request = require("request");
const _ = require("lodash");
const decode = require("../decodeProviderPayload");
const settings = require("../config");

let app = [];

const headers = {
  "cache-control": "no-cache",
  "content-type": "application/json"
};

// Called From 10MF

app.push([
  "/api/activecampaignProspect",
  (req, res) => {
    // trigger mailchimp api for prospect submission
    const credentials = JSON.parse(_.get(req.body, "credentials", "{}"));
    const cPayload = JSON.parse(decode(credentials.payload));

    const { name, firstName, lastName } = req.body;

    let payload = {
      email_service_provider: "ActiveCampaign",
      ..._.omit(cPayload, ["campaign", "type", "campaignId"]),
      list_id: cPayload.campaignId,
      email: req.body.email,
      custom_fields: _.omit(req.body, [
        "payload",
        "credentials",
        "email",
        "name",
        "firstName",
        "lastName",
        ...Object.keys(req.body).filter(
          i => !req.body[i] || req.body[i] === "false"
        )
      ])
    };

    if (firstName) { payload.firstName = firstName; payload.name = firstName }
    if (name) payload.name = name;
    if (lastName) payload.lastName = lastName;

    const url = `https://${settings.lambdaAddress}${
      settings.prospectUrl["activecampaign"]
    }`;

    console.log({ payload }, { url }, { body: req.body }, { cPayload });

    request(
      { method: "post", url, headers, body: payload, json: true },
      (error, response, body) => {
        console.log({ payload }, { url }, { body });

        if (
          body.statusCode === 400 &&
          body.message.indexOf("EmailAlreadyUsed") === -1
        ) {
          res.send({
            ...body,
            error_found: "1",
            decline_reason: _.startCase(_.toLower(body.message))
          });
        } else {
          res.send(body);
        }
      }
    );
  }
]);

module.exports = app;
