const request = require("request");
const _ = require("lodash");
const decode = require("../decodeProviderPayload");
const settings = require("../config");

let app = [];

const headers = {
  "cache-control": "no-cache",
  "content-type": "application/json"
};

// Called From 10MF

app.push([
  "/api/authorizeOrder",
  (req, res) => {
    // trigger authorize api for order submission
    // console.log(req.body);
    const credentials = JSON.parse(_.get(req.body, "mCredentials", "{}"));
    const cPayload = JSON.parse(decode(credentials.payload));

    const payload = {
      ..._.omit(cPayload, ["campaign", "type", "campaignId"]),
      mode: "sandbox", // <-- make this toggleable by the user
      email: req.body.email,
      name: req.body.name,
      card_number: req.body.creditCardNumber,
      card_brand: req.body.creditCardType,
      card_holder_name: req.body.billingLastName
        ? `${req.body.billingFirstName} ${req.body.billingLastName}`
        : req.body.billingFirstName,
      cvv: req.body.CVV,
      exp_month: req.body.expirationDate.substring(0, 2),
      exp_year: `20${req.body.expirationDate.substring(2)}`,
      // description: "Test description", <-- put the product name in there
      // product_name: "",
      // product_description: "",
      shipping: {
        recipient_name: req.body.billingLastName
          ? `${req.body.billingFirstName} ${req.body.billingLastName}`
          : req.body.billingFirstName,
        line1: _.get(req.body, "shippingAddress1", false),
        line2: _.get(req.body, "shippingAddress2", false) || "null",
        city: _.get(req.body, "shippingCity", false),
        state: _.get(req.body, "shippingState", false),
        phone: _.get(req.body, "phone", false),
        postal_code: _.get(req.body, "shippingZip", false),
        country_code: _.get(req.body, "shippingCountry", false)
      },
      billing: {
        line1: _.get(req.body, "billingAddress1", false),
        city: _.get(req.body, "billingCity", false),
        state: _.get(req.body, "billingState", false),
        postal_code: _.get(req.body, "billingZip", false),
        country_code: _.get(req.body, "billingCountry", false)
      },
      custom_fields: _.omit(req.body, [
        "mCredentials",
        "amount",
        "email",
        "name",
        "creditCardNumber",
        "creditCardType",
        "billingLastName",
        "billingFirstName",
        "billingLastName",
        "CVV",
        "expirationDate",
        "shippingAddress1",
        "shippingAddress2",
        "shippingCity",
        "shippingState",
        "phone",
        "shippingZip",
        "shippingCountry",
        "billingAddress1",
        "billingCity",
        "billingState",
        "billingZip",
        "billingCountry",
        "billingModelId",
        "tranType",
        ...Object.keys(req.body).filter(
          i => !req.body[i] || req.body[i] === "false"
        )
      ]) // omit "false" entries
    };

    const url = `https://${settings.lambdaAddress}${
      settings.orderUrl["authorize"]
    }`;

    const cleanedPayload = {
      ..._.omit(payload, Object.keys(payload).filter(i => !payload[i])),
      shipping: _.omit(
        payload.shipping,
        Object.keys(payload.shipping).filter(i => !payload.shipping[i])
      ),
      billing: _.omit(
        payload.billing,
        Object.keys(payload.billing).filter(i => !payload.billing[i])
      ),
      custom_fields: _.omit(
        payload.custom_fields,
        Object.keys(payload.custom_fields).filter(
          i => !payload.custom_fields[i]
        )
      )
    };

    console.log({ cleanedPayload }, { url }, { body: req.body });

    request(
      { method: "post", url, headers, body: payload, json: true },
      (error, response, body) => {
        console.log({ payload }, { url }, { body });

        if (_.has(body, "errorMessage")) {
          const err = JSON.parse(body.errorMessage);
          console.log({ error: err });

          res.send({
            ...body,
            error_found: "1",
            error_message: _.startCase(_.toLower(err.message))
          });
        } else {
          res.send({
            ...body,
            email: req.body.email,
            order_id: body.card_id // <-- this is what the live site needs in order to trigger an upsell
          });
        }
      }
    );
  }
]);

app.push([
  "/api/authorizeUpsell",
  (req, res) => {
    // trigger authorize api for upsell submission
    const credentials = JSON.parse(_.get(req.body, "mCredentials", "{}"));
    const cPayload = JSON.parse(decode(credentials.payload));

    const payload = {
      ..._.omit(cPayload, ["campaign", "type", "campaignId"]),
      mode: "sandbox", // <-- make this toggleable by the user
      card_id: req.body.previousOrderId,
      email: req.body.email,
      name: req.body.name,
      // description: "Test description", <-- put the product name in there
      // product_name: "",
      // product_description: "",
      shipping: {
        recipient_name: req.body.billingLastName
          ? `${req.body.billingFirstName} ${req.body.billingLastName}`
          : req.body.billingFirstName,
        line1: _.get(req.body, "shippingAddress1", false),
        line2: _.get(req.body, "shippingAddress2", false) || "null",
        city: _.get(req.body, "shippingCity", false),
        state: _.get(req.body, "shippingState", false),
        phone: _.get(req.body, "phone", false),
        postal_code: _.get(req.body, "shippingZip", false),
        country_code: _.get(req.body, "shippingCountry", false)
      },
      billing: {
        line1: _.get(req.body, "billingAddress1", false),
        city: _.get(req.body, "billingCity", false),
        state: _.get(req.body, "billingState", false),
        postal_code: _.get(req.body, "billingZip", false),
        country_code: _.get(req.body, "billingCountry", false)
      },
      custom_fields: _.omit(req.body, [
        "mCredentials",
        "amount",
        "email",
        "name",
        "previousOrderId",
        "response_code",
        "statusCode",
        "card_id",
        "authorizenet_resp",
        "creditCardNumber",
        "creditCardType",
        "billingLastName",
        "billingFirstName",
        "billingLastName",
        "CVV",
        "expirationDate",
        "shippingAddress1",
        "shippingAddress2",
        "shippingCity",
        "shippingState",
        "phone",
        "shippingZip",
        "shippingCountry",
        "billingAddress1",
        "billingCity",
        "billingState",
        "billingZip",
        "billingCountry",
        "billingModelId",
        "tranType",
        ...Object.keys(req.body).filter(
          i => !req.body[i] || req.body[i] === "false"
        )
      ]) // omit "false" entries
    };

    const url = `https://${settings.lambdaAddress}${
      settings.upsellUrl["authorize"]
    }`;

    const cleanedPayload = {
      ..._.omit(payload, Object.keys(payload).filter(i => !payload[i])),
      shipping: _.omit(
        payload.shipping,
        Object.keys(payload.shipping).filter(i => !payload.shipping[i])
      ),
      billing: _.omit(
        payload.billing,
        Object.keys(payload.billing).filter(i => !payload.billing[i])
      ),
      custom_fields: _.omit(
        payload.custom_fields,
        Object.keys(payload.custom_fields).filter(
          i => !payload.custom_fields[i]
        )
      )
    };

    console.log({ cleanedPayload }, { url }, { body: req.body });

    request(
      { method: "post", url, headers, body: payload, json: true },
      (error, response, body) => {
        console.log({ payload }, { url }, { body });

        if (_.has(body, "errorMessage")) {
          const err = JSON.parse(body.errorMessage);
          console.log({ error: err });

          res.send({
            ...body,
            error_found: "1",
            error_message: _.startCase(_.toLower(err.message))
          });
        } else {
          res.send(body);
        }
      }
    );
  }
]);

module.exports = app;
