const request = require("request");
const _ = require("lodash");
const decode = require("../decodeProviderPayload");
const settings = require("../config");

let app = [];

const headers = {
  "cache-control": "no-cache",
  "content-type": "application/json"
};

// Called From 10MF

app.push([
  "/api/convertkitProspect",
  (req, res) => {
    // trigger convertkit api for prospect submission
    const credentials = JSON.parse(_.get(req.body, "credentials", "{}"));
    const cPayload = JSON.parse(decode(credentials.payload));

    const payload = {
      email_service_provider: "ConvertKit",
      ..._.omit(cPayload, ["campaign", "type", "campaignId"]),
      form_id: cPayload.campaignId,
      email: req.body.email,
      name: req.body.name,
      custom_fields: _.omit(req.body, [
        "payload",
        "credentials",
        "email",
        "name",
        ...Object.keys(req.body).filter(
          i => !req.body[i] || req.body[i] === "false"
        )
      ])
    };

    const url = `https://${settings.lambdaAddress}${
      settings.prospectUrl["convertkit"]
    }`;

    console.log({ payload }, { url }, { body: req.body });

    request(
      { method: "post", url, headers, body: payload, json: true },
      (error, response, body) => {
        console.log({ payload }, { url }, { body });

        if (body.statusCode === 400) {
          res.send({
            ...body,
            error_found: "1",
            decline_reason: _.startCase(_.toLower(body.message))
          });
        } else {
          res.send(body);
        }
      }
    );
  }
]);

module.exports = app;
