const request = require("request");
const _ = require("lodash");
const decode = require("../decodeProviderPayload");
const settings = require("../config");

let app = [];

const headers = {
  "cache-control": "no-cache",
  "content-type": "application/json"
};

// Called From 10MF

app.push([
  "/api/getresponseProspect",
  (req, res) => {
    // trigger getresponse api for prospect submission
    const credentials = JSON.parse(_.get(req.body, "credentials", "{}"));
    const cPayload = JSON.parse(decode(credentials.payload));

    const custom_fields = _.omit(req.body, [
      "payload",
      "credentials",
      "email",
      "name",
      "firstName",
      "lastName",
      ...Object.keys(req.body).filter(
        i => !req.body[i] || req.body[i] === "false"
      )
    ]);

    const { name, firstName, lastName } = req.body;

    let payload = {
      api_key: cPayload.api_key,
      email: req.body.email,
      email_service_provider: "GetResponse",
      campaignId: cPayload.campaignId,
      dayOfCycle: 0,
      custom_fields: _.map(custom_fields, (i, k) => ({
        customFieldId: k,
        value: [i]
      }))
    };
    
    if (name) payload.name = name;
    if (firstName) payload.firstName = firstName;
    if (lastName) payload.lastName = lastName;

    const url = `https://${settings.lambdaAddress}${
      settings.prospectUrl["getresponse"]
    }`;

    request(
      { method: "post", url, headers, body: payload, json: true },
      (error, response, body) => {
        // console.log({ payload }, { url }, { body }, { error });
        console.log('payload', payload)
        console.log('url', url)
        console.log('body', body)
        console.log('error', error)

        if (
          body.statusCode === 400 &&
          body.message.indexOf("already a list member") === -1
        ) {
          res.send({
            ...body,
            error_found: "1",
            // decline_reason: _.startCase(_.toLower(body.message))
            decline_reason: body.message
          });
        } else {
          res.send(body);
        }
      }
    );
  }
]);

module.exports = app;
