const request = require("request");
const _ = require("lodash");
const decode = require("../decodeProviderPayload");
const settings = require("../config");

let app = [];

const headers = {
  "cache-control": "no-cache",
  "content-type": "application/json"
};

// Called From 10MF

app.push([
  "/api/icontactProspect",
  (req, res) => {
    // trigger icontact api for prospect submission
    const credentials = JSON.parse(_.get(req.body, "credentials", "{}"));
    const cPayload = JSON.parse(decode(credentials.payload));

    const payload = {
      email_service_provider: "iContact",
      app_id: cPayload.app_id,
      password: cPayload.password,
      username: cPayload.username,
      account_id: cPayload.account_id,
      cFolder_id: cPayload.cFolder_id,
      email: req.body.email,
      name: req.body.name,
      list_id: cPayload.campaignId,
      street: _.get(req.body, "address", false),
      street2: _.get(req.body, "address2", false),
      city: _.get(req.body, "city", false),
      state: _.get(req.body, "state", false),
      postalCode: _.get(req.body, "zip", false),
      phone: _.get(req.body, "phone", false),
      // omit "false" entries
      custom_fields: _.omit(req.body, [
        "payload",
        "credentials",
        "email",
        "name",
        "street",
        "street2",
        "city",
        "state",
        "postalCode",
        "phone",
        ...Object.keys(req.body).filter(
          i => !req.body[i] || req.body[i] === "false"
        )
      ])
    };

    const cleanedPayload = _.omit(
      payload,
      Object.keys(payload).filter(i => !payload[i])
    );

    const url = `https://${settings.lambdaAddress}${
      settings.prospectUrl["icontact"]
    }`;

    console.log({ cleanedPayload }, { url }, { body: req.body });

    request(
      { method: "post", url, headers, body: cleanedPayload, json: true },
      (error, response, body) => {
        if (
          body.statusCode === 400 &&
          body.message.indexOf("already a list member") === -1
        ) {
          res.send({
            ...body,
            error_found: "1",
            decline_reason: _.startCase(_.toLower(body.message))
          });
        } else {
          res.send(body);
        }
      }
    );
  }
]);

module.exports = app;
