const express = require("express");
const bodyParser = require("body-parser");
const fs = require("fs");
const https = require("https");
const http = require("http");

const limelight = require("./limelight");
const mailchimp = require("./mailchimp");
const getresponse = require("./getresponse");
const icontact = require("./icontact");
const sendreach = require("./sendreach");
const activecampaign = require("./activecampaign");
const convertkit = require("./convertkit");
const drip = require("./drip");
const ontraport = require("./ontraport");

const stripe = require("./stripe");
const authorize = require("./authorize");
const paypal = require("./paypal");

const settings = require("./config");

const app = express();

const rootLocation = __dirname.substring(0, __dirname.indexOf("sandcastle"));

var options =
  settings.state !== "local"
    ? {
      key: fs.readFileSync(
        // `${rootLocation}sandcastle/platform/server/.ssl/privatekey.pem`
        `/etc/letsencrypt/live/api.funnels.cc/privkey.pem`
      ),
      cert: fs.readFileSync(
        // `${rootLocation}sandcastle/platform/server/.ssl/certificate.pem`
        `/etc/letsencrypt/live/api.funnels.cc/fullchain.pem`
      ),
      // ca: fs.readFileSync(
      //   `${rootLocation}sandcastle/platform/server/.ssl/__10minutefunnels_com.ca-bundle`
      // )
    }
    : { key: false, cert: false, ca: false };

// Setting up server
const httpServer = http.createServer(app);

if (settings.state !== "local") {
  const httpsServer = https.createServer(options, app);
  httpsServer.listen(process.env.PORT || 48081, () => {
    const port = httpsServer.address().port;
    console.log("(Https) App now running on port", port);
  });
}

httpServer.listen(process.env.PORT || 8081, () => {
  const port = httpServer.address().port;
  console.log("(Http) App now running on port", port);
});

app.use(bodyParser.json());

// CORS Middleware
app.use((req, res, next) => {
  // Enabling CORS
  res.header("Access-Control-Allow-Origin", "*");
  res.header("Access-Control-Allow-Methods", "GET,HEAD,OPTIONS,POST,PUT");
  res.header(
    "Access-Control-Allow-Headers",
    "Origin, X-Requested-With, contentType,Content-Type, Accept, Authorization"
  );
  next();
});

app.get("/", (req, res) => {
  res.send({ message: "Server is running!", statusCode: 200 });
});

limelight.forEach(itm => {
  app.post(itm[0], itm[1]);
});
mailchimp.forEach(itm => {
  app.post(itm[0], itm[1]);
});
getresponse.forEach(itm => {
  app.post(itm[0], itm[1]);
});
icontact.forEach(itm => {
  app.post(itm[0], itm[1]);
});
sendreach.forEach(itm => {
  app.post(itm[0], itm[1]);
});
activecampaign.forEach(itm => {
  app.post(itm[0], itm[1]);
});
convertkit.forEach(itm => {
  app.post(itm[0], itm[1]);
});
drip.forEach(itm => {
  app.post(itm[0], itm[1]);
});
ontraport.forEach(itm => {
  app.post(itm[0], itm[1]);
});

stripe.forEach(itm => {
  app.post(itm[0], itm[1]);
});
authorize.forEach(itm => {
  app.post(itm[0], itm[1]);
});
paypal.forEach(itm => {
  app.post(itm[0], itm[1]);
});

module.exports = httpServer;
