const request = require("request");
const querystring = require("querystring");
const _ = require("lodash");
const decode = require("../decodeProviderPayload");

let app = [];

const headers = {
  "cache-control": "no-cache",
  "content-type": "application/json",
  "platform-key": "80f4ff8b-c641-11e8-ab90-12f0b4779fbe"
};

// Called From 10MF
app.push([
  "/api/limelightCampaigns",
  (req, res) => {
    console.log({ body: req.body });

    // const payload = JSON.parse(req.body.payload);
    // const subdomain = payload.subdomain;
    const subdomain = req.body.payload.subdomain;
    const url = `https://${subdomain}.limelightcrm.com/api/v1/campaign_find_active`;

    request(
      { method: "post", url, headers, body: {}, json: true },
      (error, response, body) => {
        console.log(
          { url },
          { reqBody: req.body },
          { body: JSON.stringify(body) }
        );
        res.send(body);
      }
    );
  }
]);

app.push([
  "/api/limelightProducts",
  (req, res) => {
    const subdomain = req.body.payload.subdomain;
    const url = `https://${subdomain}.limelightcrm.com/api/v1/product_index`;

    request(
      {
        method: "post",
        url,
        headers,
        body: {
          product_id: req.body.payload.hasOwnProperty("productId")
            ? req.body.payload.productId
            : "all"
        },
        json: true
      },
      (error, response, body) => {
        res.send(body);
      }
    );
  }
]);

app.push([
  "/api/limelightShippingMethods",
  (req, res) => {
    const subdomain = req.body.payload.subdomain;
    const url = `https://${subdomain}.limelightcrm.com/api/v1/shipping_method_find`;

    request(
      {
        method: "post",
        url,
        headers,
        body: {
          campaign_id: req.body.payload.hasOwnProperty("campaignId")
            ? req.body.payload.campaignId
            : "all",
          search_type: "all",
          return_type: "shipping_method_view"
        },
        json: true
      },
      (error, response, body) => {
        res.send(body);
      }
    );
  }
]);

app.push([
  "/api/limelightOffers",
  (req, res) => {
    const subdomain = req.body.payload.subdomain;
    const url = `https://${subdomain}.limelightcrm.com/api/v1/offer_view`;

    request(
      {
        method: "post",
        url,
        headers,
        body: {
          campaign_id: req.body.payload.hasOwnProperty("campaignId")
            ? req.body.payload.campaignId
            : "all"
        },
        json: true
      },
      (error, response, body) => {
        res.send(body);
      }
    );
  }
]);

app.push([
  "/api/limelightBillingModels",
  (req, res) => {
    const subdomain = req.body.payload.subdomain;
    const url = `https://${subdomain}.limelightcrm.com/api/v1/billing_model_view`;

    request(
      {
        method: "post",
        url,
        headers,
        body: {
          offer_id: req.body.payload.offerId
        },
        json: true
      },
      (error, response, body) => {
        res.send(body);
      }
    );
  }
]);

app.push([
  "/api/limelightCampaign",
  (req, res) => {
    const subdomain = req.body.payload.subdomain;
    const url = `https://${subdomain}.limelightcrm.com/api/v1/campaign_view`;

    request(
      {
        method: "post",
        url,
        headers,
        body: {
          campaign_id: req.body.payload.hasOwnProperty("campaignId")
            ? req.body.payload.campaignId
            : "all"
        },
        json: true
      },
      (error, response, body) => {
        res.send(body);
      }
    );
  }
]);

// Called from a live website
app.push([
  "/api/limelightOrder",
  (req, res) => {
    const mCredentials = JSON.parse(req.body.mCredentials);
    const data = JSON.parse(decode(mCredentials.payload));

    const billing_model_id = req.body.billingModelId;

    // need to get list of products from localStorage or the payload
    // console.log(req.body)
    const shoppingCartItems = JSON.parse(req.body.shoppingCartItems);
    const purchaseType = req.body.purchaseType;
    const offers =
      purchaseType === "cart"
        ? _.map(shoppingCartItems, itm => ({
            ..._.omit(itm, ["image", "price", "sku"]),
            billing_model_id
          }))
        : data.products.map(offer => ({
            ...offer,
            billing_model_id
          }));

    // console.log({ offers });

    const subdomain = data.subdomain;

    const url = `https://${subdomain}.limelightcrm.com/api/v1/new_order`;

    const payload = {
      ...req.body,
      campaignId: data.campaignId,
      offers
    };

    console.log("Order Payload", payload);

    request(
      { method: "post", url, headers, body: payload, json: true },
      (error, response, body) => {
        console.log(body);
        res.send(body);
      }
    );
  }
]);

app.push([
  "/api/limelightUpsell",
  (req, res) => {
    const mCredentials = JSON.parse(req.body.mCredentials);
    const data = JSON.parse(decode(mCredentials.payload));
    const subdomain = data.subdomain;
    const url = `https://${subdomain}.limelightcrm.com/api/v1/new_order_card_on_file`;
    const billing_model_id = req.body.billingModelId;

    const payload = {
      ...req.body,
      offers: data.products.map(offer => ({
        ...offer,
        billing_model_id
      }))
    };

    console.log("Order Payload", payload);
    // console.log({ mCredentials }, { providerCredentials }, { subdomain, username, password });
    request(
      { method: "post", url, headers, body: payload, json: true },
      (error, response, body) => {
        console.log(body);
        res.send(body);
      }
    );
  }
]);

app.push([
  "/api/limelightProspect",
  (req, res) => {
    const credentials = JSON.parse(req.body.credentials);
    const providerCredentials = credentials.hasOwnProperty(
      "providerCredentials"
    )
      ? JSON.parse(decode(credentials.providerCredentials))
      : credentials;

    // const subdomain = providerCredentials.subdomain;
    // console.log("providerCredentials", providerCredentials);

    const data = JSON.parse(decode(credentials.payload));
    // console.log('data', data);
    // console.log('body', req.body);
    // process.exit();
    // const email = req.body.email;

    // const firstName = req.body.fname;
    const subdomain = data.subdomain;
    const campaignId = data.campaignId;
    const ipAddress = "127.0.0.1";

    // campaignId:
    // email:
    // ipAddress:
    // firstName:
    // lastName:
    // address1: address
    // address2: address (if no address1)
    // city:
    // state:
    // zip:
    // country:
    // phone:

    // { label: "Name", name: "name" },
    // { label: "Email", name: "email" },
    // { label: "Password", name: "password" },
    // { label: "Username", name: "username" },
    // { label: "First Name", name: "firstName" },
    // { label: "Last Name", name: "lastName" },
    // { label: "Address", name: "address" },
    // { label: "City", name: "city" },
    // { label: "State", name: "state" },
    // { label: "Country", name: "country" },
    // { label: "Zip Code", name: "zip" },
    // { label: "Phone", name: "phone" },

    const url = `https://${subdomain}.limelightcrm.com/api/v1/new_prospect`;
    // const data = { email, firstName, campaignId, ipAddress };

    const payload = {
      ...req.body,
      ipAddress,
      ...data
    };

    console.log(url, payload);

    request(
      { method: "post", url, headers, body: payload, json: true },
      (error, response, body) => {
        res.send(body);
      }
    );
  }
]);

app.push([
  "/api/boltPayTransaction",
  (req, res) => {
    const body = req.body;

    const mCredentials = JSON.parse(req.body.mCredentials);
    const data = JSON.parse(decode(mCredentials.payload));
    const subdomain = data.subdomain;

    const products = _.get(data, "products", false);
    let prodarr = [];
    products.forEach(product => {
      Object.keys({
        billing_model_id: "2",
        ..._.omit(product, ["billing_model_options", "can_be_trial", "name"])
      }).forEach(k => {
        const val = k === "billing_model_id" ? "2" : product[k];
        prodarr.push(`products[${product.id}][${k}]=${val}`);
      });
    });

    const qObj = {
      gateway_id: _.get(body, "gateway_id", false),
      ip_address: _.get(body, "ip_address", "127.0.0.1"),
      shipping_id: _.get(body, "shippingMethod", false),
      transaction_reference: _.get(
        body,
        "transaction_information.data.transaction_reference",
        false
      ),
      campaign_id: _.get(data, "campaignId", false),
      email: _.get(body, "customer_email", false),
      phone: _.get(body, "customer_phone", false),
      billing_same_as_shipping: "yes", // ??
      delivery_first_name: _.get(body, "customer_firstname", false),
      delivery_last_name: _.get(body, "customer_lastname", false),
      delivery_address_1: _.get(body, "address", false),
      delivery_city: _.get(body, "city", false),
      delivery_state: _.get(body, "state", false),
      delivery_zip: _.get(body, "zip", false),
      delivery_country: _.get(body, "country", false),
      billing_first_name: _.get(body, "customer_firstname", false),
      billing_last_name: _.get(body, "customer_lastname", false),
      billing_address_1: _.get(body, "address", false),
      billing_city: _.get(body, "city", false),
      billing_state: _.get(body, "state", false),
      billing_zip: _.get(body, "zip", false),
      billing_country: _.get(body, "country", false)
    };

    const url = `https://${subdomain}.limelightcrm.com/admin/api/boltpay_api.php?`;
    const queryString1 = querystring.stringify(qObj);
    const queryString2 = prodarr.join("&");
    const bPUrl = `${url}${queryString1}&${queryString2}`;

    console.log(qObj);
    console.log(bPUrl);

    // https://sandboxdemo.limelightcrm.com/admin/api/boltpay_api.php?gateway_id=14&ip_address=false&shipping_id=5&transaction_reference=BP_PB_TRANSACTIONS_0.4410555891709398&campaign_id=14&email=kjgraham%40gmail.com&phone=8134211554&billing_same_as_shipping=yes&delivery_first_name=Kyle&delivery_last_name=Graham&delivery_address_1=11806%20Stonewood%20Gate%20Dr&delivery_city=Riverview&delivery_state=FL&delivery_zip=33579&delivery_country=US&products[27][offer_id]=3&products[27][id]=27&products[27][product_id]=27&products[27][quantity]=1&products[31][offer_id]=3&products[31][id]=31&products[31][product_id]=31&products[31][quantity]=1&products[32][offer_id]=3&products[32][id]=32&products[32][product_id]=32&products[32][quantity]=1

    //username=demoapi&password=NHepu6pkBqbcrU&gateway_id=483&ip_address=10.1.1.44&shipping_id=65
    //&transaction_reference=BP_PB_TRANSACTIONS_0.664154618377204&campaign_id=573&email=hure5h%40addthis.com
    //&phone=%2B13217912616&billing_same_as_shipping=yes&delivery_first_name=Helen&delivery_last_name=Ure
    //&delivery_address_1=7+Montana+Court&delivery_city=Melbourne&delivery_state=FL&delivery_zip=32919
    //&delivery_country=US&billing_first_name=Helen&billing_last_name=Ure&billing_address_1=7+Montana+Court
    //&billing_city=Melbourne&billing_state=FL&billing_zip=32919&billing_country=US
    //&products[198][offer_id]=2&products[198][billing_model_id]=2&products[198][quantity]=1
    //&products[204][offer_id]=2&products[204][billing_model_id]=2&products[204][quantity]=2

    // console.log("BoltPay URL", url);

    request(
      {
        method: "post",
        url: bPUrl,
        headers,
        json: true
        // useQuerystring: true,
      },
      (error, response, body) => {
        console.log("body", body);
        res.send(body);
      }
    );
  }
]);

module.exports = app;
