const request = require("request");
const _ = require("lodash");
const decode = require("../decodeProviderPayload");
const settings = require("../config");

let app = [];

const headers = {
  "cache-control": "no-cache",
  "content-type": "application/json"
};

// Called From 10MF

app.push([
  "/api/ontraportProspect",
  (req, res) => {
    // trigger ontraport api for prospect submission
    const credentials = JSON.parse(_.get(req.body, "credentials", "{}"));
    const cPayload = JSON.parse(decode(credentials.payload));

    const payload = {
      ..._.omit(cPayload, ["campaign", "type", "campaignId"]),
      email_service_provider: "Ontraport",
      email: req.body.email,
      name: req.body.name,
      address: _.get(req.body, "address", false),
      address2: _.get(req.body, "address2", false),
      city: _.get(req.body, "city", false),
      state: _.get(req.body, "state", false),
      zip: _.get(req.body, "zip", false),
      cell_phone: _.get(req.body, "phone", false)
      // custom_fields: _.omit(req.body, [
      //   "payload",
      //   "credentials",
      //   "email",
      //   "name",
      //   "address",
      //   "address2",
      //   "city",
      //   "state",
      //   "zip",
      //   "cell_phone",
      //   ...Object.keys(req.body).filter(
      //     i => !req.body[i] || req.body[i] === "false"
      //   )
      // ]),  // <-- Think how to do this
    };

    const url = `https://${settings.lambdaAddress}${
      settings.prospectUrl["ontraport"]
    }`;

    const cleanedPayload = _.omit(
      payload,
      Object.keys(payload).filter(i => !payload[i])
    );

    request(
      { method: "post", url, headers, body: cleanedPayload, json: true },
      (error, response, body) => {
        console.log({ payload }, { url }, { body });

        if (body.statusCode === 400) {
          res.send({
            ...body,
            error_found: "1",
            decline_reason: _.startCase(_.toLower(body.message))
          });
        } else {
          res.send(body);
        }
      }
    );
  }
]);

module.exports = app;
