const request = require("request");
const _ = require("lodash");
const decode = require("../decodeProviderPayload");
const settings = require("../config");

let app = [];

const headers = {
  "cache-control": "no-cache",
  "content-type": "application/json"
};

// Called From 10MF

app.push([
  "/api/sendreachProspect",
  (req, res) => {
    // trigger sendreach api for prospect submission
    const credentials = JSON.parse(_.get(req.body, "credentials", "{}"));
    const cPayload = JSON.parse(decode(credentials.payload));

    const payload = {
      email_service_provider: "sendreach",
      ..._.omit(cPayload, ["campaign", "type"]),
      email: req.body.email,
      name: req.body.name,
      // omit "false" entries
      custom_fields: _.omit(req.body, [
        "payload",
        "credentials",
        "email",
        "name",
        ...Object.keys(req.body).filter(
          i => !req.body[i] || req.body[i] === "false"
        )
      ]),
      list_id: cPayload.campaignId
    };

    const url = `https://${settings.lambdaAddress}${
      settings.prospectUrl["sendreach"]
    }`;

    console.log({ payload }, { url }, { body: req.body }, { cPayload });

    request(
      { method: "post", url, headers, body: payload, json: true },
      (error, response, body) => {
        console.log({ payload }, { url }, { body });

        if (body.statusCode === 400) {
          // there is an error
          const message =
            typeof body.message === "string"
              ? body.message
              : body.message[Object.keys(body.message)[0]];
          console.log({ message });

          if (message.indexOf("subscriber already exists") > -1) res.send(body);
          else {
            res.send({
              ...body,
              error_found: "1",
              decline_reason: _.startCase(_.toLower(message))
            });
          }
        } else {
          res.send(body);
        }
      }
    );
  }
]);

module.exports = app;
