const request = require("request");
const _ = require("lodash");
const decode = require("../decodeProviderPayload");
const settings = require("../config");

let app = [];

const headers = {
  "cache-control": "no-cache",
  "content-type": "application/json"
};

// Called From 10MF

app.push([
  "/api/stripeOrder",
  (req, res) => {
    // trigger stripe api for order submission
    // console.log(req.body);
    const credentials = JSON.parse(_.get(req.body, "mCredentials", "{}"));
    const cPayload = JSON.parse(decode(credentials.payload));

    const payload = {
      secret_key: cPayload.secret_key,
      email: req.body.email,
      amount: parseFloat(cPayload.amount) * 100, // convert to cents
      currency: "USD",
      card_number: req.body.creditCardNumber,
      card_brand: req.body.creditCardType,
      card_holder_name: req.body.billingLastName
        ? `${req.body.billingFirstName} ${req.body.billingLastName}`
        : req.body.billingFirstName,
      cvv: req.body.CVV,
      exp_month: req.body.expirationDate.substring(0, 2),
      exp_year: `20${req.body.expirationDate.substring(2)}`,
      // description: "Test description", <-- put the product name in there
      custom_fields: _.omit(req.body, [
        "mCredentials",
        "email",
        "amount",
        "creditCardNumber",
        "creditCardType",
        "CVV",
        "expirationDate",
        "billingModelId",
        "tranType",
        ...Object.keys(req.body).filter(
          i => !req.body[i] || req.body[i] === "false"
        )
      ]) // omit "false" entries
    };

    const url = `https://${settings.lambdaAddress}${
      settings.orderUrl["stripe"]
    }`;
    console.log({ payload }, { url }, { body: req.body });

    request(
      { method: "post", url, headers, body: payload, json: true },
      (error, response, body) => {
        console.log("RESPONSE: ", { payload }, { url }, { body });

        if (_.get(body, "errorType", false) === "Error") {
          const err = JSON.parse(body.errorMessage);
          console.log({ error: err });

          res.send({
            ...body,
            error_found: "1",
            error_message: _.startCase(_.toLower(err.message))
          });
        } else {
          res.send({
            ...body,
            email: req.body.email,
            order_id: _.get(body, "card_id", false) // <-- this is what the live site needs in order to trigger an upsell
          });
        }
      }
    );
  }
]);

app.push([
  "/api/stripeUpsell",
  (req, res) => {
    // trigger stripe api for upsell submission

    const credentials = JSON.parse(_.get(req.body, "mCredentials", "{}"));
    const cPayload = JSON.parse(decode(credentials.payload));

    const payload = {
      secret_key: cPayload.secret_key,
      email: req.body.email,
      card_id: req.body.previousOrderId,
      amount: parseFloat(cPayload.amount) * 100, // convert to cents
      currency: "USD"
      // description: "Test description", <-- put the product name in there
    };

    const url = `https://${settings.lambdaAddress}${
      settings.upsellUrl["stripe"]
    }`;

    request(
      { method: "post", url, headers, body: payload, json: true },
      (error, response, body) => {
        console.log({ payload }, { url }, { body });

        if (body.errorType === "Error") {
          const err = JSON.parse(body.errorMessage);
          console.log({ error: err });

          res.send({
            ...body,
            error_found: "1",
            error_message: _.startCase(_.toLower(err.message))
          });
        } else {
          res.send(body);
        }
      }
    );
  }
]);

module.exports = app;
