const shell = require("shelljs");
const fs = require("fs-extra");
const _ = require("lodash");

const homePageDefault = require("../defaults/homePage.json");
const page404Default = require("../defaults/404Page.json");

const generateFontList = require("./generateFontList");
const getBucket = require("./getBucket");
const doSiteBuild = require("./doSiteBuild");
const doQuickPublish = require("./doQuickPublish");

const settings = require("../config");
const sanitize = require("../sanitize");

const { gatsbySiteLocation } = settings;

const doPageUpdate = (req, res) => {
  // 1. download the content file from the bucket folder
  const body = req.body;
  const contentFilePath = `${gatsbySiteLocation}/data/`;

  const cpCommand = `aws s3 cp s3://${getBucket(body.parentDomain)}/${body.parentDomain}/content.json ${contentFilePath}`;

  shell.exec(cpCommand, (code, stdout) => {
    // 2. if none exists, we'll start from scratch
    if (!stdout)
      fs.writeFile(`${contentFilePath}content.json`, JSON.stringify([]));

    // 3. using the posted payload, generate a new content file
    fs.readFile(`${contentFilePath}content.json`, "utf-8", (err, data) => {
      const s3contentJson = JSON.parse(data.trim());
      const existingContent = _.get(s3contentJson, 'pages', [])
      const index = existingContent.findIndex(page => page.id === body.pageId);

      const obj = {
        id: body.pageId,
        slug: body.slug,
        subdomain: body.subdomain,
        launchDate: body.launchDate,
        content: sanitize(body.content, body),
        seoPayload: body.seoPayload,
        emailPayload: body.emailPayload,
        merchantPayload: body.merchantPayload,
        trackingPayload: sanitize(body.trackingPayload, body),
        cssPayload: body.cssPayload,
        exitPayload: body.exitPayload,
        nextPage: body.nextPage,
        type: body.type,
        isHomePage: body.isHomePage,
        is404: body.is404
      };

      console.log("Object", obj)

      let updatedContentObject =
        index > -1
          ? [
            ...existingContent.slice(0, index),
            obj,
            ...existingContent.slice(index + 1)
          ]
          : [...existingContent, obj];

      const pgScaff = {
        seoPayload: "{}",
        emailPayload: "{}",
        merchantPayload: "{}",
        trackingPayload: "{}",
        cssPayload: "",
        exitPayload: "{}",
        launchDate: new Date().toISOString(),
        nextPage: "#"
      };

      // are there any 404 pages
      const any404s = _.findIndex(updatedContentObject, pg => pg.is404) > -1;
      // if not add one
      if (!any404s)
        updatedContentObject = [
          ...updatedContentObject,
          {
            ...pgScaff,
            type: "404",
            id: "404",
            slug: "404",
            isHomePage: false,
            is404: true,
            content: JSON.stringify(page404Default)
          }
        ];

      // are there any home pages
      const anyHomePages =
        _.findIndex(updatedContentObject, pg => pg.isHomePage) > -1;
      // if not add one
      if (!anyHomePages)
        updatedContentObject = [
          ...updatedContentObject,
          {
            ...pgScaff,
            type: "home",
            id: "home",
            slug: "home",
            isHomePage: true,
            is404: false,
            content: JSON.stringify(homePageDefault)
          }
        ];

      // console.log("Updated Content Object", updatedContentObject);
      // console.log("Any 404s?", any404s);
      // console.log("Any Home Pages?", anyHomePages);

      const updatedConfigWithFontList = generateFontList(
        data,
        updatedContentObject
      );


      const updatedContent = JSON.stringify({
        ...s3contentJson,
        fonts: updatedConfigWithFontList,
        pages: updatedContentObject
      });

      // 4. now overwrite the current file with my modified file
      fs.writeFile(`${contentFilePath}content.json`, updatedContent, error => {
        if (error) return false;

        // upload it to s3
        doQuickPublish(req, res);

        // update path-prefix
        // fs.readFile(
        //   `${gatsbySiteLocation}/gatsby-config-template.js`,
        //   "utf-8",
        //   (err, data) => {
        //     const updatedConfigWithFontList = generateFontList(
        //       data,
        //       updatedContent
        //     );

        //     // still necessary?
        //     const updatedConfigWithTrackingScripts = updatedConfigWithFontList.replace(
        //       "<%=trackingScripts%>",
        //       "{}"
        //     );

        //     const updatedGatsbyConfigFileContent = updatedConfigWithTrackingScripts;

        //     fs.writeFile(
        //       `${gatsbySiteLocation}/gatsby-config.js`,
        //       updatedGatsbyConfigFileContent,
        //       error => {
        //         doSiteBuild(req, res);
        //       }
        //     );
        //   }
        // );
      });
    });
  });
};

module.exports = doPageUpdate;
