import _ from "lodash";
import PropTypes from "prop-types";
import React, { Component } from "react";
import ButtonSliderGroup from "../BuildingBlocks/ButtonSliderGroup";

/**
 * Creates a Button Slider Group to Change the Components Padding
 */
class Padding extends Component {
  constructor(props) {
    super(props);

    this.handleChange = this.handleChange.bind(this);
  }

  handleChange(value, dbUpdate = true, wait = 500) {
    const { updateComponentStyle, onChange, settings } = this.props;

    const padding = settings.properties.padding
      ? settings.properties.padding
      : 0;

    const paddingOffset = value === "SHRINK" ? padding - 5 : padding + 5;
    const newStyle = {
      padding: Number.isInteger(value) ? value : paddingOffset
    };

    updateComponentStyle(settings.id, newStyle, dbUpdate, false);

    onChange();
  }

  render() {
    const { settings } = this.props;

    return (
      <ButtonSliderGroup
        onChange={this.handleChange}
        text="Padding"
        button1={{ icon: "remove", value: "SHRINK" }}
        button2={{ icon: "add", value: "GROW" }}
        minValue={_.get(this.props, "minValue", 0)}
        maxValue={_.get(this.props, "maxValue", 200)}
        value={_.get(settings, "properties.padding", 0)}
      />
    );
  }
}

Padding.propTypes = {
  onChange: PropTypes.func,
  updateComponentStyle: PropTypes.func.isRequired
};

Padding.defaultProps = {
  onChange: () => false
};

export default Padding;
