import PropTypes from "prop-types";
import React, { Component } from "react";
import { get, has } from "lodash";
import {
  AlphaPicker,
  Swatches,
  CirclePicker,
  SliderPicker,
  SketchPicker,
  HuePicker,
} from "react-color";
import { Button } from "@sc/components/ui";
/**
 * A collapsable color picker
 */
const style = {
  fieldset: {
    border: "1px solid #ccc",
    marginBottom: 20,
    padding: 20,
  },
  input: {
    backgroundColor: "transparent",
    border: "none",
    padding: 5,
    maxWidth: 70,
    outline: "none",
    margin: 10,
    color: "#FFF",
  },
  pickerElement: {
    width: 26,
    height: 26,
    display: "inline-block",
    top: 8,
    cursor: "pointer",
    position: "relative",
    border: "1px solid transparent",
    ":hover": {
      border: "1px solid white",
    },
  },
};

class ColorPicker extends Component {
  constructor(props) {
    super(props);
    this.state = {
      colorExpanded: props.colorExpanded,
      color: props.color.hex,
      showSketchPicker: false,
    };
    this.toggleColorExpansion = this.toggleColorExpansion.bind(this);
    this.handleChange = this.handleChange.bind(this);
    this.handleKeyUp = this.handleKeyUp.bind(this);
    this.doChange = this.doChange.bind(this);
  }

  toggleColorExpansion() {
    this.setState((prevState) => ({
      colorExpanded: !prevState.colorExpanded,
    }));
  }

  handleChange(event) {
    this.setState({ color: event.target.value });
  }

  doChange(color, dbUpdate = true, wait = 500) {
    this.setState({ color: color.hex }, () => {
      this.props.onChange(color, dbUpdate, wait);
    });
  }

  handleKeyUp(e) {
    // if (e.keyCode === 13) {
    //   this.doChange({ hex: this.state.color }, true);
    // }

    if (e.keyCode === 46 || e.keyCode === 8) return false;
  }

  render() {
    // const { colorExpanded, color } = this.state;
    const { colorExpanded, showSketchPicker } = this.state;
    const {
      toolTip,
      text,
      showCircles,
      showSlider,
      showAlpha,
      showHex,
      color,
      pageContent = [],
    } = this.props;

    // const colorArray = ['#FFFFFF', '#C0C0C0', '#808080', '#000000', '#FF0000', '#800000', '#FFFF00', '#808000', '#00FF00', '#008000', '#00FFFF', '#008080', '#0000FF', '#000080', '#FF00FF', '#800080'];
    let colorArray = this.props.colorArray || [
      "#C0392B",
      "#E74C3C",
      "#9B59B6",
      "#8E44AD",
      "#2980B9",
      "#3498DB",
      "#1ABC9C",
      "#16A085",
      "#27AE60",
      "#2ECC71",
      "#F1C40F",
      "#F39C12",
      "#E67E22",
      "#D35400",
      "#ECF0F1",
      "#BDC3C7",
      "#95A5A6",
      "#34495E",
      "#2C3E50",
      "#F7F7F7",
      "#000000",
      "red",
      "green",
      "blue",
    ];

    // look through the document for any other colors they added
    const colorBlocks = pageContent.filter(
      (itm) =>
        has(itm, "properties.color") || has(itm, "properties.backgroundColor")
    );

    colorBlocks.forEach((itm) => {
      const isInArray = (color) => colorArray.indexOf(color) > -1;

      const color = get(itm, "properties.color", false);
      if (color && !isInArray(color)) colorArray.push(color);

      const backgroundColor = get(itm, "properties.backgroundColor", false);
      if (backgroundColor && !isInArray(backgroundColor))
        colorArray.push(backgroundColor);
    });

    const Colors = () => (
      <div style={{ width: 240, margin: "10px auto" }}>
        {colorExpanded ? (
          <div style={{ padding: 0, marginBottom: 0 }}>
            {showCircles && !showSketchPicker ? (
              <div
                style={{ marginBottom: 20 }}
                onMouseDown={(e) => e.stopPropagation()}
              >
                <CirclePicker
                  color={color}
                  colors={_.uniq(colorArray)}
                  onChange={(c) => this.doChange(c, false, true)}
                  onChangeComplete={(c) => this.doChange(c, true)}
                />
              </div>
            ) : null}
            {showSketchPicker && (
              <div style={{ margin: "15px auto", width: 220 /*, zoom: 1.35*/ }}>
                <SketchPicker
                  color={color}
                  onChange={(c) => this.doChange(c, false, 500)}
                  onChangeComplete={(c) => this.doChange(c, true)}
                />
              </div>
            )}
            <div style={{ textAlign: "center" }}>
              <Button
                transparent
                style={{
                  marginBottom: 15,
                  color: "#333",
                }}
                onClick={() =>
                  this.setState(({ showSketchPicker }) => ({
                    showSketchPicker: !showSketchPicker,
                  }))
                }
              >
                {showSketchPicker ? `Show Less Colors` : `Show More Colors`}
              </Button>
            </div>
            {showSlider && !showSketchPicker ? (
              <div style={{ marginBottom: 20 }}>
                <SliderPicker
                  color={color}
                  onChange={(c) => this.doChange(c, false, true)}
                  onChangeComplete={(c) => this.doChange(c, true)}
                />
              </div>
            ) : null}
            {showAlpha && !showSketchPicker ? (
              <div style={{ marginBottom: 20 }}>
                <AlphaPicker
                  color={color}
                  width={250}
                  onChange={(c) => this.doChange(c, false, true)}
                  onChangeComplete={(c) => this.doChange(c, true)}
                />
              </div>
            ) : null}
          </div>
        ) : null}
        {showHex && !showSketchPicker && (
          <div
            style={{
              backgroundColor: "#555",
              borderRadius: 4,
              padding: "0 10px",
            }}
          >
            <label style={{ color: "white" }}>{text}</label>
            <input
              value={this.state.color}
              ref={(el) => (this.input = el)}
              onClick={() => console.log("CLICKED")}
              onChange={(e) => this.setState({ color: e.target.value })}
              onKeyUp={this.handleKeyUp}
              onFocus={() => this.props.setIsEditing(true)}
              onBlur={() => {
                this.props.setIsEditing(false);
                this.doChange({ hex: this.state.color }, true);
              }}
              style={{ ...style.input, backgroundColor: "#666" }}
            />

            <div
              style={{ ...style.pickerElement, backgroundColor: color }}
              onClick={this.toggleColorExpansion}
            />

            <button
              onClick={() =>
                this.doChange({ rgb: { r: 0, g: 0, b: 0, a: 0 } }, true)
              }
              style={{
                // backgroundColor: "#666",
                backgroundColor: "transparent",
                border: "transparent",
                // borderRadius: 4,
                color: "#CCC",
                cursor: "pointer",
                float: "right",
                marginTop: 12,
              }}
            >
              clear
            </button>
          </div>
        )}
      </div>
    );

    return (
      <fieldset
        style={style.fieldset}
        title={toolTip}
        onClick={(e) => e.stopPropagation()}
      >
        <legend>{text}</legend>
        <Colors />
      </fieldset>
    );
  }
}

ColorPicker.propTypes = {
  /** This is the color that is currently selected */
  color: PropTypes.string.isRequired,
  /** This is the descriptive text label that will appear next to the colors */
  text: PropTypes.string.isRequired,
  /** This event is triggered when the color is changed */
  onChange: PropTypes.func.isRequired,
  /** Boolean if the the Alpha Picker should show */
  showAlpha: PropTypes.bool,
  /** Boolean if the horizontal slider hue picker should show */
  showSlider: PropTypes.bool,
  /** Boolean if the array of circles should show */
  showCircles: PropTypes.bool,
  /** Boolean if the expanded color options should show */
  colorExpanded: PropTypes.bool,
};

ColorPicker.defaultProps = {
  color: "#FF0000",
  text: "Colors",
  showCircles: true,
  showSlider: true,
  showHex: true,
  showAlpha: false,
  colorExpanded: true,
};

export default ColorPicker;
