import React from 'react'
import { render, fireEvent, cleanup } from '@testing-library/react'
import '@testing-library/jest-dom/extend-expect'
import { AlphabetFilter } from '..';
import {
  containerStyleData,
  characterStyleData,
  DefaultComponent,
  WithCustomContainerStyle,
  WithCustomCharacterStyle,
} from './AlphabetFilter.stories'

afterEach(cleanup)

describe("<AlphabetFilter /> Tests", () => {

  it(`Should render in the dom`, () => {
    const { getByTestId } = render(<DefaultComponent />)
    expect(getByTestId('AlphabetFilter-Default')).not.toBe(null)
  })

  it(`Should render the alphabet in the dom`, () => {
    const { getAllByTestId } = render(<DefaultComponent />)
    expect(getAllByTestId('AlphabetFilter-Character').length).toBe(26)
  })

  it(`Should overwrite the default container style with the containerStyle prop if one is provided`, () => {
    const { getByTestId } = render(<WithCustomContainerStyle />)
    const html = getByTestId('AlphabetFilter-Default').outerHTML;
    expect(html).toContain(`border: ${containerStyleData.border};`)
  })

  it(`Should overwrite the character style with the characterStyle prop if one is provided`, () => {
    const { getAllByTestId } = render(<WithCustomCharacterStyle />)
    const html = getAllByTestId('AlphabetFilter-Character')[0].outerHTML;
    expect(html).toContain(`border: ${characterStyleData.border};`)
  })

  it(`Should triggers an onClick event when an alphabet character is clicked`, () => {
    const onClick = jest.fn()
    const { queryAllByTestId } = render(<AlphabetFilter onClick={ch => onClick(ch)} />)
    fireEvent.click(queryAllByTestId('AlphabetFilter-Character')[0])
    expect(onClick).toHaveBeenCalled()
  })

});
