import React from "react";
import { render, fireEvent, cleanup } from "@testing-library/react";
import "@testing-library/jest-dom/extend-expect";

import { BulkActionsMenu } from '../'
import { DefaultComponent, RenderAsIcon, RenderAsButton, bulkActionsSampleData } from "./BulkActionsMenu.stories";

describe("<BulkActionsMenu /> Tests", () => {

  afterEach(cleanup)

  it(`Should render component in dom`, () => {
    const { getByTestId } = render(<DefaultComponent />);
    expect(getByTestId("BulkActionsMenu-Default")).not.toBe(null);
  });

  it(`Should show an icon when type prop calls for it`, () => {
    const { getByTestId } = render(<RenderAsIcon />);
    expect(getByTestId("BulkActionsMenu-Icon")).not.toBe(null);
  });

  it(`Should show a button when type prop calls for it.`, () => {
    const { getByTestId } = render(<RenderAsButton />);
    expect(getByTestId("BulkActionsMenu-Button")).not.toBe(null);
  });

  it(`Button label should be what the label prop calls for`, () => {
    const { getByText } = render(<RenderAsButton />);
    expect(getByText("Actions Dropdown")).not.toBe(null);
  });

  it(`Should show a dropdown menu of items from the data prop when button/icon is clicked`, async () => {
    const { getByTestId, queryAllByTestId } = render(<DefaultComponent />);
    const myContent = getByTestId("BulkActionsMenu-Icon")
    fireEvent.click(myContent)
    expect(queryAllByTestId('BulkActionsMenu-MenuItem').length).toBe(bulkActionsSampleData.length)
  });

  it(`Should trigger the onSelect event when a bulk action menu item is selected`, () => {
    const onSelect = jest.fn(itm => itm)
    const { getByTestId, queryAllByTestId } = render(<BulkActionsMenu data={bulkActionsSampleData} onSelect={itm => onSelect(itm)} />);
    const myContent = getByTestId("BulkActionsMenu-Icon")
    fireEvent.click(myContent)
    fireEvent.click(queryAllByTestId('BulkActionsMenu-MenuItem')[0])
    expect(onSelect).toBeCalled()
  });
});
