import React from "react";
import { render, fireEvent, cleanup } from "@testing-library/react";
import "@testing-library/jest-dom/extend-expect";

import { BulkSelectedActions } from '../'
import { DefaultComponent, RenderWithChildren, RenderWithActionButtons, RenderWithoutActionButtons, RenderWithActionMenu } from './BulkSelectedActions.stories'
import { bulkActionsSampleData } from '../BulkActionsMenu/BulkActionsMenu.stories'

import { BulkSelectedActionsPropsLocation } from '../types'

describe("<BulkSelectedActions /> Tests", () => {

  afterEach(cleanup)

  it(`Should render component in dom`, () => {
    const { getByTestId } = render(<DefaultComponent />);
    expect(getByTestId("BulkSelectedActions-Default")).not.toBe(null);
  })

  it(`Should display child components in dom`, () => {
    const { getByTestId } = render(<RenderWithChildren />);
    expect(getByTestId("BulkSelectedActions-Children").firstChild).not.toBe(null);
  })

  it(`Should pass child component its props`, () => {
    const { getByText } = render(
      <BulkSelectedActions data={['Testing']}>
        {props => <div>{props.data[0]}</div>}
      </BulkSelectedActions>
    );

    expect(getByText('Testing')).not.toBe(null)
  })

  it(`Should show a dropdown menu of items from data prop when bulk action button is clicked`, () => {

    const { getByTestId, queryAllByTestId } = render(<RenderWithActionMenu />)
    expect(getByTestId("BulkActionsMenu-Default")).not.toBe(null);
    const myContent = getByTestId("BulkActionsMenu-Icon")
    fireEvent.click(myContent)
    expect(queryAllByTestId('BulkActionsMenu-MenuItem').length).toBe(bulkActionsSampleData.length)
  })

  it(`Should show the component in the location specified by the location prop (e.g. TOP/BOTTOM/LEFT/RIGHT)`, () => {
    const BSA_TOP = render(<BulkSelectedActions location={BulkSelectedActionsPropsLocation.TOP} />);
    expect(BSA_TOP.getByTestId(`BulkSelectedActions-location-${BulkSelectedActionsPropsLocation.TOP}`)).not.toBe(null);

    const BSA_BOTTOM = render(<BulkSelectedActions location={BulkSelectedActionsPropsLocation.BOTTOM} />);
    expect(BSA_BOTTOM.getByTestId(`BulkSelectedActions-location-${BulkSelectedActionsPropsLocation.BOTTOM}`)).not.toBe(null);

    const BSA_LEFT = render(<BulkSelectedActions location={BulkSelectedActionsPropsLocation.LEFT} />);
    expect(BSA_LEFT.getByTestId(`BulkSelectedActions-location-${BulkSelectedActionsPropsLocation.LEFT}`)).not.toBe(null);

    const BSA_RIGHT = render(<BulkSelectedActions location={BulkSelectedActionsPropsLocation.RIGHT} />);
    expect(BSA_RIGHT.getByTestId(`BulkSelectedActions-location-${BulkSelectedActionsPropsLocation.RIGHT}`)).not.toBe(null);

  })

  it(`Should not show any action buttons if the showActionButtons prop is set to false`, () => {
    const { queryByTestId } = render(<RenderWithoutActionButtons />)
    expect(queryByTestId('BulkSelectedActions-ActionButtons')).toBe(null)
  })

  it(`Should show a list of buttons as specified by the actionsButtons prop intended to perform the most common actions for the selected records.`, () => {
    const { queryAllByTestId, getByTestId } = render(<RenderWithActionButtons />)
    expect(getByTestId('BulkSelectedActions-ActionButtons')).not.toBe(null)
    expect(queryAllByTestId('BulkSelectedActions-ActionButton').length).toEqual(3)
  })

});
