import { EditorMode } from "@sc/modules/v2/Editor/types";
import { IconTypes } from "@sc/plugins/webcomponents/v2/Icon";
import { FormFieldTypes } from "../types";
import { FieldNamePresets } from "../EditFormField/types";

export interface SProps {
  mode?: EditorMode;
  inputStyle: any;
}
export interface LiveFormFieldProps {
  /**
   * A unique identifier to use for this form field
   */
  id?: string;

  /**
   * The type of form field to be rendered.
   */
  type?: FormFieldTypes;

  /**
   * Alias of 'type'
   */
  fieldType?: FormFieldTypes;

  /**
   * The preset that was used when building the form
   */
  preset?: FieldNamePresets;

  /**
   * name to use for the form field
   */
  name?: string;

  /**
   * placeholder to use for the form field
   */
  placeholder?: string;

  /**
   * the list of items to use where there are multiple options needed (e.g. a dropdown menu, multiple choice array)
   */
  items?: any[];

  /**
   * the label to show next to the form field
   */
  label?: string;

  /**
   * the description to show next to the form field
   */
  description?: string;

  /**
   * the value to use for the form field
   */
  defaultValue?: string;

  /**
   * the style to use for the default form field • an object of styles to use for the different aspects of the form field (e.g. validation container, the input field, the main container, the label, etc.)
   */
  styles?: {
    labelStyle?: React.CSSProperties;
    inputStyle?: React.CSSProperties;
    descriptionStyle?: React.CSSProperties;
    containerStyle?: React.CSSProperties;
    validationStyle?: React.CSSProperties;
    iconStyle?: React.CSSProperties;
  };

  /**
   * whether or not the field is disabled
   */
  disabled?: boolean;

  /**
   * the icon to use in this form field
   */
  icon?: IconTypes;

  /**
   * The number of columns (out of 12) to consume
   */
  columns?: number;

  /**
   * Whether or not the form field (when in edit mode) is showing in its expanded or collapsed form
   */
  isExpanded?: boolean;

  /**
   * Whether or not the form field is a requred field
   */
  isRequired?: boolean;

  /**
   * function to trigger when the form field changes.  returns a mutated version of the current LiveFormFieldProps payload
   */
  onChange?: (payload: LiveFormFieldProps) => void;

  /**
   * function to trigger when a blur occurs on the form field.  returns a mutated version of the current LiveFormFieldProps payload
   */
  onBlur?: (payload: LiveFormFieldProps) => void;

  /**
   * function to trigger when a keyUp event occurs with the form field
   */
  onKeyUp?: (evt: React.KeyboardEvent, payload: LiveFormFieldProps) => void;

  /**
   * function to trigger when a click event occurs with the form field
   */
  onClick?: () => void;
}
