import * as React from "react";
import { action } from "@storybook/addon-actions";
import { withKnobs, text, boolean, select } from "@storybook/addon-knobs";

import SortableList from "./SortableList";
import { SortableListProps, ItemComponentProps } from "./types";

export default {
  title: "Modules|CRUD/SortableList",
  component: SortableList,
  excludeStories: /.*Data$/,
};

export const propsData: SortableListProps = {
  data: [{ id: "1" }, { id: "2" }, { id: "3" }],
  ItemComponent: (props) => (
    <div style={{ padding: 20, border: `2px solid green` }}>{props.id}</div>
  ),
  showCRUDOnHover: false,
};

export const Default: any = () => {
  const [data, setData] = React.useState<unknown[]>([
    { id: "1", firstName: "Kyle" },
    { id: "2", firstName: "Linda" },
    { id: "3", firstName: "Mikel" },
    { id: "4", firstName: "Nevaeh" },
  ]);

  return (
    <SortableList
      // showCRUDOnHover={false}
      style={{ width: 300 }}
      data={data}
      ItemComponent={(itm) => (
        <div
          style={{
            // width: 250,
            width: "100%",
            padding: 10,
            margin: 5,
            border: `1px solid #DDD`,
          }}
        >
          {itm.firstName} ({itm.id})
        </div>
      )}
      onAdd={() => setData([...data, { id: "5", firstName: "Crimson" }])}
      onEdit={() => console.log("Edit Button Clicked")}
      onChange={(updatedData) => setData(updatedData)}
      onDelete={(payload, updatedData) => setData(updatedData)}
      canDragAndDrop
      // showDragHandle={false}
    />
  );
};

Default.story = {
  parameters: {
    jest: ["SortableList"],
  },
};
