## Spec for Editor Module Package

A flexible module for quickly building powerful, drag-and-drop editors like what you see in PowerPoint, Canva, or 10 Minute Pages. This module renders a canvas of web components, each wrapped with customizable handlers that take care of dragging, dropping, and content manipulation. Components are rendered based on a data array provided in the props with each item in the array mapping to a provided set of react components (e.g. headline, pictures, videos, etc.). Editor components are simply react components (provided by props or plugins) that render itself based on settings provided by the editor. Each editor component provides its own properties control, which is used to further customize itself. The module also provides common property building tools (e.g. sidebar, sections, sliders, typography, etc.) that can be leveraged for speed and visual consistency

## Table of Contents

- [Spec for Editor Module Package](#spec-for-editor-module-package)
- [Table of Contents](#table-of-contents)
- [Workflow](#workflow)
- [User Stories](#user-stories)
- [Test Plan](#test-plan)
- [Acceptance Tests](#acceptance-tests)
- [Screens / States](#screens--states)
- [Usage](#usage)
- [Components](#components)
  - [Layouts](#layouts)
  - [Containers](#containers)
  - [Components](#components-1)
- [Schema](#schema)
  - [Component Schema](#component-schema)
    - [Editor](#editor)
      - [Schema](#schema-1)
      - [Tests](#tests)
    - [LoadComponent](#loadcomponent)
      - [Schema](#schema-2)
      - [Tests](#tests-1)
    - [ComponentWrapper](#componentwrapper)
      - [Schema](#schema-3)
      - [Tests](#tests-2)
    - [EditorObject](#editorobject)
      - [Schema](#schema-4)
      - [Tests](#tests-3)
    - [RichEditor](#richeditor)
      - [Schema](#schema-5)
      - [Tests](#tests-4)
    - [InlineControls](#inlinecontrols)
      - [Schema](#schema-6)
      - [Tests](#tests-5)
    - [InlineControlButton](#inlinecontrolbutton)
      - [Schema](#schema-7)
      - [Tests](#tests-6)
    - [ItemLegend](#itemlegend)
      - [Schema](#schema-8)
      - [Tests](#tests-7)
    - [ComponentSelector](#componentselector)
      - [Schema](#schema-9)
      - [Tests](#tests-8)
  - [Database Schema](#database-schema)
  - [Store/Reducers](#storereducers)
  - [APIs/Hook Schema](#apishook-schema)

## Workflow

![]()

## User Stories

- As a user, I want to be able to select individual page elements (widgets) on the page
- As a user I want to be able to drag my objects around the page with pixel precision
- As a user I want to be able to drag my objects around the page and have them snap to (or inside) the other objects on the page
- As a user I would like to delete objects using my keyboard
- As a user I would like all elements fit to the width of parent container by default
- As a developer I would like to customize the various component wrappers (e.g. resize handle, toolbar, etc.)
- As a developer I would like to provide a list of components that the content array will use for displaying content
- As a developer I would like to hook in and override any of the events associated with the editor (e.g. update, delete, drag, move, etc.)
- As a developer I would like to configure the editor to be readOnly
- As a developer, I would like to configure the editor to not allow dragging or adding new items
- As a developer, I would like to pass in an array of content that links to a provided component that I want it to render
- As a developer I would like to turn on/off snap guides to aid in pixel-level edit control
- As a user I would like to easily undo or redo previous actions
- As a user I would like the ability to resize editor content

## Test Plan

| Scenario  | Expected                                                                                                                                         | Automated | Type       |
| --------- | ------------------------------------------------------------------------------------------------------------------------------------------------ | --------- | ---------- |
| Actions   | Should be able to drag new objects immediately above or below existing objects                                                                   | Yes       | End To End |
| Actions   | Should be able to drag existing objects immediately above or below existing objects                                                              | Yes       | End To End |
| Actions   | Should be able to drag objects inside of existing object containers                                                                              | Yes       | End To End |
| Actions   | Should be able to select an object and make it active                                                                                            | Yes       | End To End |
| Actions   | Should be able to see objects highlight when I hover over them                                                                                   | Yes       | End To End |
| Actions   | Should be able to open an objects property (if provided) when I double click on it                                                               | Yes       | End To End |
| Actions   | Should be able to remove items via [delete] on my keyboard                                                                                       | Yes       | End To End |
| Actions   | Should be able to remove items through an action item in the editor object action menu                                                           | Yes       | End To End |
| Actions   | Should be able to duplicate an item through an action item in the editor object action menu                                                      | Yes       | End To End |
| Actions   | Should be able to duplicate an item by pressing [CTRL/CMD] + [D] on my keyboard                                                                  | Yes       | End To End |
| Actions   | Should be able to replace the content in the editor through the updateContent method                                                             | Yes       | End To End |
| Actions   | Should be able to change the style properties of an item in the editor through the updateComponentStyle method                                   | Yes       | End To End |
| Actions   | Should be able to update anything about an item through the updateComponentSettings method                                                       | Yes       | End To End |
| Actions   | Should be able to make an object the main active object by clicking on it                                                                        | Yes       | End To End |
| Actions   | Should be able to undo one or more changes I make to the editor                                                                                  | Yes       | End To End |
| Actions   | Should be able to reverse an undo decision via a redo button                                                                                     | Yes       | End To End |
| Rendering | Should show editor in the dom                                                                                                                    | Yes       | End To End |
| Rendering | Should show the same number of items in the dom as there are items in the content prop                                                           | Yes       | End To End |
| Rendering | Should show items in the dom as specifie in the content prop and match components found in the components prop                                   | Yes       | End To End |
| Rendering | Should not be able to add new items if canAddItems prop is false                                                                                 | Yes       | End To End |
| Rendering | Should not be able to drag items if canDrag prop is false                                                                                        | Yes       | End To End |
| Rendering | Should be able to move items one pixel at a time if dragMode prop is set to PIXELBYPIXEL                                                         | Yes       | End To End |
| Rendering | Should only be able to move items above, beneath, and inside existing objects if dragMode prop is set to OBJECT                                  | Yes       | End To End |
| Rendering | Should only be able to drag section objects up and down if dragMode prop is set to BLOCK                                                         | Yes       | End To End |
| Rendering | Should show a snap guide if in PIXELBYPIXEL mode and dragging an object next to the vertical or horizontal cross-section of another object       | Yes       | End To End |
| Rendering | Should show a cursor when dragging items around in OBJECT mode                                                                                   | Yes       | End To End |
| Rendering | Should show a custom cursor component when one is provided in the cursorComponent prop                                                           | Yes       | End To End |
| Rendering | Should show a wrapper component around each object in the dom                                                                                    | Yes       | End To End |
| Rendering | Should show a custom wrapper component around each object when a custom component is provided in the editorObjectComponent prop                  | Yes       | End To End |
| Rendering | Should modify the editor object (e.g. colors, etc.) according to the editorObjectSettings prop                                                   | Yes       | End To End |
| Rendering | Should show a default drag handle component near each object when selected                                                                       | Yes       | End To End |
| Rendering | Should show a custom drag handle component near each object when selected and a custom component is provided in the dragHandleComponent prop     | Yes       | End To End |
| Rendering | Should modify the drag handle (e.g. colors, etc.) according to the dragHandleSettings prop                                                       | Yes       | End To End |
| Rendering | Should show a custom resize handler component for resizable editor objects when one is provided in the resizeHandleComponent prop                | Yes       | End To End |
| Rendering | Should modify the resize handler (e.g. colors, etc.) according to the resizeHandlerSettings prop                                                 | Yes       | End To End |
| Rendering | Should keep track of the changes that occur in the content prop via the undoStack prop                                                           | Yes       | End To End |
| Rendering | Should keep track of the current undo position in the undoPosition prop. Number decrements on undo actions, increments on redo.                  | Yes       | End To End |
| Rendering | Should not allow any changes of any kind when the readOnly prop is set to true                                                                   | Yes       | End To End |
| Rendering | Should show editor component in a zoomed state the corresponds with the number in the zoom prop                                                  | Yes       | End To End |
| Rendering | Should show an item legend if the itemLegendIsVisible prop is true                                                                               | Yes       | End To End |
| Rendering | Props in the item legend should match the object provided in the itemLegendSettings prop                                                         | Yes       | End To End |
| Rendering | Should show the component provided in the itemLegendComponent prop instead of the default one if one is provided                                 | Yes       | End To End |
| Methods   | Should trigger the addThisAfterThat() method when an item is to be added to the editor                                                           | Yes       | End To End |
| Methods   | Should trigger the removeItem() method when an item should be removed from the content array                                                     | Yes       | End To End |
| Methods   | Should trigger the duplicateItem() method when an item should be duplicated                                                                      | Yes       | End To End |
| Methods   | Should trigger the moveThisByThat() method when an item should be moved to another location                                                      | Yes       | End To End |
| Methods   | Should trigger the updateContent() method when the editor's content should be updated                                                            | Yes       | End To End |
| Methods   | Should trigger the updateComponentStyle() method when an items style should be changed                                                           | Yes       | End To End |
| Methods   | Should trigger the updateComponentSettings() method when something should change about an item                                                   | Yes       | End To End |
| Methods   | Should trigger the setActiveObject() method when an item's state should be active                                                                | Yes       | End To End |
| Methods   | Should trigger the doUndoRedo() method when the editor's content needs to return to a previous state                                             | Yes       | End To End |
| Methods   | Should trigger the chagneState() method when the item's state should change                                                                      | Yes       | End To End |
| Methods   | Should be able to enable or disable the editors canDrag property from anywhere in the editor                                                     | Yes       | End To End |
| Methods   | Should be able to retrieve a list of all the direct ancestors to a provided editor item from anywhere inside the editor                          | Yes       | End To End |
| Methods   | Should be able to retrieve a list of the items (and a useful icon) in the editor using the listComponents method from anywhere inside the editor | Yes       | End To End |
| Events    | Should trigger onAdd() event with appropriate payload when a new item is added to the editor                                                     | Yes       | End To End |
| Events    | Should trigger onRemove() event with appropriate payload when an item is removed from the editor                                                 | Yes       | End To End |
| Events    | Should trigger onDuplicate() event with appropriate payload when an item is duplicated in the editor                                             | Yes       | End To End |
| Events    | Should trigger onMove() event with appropriate payload when an item is moved in the editor                                                       | Yes       | End To End |
| Events    | Should trigger onStateChange() event with appropriate payload when the state of an item changes in the editor                                    | Yes       | End To End |
| Events    | Should trigger onChange() event with appropriate payload when an item in the editor changes in some way                                          | Yes       | End To End |
| Events    | Should trigger onKeyUp() event with appropriate payload when a key is pressed in the editor                                                      | Yes       | End To End |
| Events    | Should trigger onSelect() event with appropriate payload when an item is selected in the editor                                                  | Yes       | End To End |
| Events    | Should trigger onUndo() event with appropriate payload when an undo action is supposed to happen                                                 | Yes       | End To End |
| Events    | Should trigger onRedo() event with appropriate payload when redo action is supposed to happen                                                    | Yes       | End To End |
| Hooks     | Should trigger _onAddItem_ hook when a new item is added to the editor                                                                           | Yes       | End To End |
| Hooks     | Should trigger _onRemoveItem_ hook when an item is removed from the editor                                                                       | Yes       | End To End |
| Hooks     | Should trigger _onDuplicateItem_ hook when an item is duplicated in the editor                                                                   | Yes       | End To End |
| Hooks     | Should trigger _onMoveItem_ hook when an item is duplicated in the editor                                                                        | Yes       | End To End |
| Hooks     | Should trigger _onResizeItem_ hook when an item is resizing in the editor                                                                        | Yes       | End To End |
| Hooks     | Should trigger _onResizeItemEnd_ hook when an item is done resizing itself                                                                       | Yes       | End To End |
| Hooks     | Should trigger _onItemStateChange_ hook when the state of an item changes in the editor                                                          | Yes       | End To End |
| Hooks     | Should trigger _onChange_ hook when an item in the editor changes in some way                                                                    | Yes       | End To End |
| Hooks     | Should trigger _onKeyUp_ hook when a key is pressed in the editor                                                                                | Yes       | End To End |
| Hooks     | Should trigger _onSelectItem_ hook when an item is selected in the editor                                                                        | Yes       | End To End |
| Hooks     | Should trigger _onUndo_ hook when an undo action is supposed to happen                                                                           | Yes       | End To End |
| Hooks     | Should trigger _onRedo_ hook when redo action is supposed to happen                                                                              | Yes       | End To End |
| Hooks     | Should trigger _onEditorRender_ hook when Editor is rendered                                                                                     | Yes       | End To End |
| Hooks     | Should trigger _onEditorObjectRender_ hook when Editor Object is rendered                                                                        | Yes       | End To End |
| Hooks     | Should trigger _onComponentLoaderRender_ hook when the Component Loader is rendered                                                              | Yes       | End To End |
| Hooks     | Should trigger _onWebComponentWrapperRender_ hook when componentWrapper is rendered                                                              | Yes       | End To End |

## Acceptance Tests

(N/A)

## Screens / States

![](http://ambid-backups.s3.amazonaws.com/screenshots/sandcastle/funnel_screen_simple.png)

## Usage

To install it...

> npm install @sandcastle/components

Add it to your project...

```
import * as React from 'react'
import * as Editor from '@sandcastle/components/Editor`

export default () => (
  <Editor
    name=""
    canAddItems=""
    canDrag=""
    dragMode={0}
    snapGuidesAreEnabled=""
    content=""
    components=""
    cursorComponent=""
    componentWrapperComponent=""
    editorObjectComponent=""
    editorObjectSettings=""
    dragHandleComponent=""
    dragHandleSettings=""
    resizeHandleComponent=""
    resizeHandleSettings=""
    itemLegendSettings=""
    itemLegendIsVisible=""
    itemLegendComponent={<div />}
    undoStack=""
    undoPosition=""
    readOnly=""
    zoom=""
    onAdd=""
    onRemove=""
    onDuplicate=""
    onMove=""
    onStateChange=""
    onChange=""
    onKeyUp=""
    onSelect=""
    onUndo=""
    onRedo=""
    content=""
  />
)
```

## Components

### Layouts

N/A

### Containers

| Type       | Name   | Description                                                                                                                       | Behaviors | Exists | Package |
| ---------- | ------ | --------------------------------------------------------------------------------------------------------------------------------- | --------- | ------ | ------- |
| Containers | Editor | A flexible module for quickly building powerful, drag-and-drop editors like what you see in PowerPoint, Canva, or 10 Minute Pages |           | No     | No      |

### Components

| Type       | Name             | Description                                                                                                                                                                                                                                                                                                   | Behaviors                                              | Exists | Package |
| ---------- | ---------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------ | ------ | ------- |
| Components | LoadComponent    | (Formerly WebComponent) The react component used to interpret each item in the editor.                                                                                                                                                                                                                        | Dynamically loads the appropriate editor widget plugin | No     | No      |
| Components | ComponentWrapper | The container that is wrapped around each component in the editor                                                                                                                                                                                                                                             |                                                        | No     | No      |
| Components | EditorObject     | This component makes child components compatible with the editor, enabling drag-and-drop, widget toolbars, etc. Each component in the editor should wrap itself with this component. It's the component that highlights the object in various ways to let the user know what they are editing at a given time |                                                        | No     | No      |
| Components | RichEditor       | A component for providing rich, wysiwyg text composition. A wrapper of the draft.js library                                                                                                                                                                                                                   |                                                        | No     | No      |
| Components | InlineControls   | The toolbar of <InlineControlButtons /> or Button Groups for controlling formatting, etc                                                                                                                                                                                                                      |                                                        | No     | No      |

## Schema

### Component Schema

#### Editor

##### Schema

| Schema Type | Name                      | Type                            | Description                                                                                                                                                                                                                                                                                                    |
| ----------- | ------------------------- | ------------------------------- | -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| prop        | name                      | string                          | The name to use for the Editor component. Useful for plugins that want to hook into your specific editor vs others                                                                                                                                                                                             |
| prop        | canAddItems               | bool                            | Whether or not the user is able to add new items to the editor                                                                                                                                                                                                                                                 |
| prop        | canDrag                   | bool                            | Whether or not dragging is enabled                                                                                                                                                                                                                                                                             |
| prop        | dragMode                  | enum(PIXELBYPIXEL,OBJECT,BLOCK) | The type of drag to perform (pixel-by-pixel, object snap, or blocks)                                                                                                                                                                                                                                           |
| prop        | snapGuidesAreEnabled      | bool                            | Whether or not snap guides are enabled while in pixel-by-pixel mode                                                                                                                                                                                                                                            |
| prop        | content                   | array                           | The content to use to populate the editor with objects                                                                                                                                                                                                                                                         |
| prop        | components                | array                           | The components that are available for rendering                                                                                                                                                                                                                                                                |
| prop        | cursorComponent           | React.ReactNode                 | The custom component to use for the cursor that shows while dragging                                                                                                                                                                                                                                           |
| prop        | componentWrapperComponent | React.ReactNode                 | A custom component that will wrap around each editor component                                                                                                                                                                                                                                                 |
| prop        | editorObjectComponent     | React.ReactNode                 | The custom component to use instead of the default editor object component                                                                                                                                                                                                                                     |
| prop        | editorObjectSettings      | any                             | For customizing the default editor object (e.g. colors, etc.)                                                                                                                                                                                                                                                  |
| prop        | dragHandleComponent       | React.ReactNode                 | The custom component to use instead of the default drag handle component                                                                                                                                                                                                                                       |
| prop        | dragHandleSettings        | any                             | For customizing the default drag handle (e.g. colors, etc.)                                                                                                                                                                                                                                                    |
| prop        | resizeHandleComponent     | React.ReactNode                 | The custom component to use for resize handles                                                                                                                                                                                                                                                                 |
| prop        | resizeHandleSettings      | any                             | For customizing the default resize handle (e.g. colors, etc.)                                                                                                                                                                                                                                                  |
| prop        | itemLegendSettings        | object                          | The props to use for the <ItemLegend /> component                                                                                                                                                                                                                                                              |
| prop        | itemLegendIsVisible       | bool                            | Whether or not the <ItemLegend /> component should render                                                                                                                                                                                                                                                      |
| prop        | itemLegendComponent       | element                         | Replaces the default <ItemLegend /> component                                                                                                                                                                                                                                                                  |
| prop        | undoStack                 | array                           | The current undo stack                                                                                                                                                                                                                                                                                         |
| prop        | undoPosition              | int                             | The current position in the undo stack                                                                                                                                                                                                                                                                         |
| prop        | readOnly                  | bool                            | Whether or not the editor is in read only mode                                                                                                                                                                                                                                                                 |
| prop        | zoom                      | float                           | The current zoom of the editor                                                                                                                                                                                                                                                                                 |
| prop        | onAdd                     | () => void                      | Triggers when a new item is added to the editor                                                                                                                                                                                                                                                                |
| prop        | onRemove                  | () => void                      | Triggers when an item is removed from the editor                                                                                                                                                                                                                                                               |
| prop        | onDuplicate               | () => void                      | Triggers when an item is duplicated in the editor                                                                                                                                                                                                                                                              |
| prop        | onMove                    | () => void                      | Triggers when an item is moved in the editor                                                                                                                                                                                                                                                                   |
| prop        | onStateChange             | () => void                      | Triggers when the state of an item changes in the editor                                                                                                                                                                                                                                                       |
| prop        | onChange                  | () => void                      | Triggers when an item in the editor changes in some way                                                                                                                                                                                                                                                        |
| prop        | onKeyUp                   | () => void                      | Triggers when a key is pressed in the editor ~ to handle delete requests, pixel nudging, etc.                                                                                                                                                                                                                  |
| prop        | onSelect                  | () => void                      | Triggers when an item is selected in the editor                                                                                                                                                                                                                                                                |
| prop        | onUndo                    | () => void                      | Triggers when an undo action is supposed to happen                                                                                                                                                                                                                                                             |
| prop        | onRedo                    | () => void                      | Triggers when redo action is supposed to happen                                                                                                                                                                                                                                                                |
| prop        | content                   | any[]                           | The current content (same as the one in the props) in the editor                                                                                                                                                                                                                                               |
| method      | addThisAfterThat          | () => void                      | Takes an object representing a new component and adds it immediately after an existing item in the content array                                                                                                                                                                                               |
| method      | removeItem                | () => void                      | Removes an item from the content array                                                                                                                                                                                                                                                                         |
| method      | duplicateItem             | () => void                      | Duplicates a specific item in the content array                                                                                                                                                                                                                                                                |
| method      | moveThisByThat            | () => void                      | Moves an item in the content array to another location in the content array                                                                                                                                                                                                                                    |
| method      | updateContent             | () => void                      | Updates the entire content array                                                                                                                                                                                                                                                                               |
| method      | updateComponentStyle      | () => void                      | Updates the properties object of an item in the content array                                                                                                                                                                                                                                                  |
| method      | updateComponentSettings   | () => void                      | Updates an item in the content array                                                                                                                                                                                                                                                                           |
| method      | setActiveObject           | () => void                      | Sets the provided object to be the active object                                                                                                                                                                                                                                                               |
| method      | doUndoRedo                | () => void                      | Triggers an undo or a redo command                                                                                                                                                                                                                                                                             |
| method      | changeState               | () => void                      | Sets the provided object's current state to something else                                                                                                                                                                                                                                                     |
| method      | resizeObject              | () => void                      | Updates the width and height of the provided object                                                                                                                                                                                                                                                            |
| method      | setCanDrag                | () => void                      | A global way to update the editor's canDrag property                                                                                                                                                                                                                                                           |
| method      | listAncestors             | () => void                      | Provides a list of all the direct ancestors to a provided editor item                                                                                                                                                                                                                                          |
| method      | listComponents            | () => void                      | Generates a list of the current items in the editor. Including an icon to use when display. Also will return a filtered list of components if you provide the filter in [key, value] format (e.g. ['type', 'Body'] for filtering out the main body or ['canHaveChildren', true] for filtering only containers) |

##### Tests

N/A

#### LoadComponent

##### Schema

| Schema Type | Name              | Type       | Description                                                                             |
| ----------- | ----------------- | ---------- | --------------------------------------------------------------------------------------- |
| prop        | mode              | enum       | enum(LIVE,EDITOR)                                                                       |
| prop        | type              | string     | The name of the component that should be loaded                                         |
| prop        | settings          | object     | The settings to pass along to the component                                             |
| prop        | [!]rSettings      | object     | Mobile responsive settings                                                              |
| prop        | isDragInProgress  | bool       | Whether or not the component is currently being dragged                                 |
| prop        | children          | component  |                                                                                         |
| globals     | itemCoordinates   | object     | The current top, right, bottom, left, width, height coordinates of the component        |
| globals     | parentCoordinates | object     | The current top, right, bottom, left, width, height coordinates of the parent component |
| globals     | settings          | object     | The current settings for the item                                                       |
| globals     | setIsEditing      | () => void | Sets the component in 'editing' mode                                                    |
| globals     | isEditing         | bool       | Whether or not the component is being edited                                            |

##### Tests

| It                                                                                                                                         | Type        |
| ------------------------------------------------------------------------------------------------------------------------------------------ | ----------- |
| Should render the component provided in the type prop                                                                                      | Integration |
| Should render the `LIVE` version of the component when the mode is set to `LIVE`                                                           | Integration |
| Should render the `EDITOR` version of the component when the mode is set to `EDITOR`                                                       | Integration |
| Component rendered should reflect the properties found in the settings prop                                                                | Integration |
| Should set isDragInProgress prop to true when in the middle of dragging                                                                    | Integration |
| Should see accurate values in itemCoordinates prop after the item's position changes                                                       | Integration |
| Should see accurate values in parentCoordinates prop after the item's position changes to be inside of a different parent container/column | Integration |
| Should be able to access itemCoordinates, settings, isEditing, setIsEditing, and parentCoordinates from any child component                | Integration |
| Should set the isEditing prop to true when the component is being edited                                                                   | Integration |

#### ComponentWrapper

##### Schema

| Schema Type | Name                | Type | Description                                                  |
| ----------- | ------------------- | ---- | ------------------------------------------------------------ |
| prop        | isShowingProperties | bool | Whether or not the component is currently showing properties |
| prop        | children            | bool |                                                              |

##### Tests

| It                                                                                   | Type        |
| ------------------------------------------------------------------------------------ | ----------- |
| Should render in dom as parent to the editor component                               | Integration |
| Should set the isShowingProperties prop to true when the properties are showing      | Integration |
| Should set the isShowingProperties prop to true when setIsEditing() method is called | Integration |

#### EditorObject

##### Schema

| Schema Type | Name                    | Type       | Description                                                                                                                                                                                                                                                                                                                     |
| ----------- | ----------------------- | ---------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| prop        | title                   | string     | The caption to title the editor object                                                                                                                                                                                                                                                                                          |
| prop        | icon                    | string     | The icon to use in the title                                                                                                                                                                                                                                                                                                    |
| prop        | color                   | string     | The color of the editor object borders                                                                                                                                                                                                                                                                                          |
| prop        | style                   | object     | The sytle to use for the editor object                                                                                                                                                                                                                                                                                          |
| prop        | resizeHandles           | array      | The resize handles that are enabled (e.g. [`SW`] or [`N`,`S`,`E`,`W`]                                                                                                                                                                                                                                                           |
| prop        | isResizable             | bool       | Whether or not the component is resizable                                                                                                                                                                                                                                                                                       |
| prop        | isEditing               | bool       | Whether or not the editor is in `editing` mode                                                                                                                                                                                                                                                                                  |
| prop        | overlay                 | bool       | Whether or not to place a transparent <div /> on the component in order to prevent the user from manipulating the component while editing. For example, videos. You likely don't want them to be able to play/pause videos while in the editor. This would place an overlay over the video so that users can't interact with it |
| prop        | actions                 | object     | An array of objects that represent the items in to show in the dropdown menu and associated actions to take (id, label, icon, onSelect) e.g. (Duplicate, Delete, Copy, Paste, Save)                                                                                                                                             |
| prop        | actionComponent         |            | Custom component to use instead of the default action component                                                                                                                                                                                                                                                                 |
| prop        | propertiesViewComponent |            | The component to use for the object's properties                                                                                                                                                                                                                                                                                |
| prop        | resizeHandlesComponent  |            | The component to use for the resize handles                                                                                                                                                                                                                                                                                     |
| prop        | dragHandleComponent     |            | The component to use for the drag handle                                                                                                                                                                                                                                                                                        |
| prop        | children                | component  |                                                                                                                                                                                                                                                                                                                                 |
| prop        | onResizing              | () => void | Triggers when a resize is supposed to take place                                                                                                                                                                                                                                                                                |
| prop        | onResizeEnd             | () => void | Triggers when a resize has ended                                                                                                                                                                                                                                                                                                |
| prop        | onDragStart             | () => void | Triggers when the editor object's drag handle has begun dragging                                                                                                                                                                                                                                                                |
| prop        | onClick                 | () => void | Triggers when the editor object is clicked                                                                                                                                                                                                                                                                                      |
| prop        | onContextMenu           | () => void | Triggers when the `right` mouse button is clicked                                                                                                                                                                                                                                                                               |

##### Tests

| It                                                                                                                                | Type        |
| --------------------------------------------------------------------------------------------------------------------------------- | ----------- |
| Should render the Editor Object component when called                                                                             | Integration |
| Should render in hover mode when state is hovered                                                                                 | Integration |
| Should render in active mode when state is active                                                                                 | Integration |
| Should show a caption in the editor object that reflects the title prop                                                           | Integration |
| Should show an icon if one is provided that reflects the icon prop                                                                | Integration |
| Should be styled according to the style prop if one is present                                                                    | Integration |
| Should render resize handles if isResizable prop is true                                                                          | Integration |
| Should render the `North` resize handle if resizeHandles prop has an `N` as an array item                                         | Integration |
| Should render the `North West` resize handle if resizeHandles prop has an `NW` as an array item                                   | Integration |
| Should render the `West` resize handle if resizeHandles prop has an `W` as an array item                                          | Integration |
| Should render the `South West` resize handle if resizeHandles prop has an `SW` as an array item                                   | Integration |
| Should render the `South` resize handle if resizeHandles prop has an `S` as an array item                                         | Integration |
| Should render the `South East` resize handle if resizeHandles prop has an `SE` as an array item                                   | Integration |
| Should render the `East` resize handle if resizeHandles prop has an `E` as an array item                                          | Integration |
| Should render the `North East` resize handle if resizeHandles prop has an `NE` as an array item                                   | Integration |
| Should render a transparent div component if overlay prop is true                                                                 | Integration |
| Should show an overlay prop across the entire editor object if one is showing                                                     | Integration |
| Should show a list of menu items in the actions drop down menu that reflect the items in the actions prop                         | Integration |
| Should show a custom drag handle component if provided in the dragHandleComponent prop                                            | Integration |
| Should show a custom resize handler component for resizable editor objects when one is provided in the resizeHandleComponent prop | Integration |
| Should trigger the onResize event with an appropriate payload when a resize is supposed to take place                             | Integration |
| Should trigger the onResizeEnd event with an appropriate payload when a resize has ended                                          | Integration |
| Shoudl trigger the onDragStart event when the editor object's drag handle has begun dragging                                      | Integration |
| Should trigger the onClick event when the editor object is clicked                                                                | Integration |
| Should delete the item if the [del] key is pressed (while not in edit mode)                                                       | Integration |
| Should exit editing mode if the [esc] key is pressed                                                                              | Integration |
| Should trigger the `onEditorObjectResize` plugin hook when the resize is taking place                                             | Integration |
| Should trigger the `onEditorObjectDragDrop` plugin hook when the editor object drag and drop is taking place                      | Integration |
| Should trigger the `onEditorObjectClick` plugin hook when the editor object is clicked                                            | Integration |
| Should trigger the `onEditorObjectContextMenu` plugin hook when the context menu is being showed                                  | Integration |
| Should trigger the `onEditorObjectRender` plugin hook when the editor object is being rendered                                    | Integration |
| Should trigger the `onEditorObjectResizeHandleRender` plugin hook when the editor object's resize handler is being rendered       | Integration |
| Should trigger the `onEditorObjectActionComponentRender` plugin hook when the editor object's action component is being rendered  | Integration |
| Should trigger the `onEditorObjectActionMenuList` plugin hook when the editor object's action menu list is being generated        | Integration |

#### RichEditor

##### Schema

| Schema Type | Name                    | Type       | Description                                                                                                                                                                                                                                                                         |
| ----------- | ----------------------- | ---------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| prop        | buttonList              | string[]   | The array of buttons you want to display (e.g. settings, duplicate, delete, color, upload, spacer, bold, italic, underline, textStyle, textAlign, textAlignLeft, textAlignRight, textAlignCenter, link, list, listBullet, listNumbers, objAlignLeft, objAlignRight, objAlignCenter) |
| prop        | onChange                | () => void | Triggers when a change is made in the rich editor                                                                                                                                                                                                                                   |
| prop        | onFocus                 | () => void | Triggers when the editor is focused on                                                                                                                                                                                                                                              |
| prop        | onBlur                  | () => void | Triggers when the editor loses focus                                                                                                                                                                                                                                                |
| prop        | onKeyCommand            | () => void | Triggers when a key is pressed while in the editor                                                                                                                                                                                                                                  |
| prop        | inlineControlsComponent | element    | Render this component instead of the default component when inline controls are to be shown                                                                                                                                                                                         |
| prop        | content                 | string     | The html content of the rich editor                                                                                                                                                                                                                                                 |
| prop        | onSelectText            | () => void | Triggers when text is selected in the editor                                                                                                                                                                                                                                        |
| prop        | disabled                | bool       | Whether or not the rich editor is disabled                                                                                                                                                                                                                                          |
| prop        | position                | enum       | The desired position of the inline style controls                                                                                                                                                                                                                                   |
| prop        | disableInlineControls   | bool       | Whether or not to display an inline control toolbar                                                                                                                                                                                                                                 |
| prop        | inlineControlsStyle     | object     | The style to use for the inline controls toolbar                                                                                                                                                                                                                                    |

##### Tests

| It                                                                                                                                     | Type        |
| -------------------------------------------------------------------------------------------------------------------------------------- | ----------- |
| Should render the RichEditor in the dom                                                                                                | Integration |
| Should render a collection of buttons that match the list provided in the buttonList prop                                              | Integration |
| Should show the inline control buttons in the location provided in the position prop                                                   | Integration |
| Should not render any inline controls if the disableInlineControls prop is true                                                        | Integration |
| Should style the inline controls according to the style provided in the inlineControlsStyle prop                                       | Integration |
| Should render the component provided in the inlineControlsComponent instead of the default component when one is provided in the props | Integration |
| Should show content inside the editor that matches the html content provided in the content prop                                       | Integration |
| Should disable the editor when the disabled prop is true                                                                               | Integration |
| Should trigger the onChange() event when a change is made in the rich editor                                                           | Integration |
| Should trigger the onFocus() event when the editor is focused on                                                                       | Integration |
| Should trigger the onBlur() event when the editor loses focus                                                                          | Integration |
| Should trigger the onKeyCommand() event when a key is pressed while in the editor                                                      | Integration |
| Should trigger the onSelectText() event when text is selected in the editor                                                            | Integration |
| Should trigger the `onRichEditorRender` plugin hook when the RichEditor component is rendering                                         | Integration |
| Should trigger the `onRichEditorFocus` plugin hook when the editor is focused on                                                       | Integration |
| Should trigger the `onRichEditorChange` plugin hook when a change is made in the rich editor                                           | Integration |
| Should trigger the `onRichEditorKeyCommand` plugin hook when a key is pressed while in the editor                                      | Integration |
| Should trigger the `onRichEditorSelectText` plugin hook when text is selected in the editor                                            | Integration |
| Should trigger the `onRichEditorBlur` plugin hook when the editor loses focus                                                          | Integration |

#### InlineControls

##### Schema

| Name         | Type   | Description                                                                                                                                                                                                                                                               |
| ------------ | ------ | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| isShowing    | bool   | Whether or not the inline controls are showing at the moment                                                                                                                                                                                                              |
| buttonList   | array  | An array of buttons to display (e.g. settings, duplicate, delete, color, upload, spacer, bold, italic, underline, textStyle, textAlign, textAlignLeft, textAlignRight, textAlignCenter, link, list, listBullet, listNumbers, objAlignLeft, objAlignRight, objAlignCenter) |
| position     | string | The current location of the inline popup (e.g. top, right, bottom, left, auto, [x,y] offset)                                                                                                                                                                              |
| currentStyle | any    | The current inline style of the editor (editorState.getCurrentInlineStyle())                                                                                                                                                                                              |

##### Tests

| It                                                                                             | Type        |
| ---------------------------------------------------------------------------------------------- | ----------- |
| Should not render any inline controls if the isShowing prop is false                           | Integration |
| Should render a collection of buttons that match the list provided in the buttonList prop      | Integration |
| Should show the inline control buttons in the location provided in the position prop           | Integration |
| Should triggers the `onlnlineControlsRender` plugin hook when the InlineControls are rendering | Integration |

#### InlineControlButton

##### Schema

| Name     | Type       | Description                                                                                                                                                                                                                                                                                      |
| -------- | ---------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------ |
| type     | string     | The button to show                                                                                                                                                                                                                                                                               |
| isActive | bool       | Whether or not the button should be `active` (e.g. if the highlight text is bold, and this button is the [bold] button, then active would be `true`)                                                                                                                                             |
| action   | string     | The type prop in upper case. Represents the constant that Draft.js uses to indicate the action to perform to the content editable element. For example if type is `bold`, action is `BOLD`, meaning the `BOLD` action will be triggered against the constant editable when the button is clicked |
| onToggle | () => void | Triggers when the button is clicked. Accepts a payload that represents the content editable function it should perform. Recommended action is to let it perform the draft.js onToggle event, which will perform the content editable function                                                    |

##### Tests

| It                                                                                                          | Type        |
| ----------------------------------------------------------------------------------------------------------- | ----------- |
| Should trigger the onToggle event when the button is clicked                                                | Integration |
| Should trigger a DraftJs contenteditable action that matches the `action` prop when the button is clicked   | Integration |
| Should trigger the `onInlineControlButtonRender` plugin hook when the InlineControlButton is being rendered | Integration |
| Should trigger the `onInlineControlButtonToggle` plugin hook when the inline control button is clicked      | Integration |
| Should render a `Settings` button in the dom when the type prop is `settings`                               | Integration |
| Should render a `Duplicate` button in the dom when the type prop is `duplicate`                             | Integration |
| Should render a `Delete` button in the dom when the type prop is `delete`                                   | Integration |
| Should render a `Close` button in the dom when the type prop is `close`                                     | Integration |
| Should render a `Color` button in the dom when the type prop is `color`                                     | Integration |
| Should render a `Upload` button in the dom when the type prop is `upload`                                   | Integration |
| Should render a `Spacer` button in the dom when the type prop is `spacer`                                   | Integration |
| Should render a `Bold` button in the dom when the type prop is `bold`                                       | Integration |
| Should render a `Italic` button in the dom when the type prop is `italic`                                   | Integration |
| Should render a `Underline` button in the dom when the type prop is `underline`                             | Integration |
| Should render a `TextStyle` button in the dom when the type prop is `textStyle`                             | Integration |
| Should render a `TextAlign` button in the dom when the type prop is `textAlign`                             | Integration |
| Should render a `TextAlignLeft` button in the dom when the type prop is `textAlignLeft`                     | Integration |
| Should render a `TextAlignRight` button in the dom when the type prop is `textAlignRight`                   | Integration |
| Should render a `TextAlignCenter` button in the dom when the type prop is `textAlignCenter`                 | Integration |
| Should render a `Link` button in the dom when the type prop is `link`                                       | Integration |
| Should render a `List` button in the dom when the type prop is `list`                                       | Integration |
| Should render a `ListBullet` button in the dom when the type prop is `listBullet`                           | Integration |
| Should render a `ListNumbers` button in the dom when the type prop is `listNumbers`                         | Integration |
| Should render a `ObjAlignLeft` button in the dom when the type prop is `objAlignLeft`                       | Integration |
| Should render a `ObjAlignRight` button in the dom when the type prop is `objAlignRight`                     | Integration |
| Should render a `ObjAlignCenter` button in the dom when the type prop is `objAlignCenter`                   | Integration |
| Should render a `ButtonAlignGroup` button in the dom when the type prop is `textAlignGroup`                 | Integration |
| Should render a `ButtonLinkGroup` button in the dom when the type prop is `linkGroup`                       | Integration |
| Should render a `ButtonColorGroup` button in the dom when the type prop is `colorGroup`                     | Integration |
| Should render a `ButtonFontGroup` button in the dom when the type prop is `fontGroup`                       | Integration |
| Should render a `Custom` button in the dom when the type prop is not recognized                             | Integration |

#### ItemLegend

##### Schema

| Schema Type | Name              | Type       | Description                                                                                                                                               |
| ----------- | ----------------- | ---------- | --------------------------------------------------------------------------------------------------------------------------------------------------------- |
| prop        | isCollapsed       | bool       | Whether or not the big legend is showing or not                                                                                                           |
| prop        | title             | string     | The title/caption that shows as the title of the item legend                                                                                              |
| prop        | tabs              | array      | { id, component, itemComponent, label, filterOut, filterOnly }                                                                                            |
| prop        | canReorder        | bool       | Whether or not re-ordering the items in the legend is enabled or not                                                                                      |
| prop        | showNesting       | bool       | Whether or not the list should show how the items are nested (e.g. should containers as uncollapsed, then show the objects inside the container indented) |
| prop        | showCloseButton   | bool       | Whether or not a close button is showing                                                                                                                  |
| prop        | onClose           | () => void | Triggers when the item legend is closed                                                                                                                   |
| prop        | onReorder         | () => void | Triggers when an item in the legend is re-ordered                                                                                                         |
| prop        | onItemSelect      | () => void | Triggers when an item in the legend is selected                                                                                                           |
| prop        | onItemDoubleClick | () => void | Triggers when an item in the legend is double clicked                                                                                                     |
| prop        | onItemChange      | () => void | Triggers when an item in the legend has changed                                                                                                           |
| prop        | onItemMouseEnter  | () => void | Triggers when the mouse enters an item in the legend                                                                                                      |
| prop        | onItemMouseLeave  | () => void | Triggers when the mouse leaves an item in the legend                                                                                                      |

##### Tests

| It                                                                                                     | Type        |
| ------------------------------------------------------------------------------------------------------ | ----------- |
| Should be able to see all my page objects and sections in a legend, where i can show/hide and re-order | Integration |
| Should (in addition to the editor) be able to reorder my page elements from a simple list              | Integration |
| Should (in addition to on the editor) be able to delete elements from a simple list                    | Integration |
| Should be able to access the page elements properties from the simple components list (double-click)   | Integration |
| Should be able to Double-click to change the name                                                      | Integration |

#### ComponentSelector

##### Schema

| Name       | Type       | Description                                                                                                                           |
| ---------- | ---------- | ------------------------------------------------------------------------------------------------------------------------------------- |
| filterOut  | array      | An array of components NOT to show. e.g. `filterOut={[[`type`,`Body`]]}`                                                              |
| filterOnly | array      | An array of components ONLY to show. e.g. `filterOnly={[[`canHaveChildren`, true]]}`. ^^ This is useful for showing only blocks, etc. |
| label      | string     | The label to show for the dropdown menu                                                                                               |
| onChange   | () => void | Triggers when an item is clicked                                                                                                      |

##### Tests

| It                                                                                                                                                                  | Type        |
| ------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ----------- |
| Should render the component in the dom                                                                                                                              | Integraiton |
| Should render a list of components extracted from the content of the page                                                                                           | Integraiton |
| Should filter out any items from the list of editor items based on the filterOut prop that matches the [key, value] pattern (e.g. ['type', 'Body'])                 | Integraiton |
| Should only show a list of editor items that match what's in the filterOnly prop where the filter matches the [key, value] pattern (e.g. ['canHaveChildren', true]) | Integraiton |
| Should show a placeholder in the dropdown menu that matches the provided label prop                                                                                 | Integraiton |
| Should highlight the actual page object when mouse hovers over the item                                                                                             | Integraiton |
| Should render an icon next to each item in the list                                                                                                                 | Integraiton |
| Should trigger the onChange() event when an item is clicked                                                                                                         | Integraiton |
| Should trigger the `onComponentSelectorMenuList` plugin hook when the list to show is being generated                                                               | Integraiton |
| Should trigger the `onComponentSelected` plugin hook when an item is selected                                                                                       | Integraiton |
| Should trigger the `onComponentSelectorRender` the ComponentSelector is rendering                                                                                   | Integraiton |

### Database Schema

### Store/Reducers

### APIs/Hook Schema
