export enum RichEditorPosition {
  TOP,
  BOTTOM,
  FIXED,
}

export interface RichEditorProps {
  /**
   * The array of buttons you want to display (e.g. settings, duplicate, delete, color, upload, spacer, bold, italic, underline, textStyle, textAlign, textAlignLeft, textAlignRight, textAlignCenter, link, list, listBullet, listNumbers, objAlignLeft, objAlignRight, objAlignCenter)
   */
  buttonList?: string[];

  /**
   * Triggers when a change is made in the rich editor
   */
  onChange?: () => void;

  /**
   * Triggers when the editor is focused on
   */
  onFocus?: () => void;

  /**
   * Triggers when the editor loses focus
   */
  onBlur?: () => void;

  /**
   * Triggers when a key is pressed while in the editor
   */
  onKeyCommand?: () => void;

  /**
   * Render this component instead of the default component when inline controls are to be shown
   */
  inlineControlsComponent?: React.ReactNode;

  /**
   * The html content of the rich editor
   */
  content?: string;

  /**
   * Triggers when text is selected in the editor
   */
  onSelectText?: () => void;

  /**
   * Whether or not the rich editor is disabled
   */
  disabled?: Boolean;

  /**
   * The desired position of the inline style controls
   */
  position?: RichEditorPosition;

  /**
   * Whether or not to display an inline control toolbar
   */
  disableInlineControls?: Boolean;

  /**
   * The style to use for the inline controls toolbar
   */
  inlineControlsStyle?: object;

  /**
   * TODO: May not need
   */
  children?: React.ReactNode;
}
