import * as React from "react";
import { AlphaPicker, CirclePicker, SliderPicker } from "react-color";
import { ColorPickerProps } from "./types";
/**
 * A collapsable color picker
 */
const style = {
  fieldset: {
    border: "1px solid #ccc",
    marginBottom: 20,
    padding: 20,
  },
  input: {
    backgroundColor: "transparent",
    border: "none",
    padding: 5,
    maxWidth: 100,
    outline: "none",
    margin: 10,
    color: "#FFF",
  },
  pickerElement: {
    width: 26,
    height: 26,
    display: "inline-block",
    top: 8,
    cursor: "pointer",
    position: "relative",
    border: "1px solid transparent",
    ":hover": {
      border: "1px solid white",
    },
  },
};

/**
 * A tool for picking and settings colors
 */
const ColorPicker: React.FC<ColorPickerProps> = ({
  toolTip,
  text,
  showCircles = true,
  showSlider = true,
  showAlpha,
  showHex = true,
  onChange,
  color,
  colorArray = [
    "#C0392B",
    "#E74C3C",
    "#9B59B6",
    "#8E44AD",
    "#2980B9",
    "#3498DB",
    "#1ABC9C",
    "#16A085",
    "#27AE60",
    "#2ECC71",
    "#F1C40F",
    "#F39C12",
    "#E67E22",
    "#D35400",
    "#ECF0F1",
    "#BDC3C7",
    "#95A5A6",
    "#34495E",
    "#2C3E50",
    "#FFFFFF",
    "#000000",
    "red",
    "green",
    "blue",
  ],
}) => {
  const [theColor, setColor] = React.useState(color);
  const [colorExpanded, setColorExpanded] = React.useState(true);

  const doChange = (color) => {
    setColor(color.hex);
    onChange(color);
  };

  const toggleColorExpansion = () => {
    setColorExpanded(!colorExpanded);
  };

  return (
    <fieldset data-testid="ColorPicker" style={style.fieldset} title={toolTip}>
      <legend>{text}</legend>
      {colorExpanded ? (
        <div style={{ padding: 0, marginBottom: 0 }}>
          {showCircles ? (
            <div data-testid="ColorPicker-Circles" style={{ marginBottom: 20 }}>
              <CirclePicker
                color={theColor}
                colors={colorArray}
                onChange={(c) => doChange(c)}
                onChangeComplete={(c) => doChange(c)}
              />
            </div>
          ) : null}
          {showSlider ? (
            <div data-testid="ColorPicker-Slider" style={{ marginBottom: 20 }}>
              <SliderPicker
                color={theColor}
                onChange={(c) => doChange(c)}
                onChangeComplete={(c) => doChange(c)}
              />
            </div>
          ) : null}
          {showAlpha ? (
            <div data-testid="ColorPicker-Alpha" style={{ marginBottom: 20 }}>
              <AlphaPicker
                onChange={(c) => doChange(c)}
                onChangeComplete={(c) => doChange(c)}
              />
            </div>
          ) : null}
        </div>
      ) : null}
      {showHex && (
        <div
          data-testid="ColorPicker-Hex"
          style={{
            backgroundColor: "#555",
            borderRadius: 4,
            padding: "0 10px",
          }}
        >
          <label style={{ color: "white" }}>{text}</label>
          <input
            data-testid="ColorPicker-color"
            value={theColor}
            onBlur={() => {
              doChange({ hex: theColor });
            }}
            type="text"
            style={{ ...style.input, backgroundColor: "#666" }}
          />

          <div
            style={{ ...style.pickerElement, backgroundColor: theColor }}
            onClick={toggleColorExpansion}
          />
        </div>
      )}
    </fieldset>
  );
};

export default ColorPicker;
