import * as React from "react";

interface ActionSelectorProps {
  /**
   * The name of the specific behavior that has to occur (e.g. _click_, _mouseEnter_, etc) before the selected action is triggered
   */
  behavior?: string;

  /**
   * Only actions that match this filter are available for selecting
   */
  filter?: string;

  /**
   * The label to use in the title/caption of the ActionSelector
   */
  label?: string;

  /**
   * The specific properties of this action
   */
  action?: object;

  /**
   * The index of this particular action if there are multiple actions to be triggered
   */
  myKey?: Number;

  /**
   * Triggers when an action is to be set for the object
   */
  onSetAction?: () => void;

  /**
   * Triggers when an action is to be deleted from the stack
   */
  onDeleteAction?: () => void;
}

/**
 * This component lets you customize a specific action.
 *
 * It renders a drop-down menu that will show the list of available actions that can be performed for the associated behavior
 *
 * When an action is selected, it may also show a sub selection of components to fine-tune the selection
 *
 * For example, if the action selected is [Go To a URL], a fine-tuning sub selection may ask [What URL?]
 */
const ActionSelector: React.FC<ActionSelectorProps> = ({ children }) => {
  return <div>{children}</div>;
};

export default ActionSelector;
