const { head, get, filter } = require("lodash");

const getDomainId = async (userId, context) => {
  // console.log({ userId })

  const user = await context.prisma.user({ id: userId });
  // console.log({ user })
  const domains = await context.prisma.user({ id: userId }).domains();
  const domainObj = head(filter(domains, domain => domain.name === `${user.subdomain}.tenminutefunnels.com`))
  const domainId = get(domainObj, 'id', false)

  return domainId;
}

const cloneObject = async (obj, campaignId, userId, context) => {

  const { name, screenshot, settings, type, x, y, deleted } = obj;
  const objUpdated = {
    name: `${name} (Copy)`,
    screenshot,
    settings,
    type,
    x: parseInt(x) + 50,
    y: parseInt(y) + 50,
    deleted
  };

  const page = {
    name: `${get(obj, 'page.name', 'Untitled Page')} (Copy)`,
    slug: `${get(obj, 'page.slug', 'untitled')}-${Math.random()
      .toString(36)
      .substr(2, 2)}`,
    type: get(obj, 'page.type', ''),
    theme: get(obj, 'page.theme', ''),
    screenshot: get(obj, 'page.screenshot', ''),
    content: get(obj, 'page.content', null),
    pageSettings: get(obj, 'page.pageSettings', null), // when doing campaign sharing, remove email/merchant settings before sharing
    user: { connect: { id: userId } }
  };

  // console.log({ page, objUpdated })

  const createPageResult = await context.prisma.createPage(page);

  const pageId = createPageResult.id;

  const variables = {
    ...objUpdated,
    campaign: { connect: { id: campaignId } },
    page: { connect: { id: pageId } }
  };

  return await context.prisma.createObject(variables);

}

const copyCampaignOnly = async (campaignDetails, domainId, userId, context) => {
  const { name, screenshot, type } = campaignDetails;
  const variables = {
    name: `${name} (Copy)`,
    screenshot,
    type,
    user: { connect: { id: userId } },
    domain: { connect: { id: domainId } },
    deleted: false
  }

  const createNewCampaign = await context.prisma.createCampaign(variables)
  return createNewCampaign
}

const linkObject = async (obj, hash, context) => {

  const { connectTo, name, deleted, screenshot } = obj;

  // console.log(connectTo)
  const connectToIdsOld = connectTo.map(itm => itm.id);
  const connectToIdsNew = connectToIdsOld.map(id => ({ id: hash[id].id }));
  const variables = {
    where: {
      id: hash[obj.id].id
    }, data: {
      connectTo: { connect: connectToIdsNew },
      screenshot,
      name,
      deleted
    }
  };

  // console.log({ variables });
  return await context.prisma.updateObject(variables);
}

module.exports = {
  Mutation: {
    cloneCampaign: async (_, args, context) => {
      const { id, userId } = args;


      // 1. grab the users default domain id
      const domainId = await getDomainId(userId, context)

      // 2. grab the campaign data  
      const campaignDetails = await context.prisma.campaign({ id })
      const objects = await context.prisma.campaign({ id }).objects()

      // 3. create a campaign using old campaign data
      const createNewCampaign = await copyCampaignOnly(campaignDetails, domainId, userId, context)
      const newCampaignId = createNewCampaign.id;
      // console.log({ objects, campaignDetails })

      // 4. clone each campaign object (but build a hash that maps the old obj id to the new obj id)
      let hash = [];
      for (const obj of objects) {
        const page = await context.prisma.object({ id: obj.id }).page()
        hash[obj.id] = await cloneObject({ ...obj, page }, newCampaignId, userId, context)
      }

      // console.log(hash)
      // 5. link each object together
      for (const obj of objects) {
        const connectTo = await context.prisma.object({ id: obj.id }).connectTo();
        await linkObject({ ...obj, connectTo }, hash, context)
      }

      // 6. return the campaign object
      const newCampaignDetails = await context.prisma.campaign({ id: newCampaignId })

      return {
        statusCode: 200,
        message: "New Campaign Created",
        response: newCampaignDetails,
      }

    },

    cloneObject: async (_, args, context) => {
      const { id, campaignId } = args;

      const obj = await context.prisma.object({ id });
      const page = await context.prisma.object({ id }).page();
      const user = await context.prisma.object({ id }).campaign().user()

      const userId = user.id;

      const newObjectDetails = await cloneObject({ ...obj, page }, campaignId, userId, context);

      return {
        statusCode: 200,
        message: "New Object Created",
        response: newObjectDetails,
      }
    }
  },
};
