const { prisma } = require("@sc/api/db/prisma/generated/prisma-client");

const resolvers = {
  Query: {
    users: async (_, args) => await prisma.users(args),
    user: async (_, args) => await prisma.user({ id: args.where.id }),

    campaigns: async (_, args) => await prisma.campaigns(args),
    campaign: async (_, args) => await prisma.campaign({ id: args.where.id }),

    objects: async (_, args) => await prisma.objects(args),
    object: async (_, args) => await prisma.object({ id: args.where.id }),

    domains: async (_, args) => await prisma.domains(args),
    domain: async (_, args) => await prisma.domain({ id: args.where.id }),

    integrations: async (_, args) => await prisma.integrations(args),
    integration: async (_, args) =>
      await prisma.integration({ id: args.where.id }),

    pages: async (_, args) => await prisma.pages(args),
    page: async (_, args) => await prisma.page({ id: args.where.id }),

    catalogItems: async (_, args) => await prisma.catalogItems(args),
    catalogItem: async (_, args) =>
      await prisma.catalogItem({ id: args.where.id }),

    mediaItems: async (_, args) => await prisma.mediaItems(args),
    mediaItem: async (_, args) => await prisma.mediaItem({ id: args.where.id }),

    apps: async (_, args) => await prisma.apps(args),
    app: async (_, args) => await prisma.app({ id: args.where.id }),
  },
  Mutation: {
    createUser: async (_, args) => await prisma.createUser(args.data),
    updateUser: async (_, args) => await prisma.updateUser(args),
    updateManyUsers: async (_, args) => await prisma.updateManyUsers(args),
    upsertUser: async (_, args) => await prisma.upsertUser(args),
    deleteUser: async (_, args) => await prisma.deleteUser(args.where),
    deleteManyUsers: async (_, args) => await prisma.deleteManyUsers(args),

    createDomain: async (_, args) => await prisma.createDomain(args.data),
    updateDomain: async (_, args) => await prisma.updateDomain(args),
    updateManyDomains: async (_, args) => await prisma.updateManyDomains(args),
    upsertDomain: async (_, args) => await prisma.upsertDomain(args),
    deleteDomain: async (_, args) => await prisma.deleteDomain(args.where),
    deleteManyDomains: async (_, args) => await prisma.deleteManyDomains(args),

    createIntegration: async (_, args) =>
      await prisma.createIntegration(args.data),
    updateIntegration: async (_, args) => await prisma.updateIntegration(args),
    updateManyIntegrations: async (_, args) =>
      await prisma.updateManyIntegrations(args),
    upsertIntegration: async (_, args) => await prisma.upsertIntegration(args),
    deleteIntegration: async (_, args) =>
      await prisma.deleteIntegration(args.where),
    deleteManyIntegrations: async (_, args) =>
      await prisma.deleteManyIntegrations(args),

    createPage: async (_, args) => await prisma.createPage(args.data),
    updatePage: async (_, args) => await prisma.updatePage(args),
    updateManyPages: async (_, args) => await prisma.updateManyPages(args),
    upsertPage: async (_, args) => await prisma.upsertPage(args),
    deletePage: async (_, args) => await prisma.deletePage(args.where),
    deleteManyPages: async (_, args) => await prisma.deleteManyPages(args),

    createCampaign: async (_, args) => await prisma.createCampaign(args.data),
    updateCampaign: async (_, args) => await prisma.updateCampaign(args),
    updateManyCampaigns: async (_, args) =>
      await prisma.updateManyCampaigns(args),
    upsertCampaign: async (_, args) => await prisma.upsertCampaign(args),
    deleteCampaign: async (_, args) => await prisma.deleteCampaign(args.where),
    deleteManyCampaigns: async (_, args) =>
      await prisma.deleteManyCampaigns(args),

    createObject: async (_, args) => await prisma.createObject(args.data),
    updateObject: async (_, args) => await prisma.updateObject(args),
    updateManyObjects: async (_, args) => await prisma.updateManyObjects(args),
    upsertObject: async (_, args) => await prisma.upsertObject(args),
    deleteObject: async (_, args) => await prisma.deleteObject(args.where),
    deleteManyObjects: async (_, args) => await prisma.deleteManyObjects(args),

    createCatalogItem: async (_, args) =>
      await prisma.createCatalogItem(args.data),
    updateCatalogItem: async (_, args) => await prisma.updateCatalogItem(args),
    updateManyCatalogItems: async (_, args) =>
      await prisma.updateManyCatalogItems(args),
    upsertCatalogItem: async (_, args) => await prisma.upsertCatalogItem(args),
    deleteCatalogItem: async (_, args) =>
      await prisma.deleteCatalogItem(args.where),
    deleteManyCatalogItems: async (_, args) =>
      await prisma.deleteManyCatalogItems(args),

    createMediaItem: async (_, args) => await prisma.createMediaItem(args.data),
    updateMediaItem: async (_, args) => await prisma.updateMediaItem(args),
    updateManyMediaItems: async (_, args) =>
      await prisma.updateManyMediaItems(args),
    upsertMediaItem: async (_, args) => await prisma.upsertMediaItem(args),
    deleteMediaItem: async (_, args) =>
      await prisma.deleteMediaItem(args.where),
    deleteManyMediaItems: async (_, args) =>
      await prisma.deleteManyMediaItems(args),

    createApp: async (_, args) => await prisma.createApp(args.data),
    updateApp: async (_, args) => await prisma.updateApp(args),
    updateManyApps: async (_, args) =>
      await prisma.updateManyApps(args),
    upsertApp: async (_, args) => await prisma.upsertApp(args),
    deleteApp: async (_, args) =>
      await prisma.deleteApp(args.where),
    deleteManyApps: async (_, args) =>
      await prisma.deleteAppItems(args)
  },
  User: {
    campaigns: async parent => await prisma.user({ id: parent.id }).campaigns(),
    domains: async parent => await prisma.user({ id: parent.id }).domains(),
    integrations: async parent =>
      await prisma.user({ id: parent.id }).integrations(),
    pages: async parent => await prisma.user({ id: parent.id }).pages(),
    catalogItems: async parent =>
      await prisma.user({ id: parent.id }).catalogItems(),
    mediaItems: async parent =>
      await prisma.user({ id: parent.id }).mediaItems(),
    apps: async parent => await prisma.user({ id: parent.id }).apps()
  },
  Campaign: {
    objects: async parent => await prisma.campaign({ id: parent.id }).objects(),
    user: async parent => await prisma.campaign({ id: parent.id }).user(),
    domain: async parent => await prisma.campaign({ id: parent.id }).domain(),
    catalogItem: async parent =>
      await prisma.campaign({ id: parent.id }).catalogItem(),
    mediaItems: async parent =>
      await prisma.campaign({ id: parent.id }).mediaItems()
  },
  Object: {
    campaign: async parent => await prisma.object({ id: parent.id }).campaign(),
    page: async parent => await prisma.object({ id: parent.id }).page(),
    connectTo: async parent =>
      await prisma.object({ id: parent.id }).connectTo()
  },
  Domain: {
    user: async parent => await prisma.domain({ id: parent.id }).user(),
    campaign: async parent => await prisma.domain({ id: parent.id }).campaign(),
    homePage: async parent => await prisma.domain({ id: parent.id }).homePage(),
    errorPage: async parent =>
      await prisma.domain({ id: parent.id }).errorPage()
  },
  Integration: {
    user: async parent => await prisma.integration({ id: parent.id }).user()
  },
  Page: {
    homePageForDomain: async parent =>
      await prisma.page({ id: parent.id }).homePageForDomain(),
    errorPageForDomain: async parent =>
      await prisma.page({ id: parent.id }).errorPageForDomain(),
    object: async parent => await prisma.page({ id: parent.id }).object(),
    user: async parent => await prisma.page({ id: parent.id }).user(),
    catalogItem: async parent =>
      await prisma.page({ id: parent.id }).catalogItem(),
    mediaItems: async parent =>
      await prisma.page({ id: parent.id }).mediaItems()
  },
  CatalogItem: {
    user: async parent => await prisma.catalogItem({ id: parent.id }).user(),
    campaign: async parent =>
      await prisma.catalogItem({ id: parent.id }).campaign(),
    page: async parent => await prisma.catalogItem({ id: parent.id }).page()
  },
  MediaItem: {
    user: async parent => await prisma.mediaItem({ id: parent.id }).user(),
    campaign: async parent =>
      await prisma.mediaItem({ id: parent.id }).campaign(),
    page: async parent => await prisma.mediaItem({ id: parent.id }).page()
  },
  App: {
    users: async parent => await prisma.app({ id: parent.id }).users(),
  }
};

exports.resolvers = resolvers;
``