require("dotenv").config();

const fs = require("fs");
const clear = require("clear");
const chalk = require("chalk");
const figlet = require("figlet");

var redis = require("redis"); // 1
var client = redis.createClient(); // 2

const express = require("express");
const bodyParser = require("body-parser");

const { prisma } = require("@sc/api/db/prisma/generated/prisma-client");
const { GraphQLServer } = require("graphql-yoga");

const { AuthenticationError } = require("apollo-server-core");

const { resolvers, typeDefs } = require("./server");
const { curPath } = require("./utils");

// const authenticate = async (resolve, root, args, context, info) => {
//   let token;

//   try {
//     const authHeader = context.request.headers.authorization;
//     token = authHeader.split("Bearer ")[1]
//     console.log("A command took place", token)
//     // if (!token) return new AuthenticationError("You are not authorized to use this API")
//   } catch (e) {
//     return new AuthenticationError("You are not authorized to use this API")
//   }
//   const result = await resolve(root, args, context, info);
//   return result;
// }

const server = new GraphQLServer({
  typeDefs,
  resolvers,
  context: { prisma },
  // context: req => ({ ...req }),
  // middlewares: [authenticate]
});

const options = {
  https: {
    // key: fs.readFileSync(`${curPath}.ssl/privatekey.pem`),
    // cert: fs.readFileSync(`${curPath}.ssl/certificate.pem`)
    key: `/etc/letsencrypt/live/api.funnels.cc/privkey.pem`,
    cert: `/etc/letsencrypt/live/api.funnels.cc/fullchain.pem`
  }
};

server.express.use(bodyParser.json({ limit: "10mb" }));

server.start(options => {
  clear();

  console.log(
    chalk.blue(
      figlet.textSync("Sandcastle", {
        horizontalLayout: "full",
        font: "Slant"
      })
    )
  );

  console.log(
    `  
    
              🚀    The Sandcastle (GraphQL) API server is 
                    running on http://${process.env.SERVER_ENDPOINT}:4000
              

              Navigate there to access the GraphiQL Playground

    `
  );

  // client.set("my_key", "Hello World using Node.js and Redis"); // 3
  // client.get("my_key", redis.print); // 4
  // client.quit(); // 5
});
