const { head, omit, template } = require("lodash");
const md5 = require("md5");
const jwt = require("jsonwebtoken");

const { Mutation } = require("../crm/sendEmail/resolvers");
const { sendEmail } = Mutation;

const secretKey = "A1234567a+";

module.exports = {
  Mutation: {
    resetPassword: async (_, args, context) => {
      const { id, password } = args;
      try {
        await context.prisma.updateUser({
          where: { id },
          data: { password: md5(password) }
        });

        return {
          statusCode: 200,
          message: "Your password was updated"
        };
      } catch (err) {
        return {
          statusCode: 400,
          message: "Something went wrong.  The password was not updated"
        };
      }
    },
    sendResetPasswordEmail: async (_, args, context) => {
      // send an email that resets the password
      const { to, from, subject, text, html } = args;
      const userInfo = await context.prisma.users({ where: { email: to } });

      if (!userInfo.length)
        return {
          statusCode: 400,
          message: "Sorry, we could not find a user with that email address"
        };

      // generate token
      const token = jwt.sign({ data: to }, secretKey, { expiresIn: "20m" });

      const { name } = head(userInfo);
      // send reset email
      const compiledSubject = template(subject);
      const subjectWithToken = compiledSubject({ token, name });

      const compiledText = template(text);
      const textWithToken = compiledText({ token, name });

      const compiledHtml = template(html);
      const htmlWithToken = compiledHtml({ token, name });

      await sendEmail(_, {
        to,
        from,
        subject: subjectWithToken,
        text: textWithToken,
        html: htmlWithToken
      });

      return {
        statusCode: 200,
        message: "Your password reset instructions have been sent."
      };
    },
  },
  Query: {
    verifyToken: async (_, args, context) => {
      const { token } = args;
      try {
        const decodedToken = jwt.verify(token, secretKey);
        const { data } = decodedToken;
        const response = await context.prisma.users({ where: { email: data } });
        const user = head(response);

        return {
          statusCode: 200,
          message: "Your token was verified",
          response: { ...omit(user, "password") }
        };
      } catch (err) {
        return {
          statusCode: 400,
          message: "Your token is invalid or has expired"
        };
      }
    }
  }
};
