import * as React from "react";
import { get } from "lodash";
// import { Search, Lock } from "@material-ui/icons";

import { style } from "./style";
import { default as defaultData } from "./data.json";

import { doIShow, combineData } from "../../utils";
import theme from "../../theme";

import {
  Block,
  Section,
  Headline,
  Text,
  Container,
  Button,
  Grid,
  GridItem,
  List,
  ListItem,
} from "@sc/plugins/webcomponents/v2";
import { Icon, IconTypes } from "@sc/plugins/webcomponents/v2/Icon";

type LayoutProps = {
  data: any;
};

const Layout: React.FC<LayoutProps> = ({ data }) => {
  const initialContent = {
    main_headline: {
      html: "Headline Goes Here",
    },
    sub_headline: {
      html: "Sub Headline Text Content Goes Here",
    },
  };

  const content = combineData(initialContent, defaultData, data);

  return (
    <Block>
      <Section style={style.SECTION}>
        <Grid>
          <GridItem xs={6}>
            <Container
              style={{ padding: 110, backgroundColor: theme.backgroundColor }}
            >
              {doIShow(content, "main_headline") && (
                <Headline
                  name="Main Headline"
                  id="main_headline"
                  style={{
                    ...style.HEADLINE,
                    ...get(content, "main_headline.style", {}),
                  }}
                >
                  {get(content, "main_headline.html", "...")}
                </Headline>
              )}
              {doIShow(content, "sub_headline") && (
                <Text
                  name="Sub Headline"
                  id="sub_headline"
                  style={{
                    ...style.TEXT,
                    ...get(content, "sub_headline.style", {}),
                  }}
                >
                  {get(content, "sub_headline.html", "...")}
                </Text>
              )}

              <List style={{ ...style.LIST, marginTop: 60 }}>
                <ListItem
                  style={{
                    ...style.LI,
                    color: theme.foregroundColor,
                  }}
                  iconStyle={{
                    borderRadius: "100%",
                    backgroundColor: theme.foregroundColor,
                    padding: 10,
                    color: theme.backgroundColor,
                  }}
                  contentStyle={{
                    padding: 12,
                  }}
                  icon={IconTypes.Search}
                >
                  Auto-find Tracker
                </ListItem>
                <ListItem
                  style={{
                    ...style.LI,
                    color: theme.foregroundColor,
                  }}
                  iconStyle={{
                    borderRadius: "100%",
                    backgroundColor: theme.foregroundColor,
                    padding: 10,
                    color: theme.backgroundColor,
                  }}
                  contentStyle={{
                    padding: 12,
                  }}
                  icon={IconTypes.Lock}
                >
                  Password system
                </ListItem>
              </List>
            </Container>
          </GridItem>
          <GridItem xs={6}></GridItem>
        </Grid>
      </Section>
    </Block>
  );
};

export default Layout;
