import * as React from "react";
import { get } from "lodash";

import { style } from "./style";
import { default as defaultData } from "./data.json";

import { doIShow, combineData } from "../../utils";
import theme from "../../theme";

import {
  Block,
  Section,
  Headline,
  Text,
  Container,
  Grid,
  GridItem,
  List,
  ListItem,
} from "@sc/plugins/webcomponents/v2";

import { Icon, IconTypes } from "@sc/plugins/webcomponents/v2/Icon";

import {
  ImagePlaceholder,
  VideoPlaceholder,
  ImagePlaceholderTypes,
} from "../../Placeholders";

type LayoutProps = {
  data: any;
};

const Layout: React.FC<LayoutProps> = ({ data }) => {
  const initialContent = {
    main_headline: {
      html: "Headline Goes Here",
    },
    sub_headline: {
      html: "Sub Headline Text Content Goes Here",
    },
  };

  const content = combineData(initialContent, defaultData, data);

  return (
    <Block>
      <Section style={style.SECTION}>
        <Container
          style={{
            ...style.SECTION_INNER,
            maxWidth: get(data, "section.pageMargin"),
          }}
        >
          <Grid>
            <GridItem xs={6}>
              <ImagePlaceholder
                type={ImagePlaceholderTypes.NONE}
                style={{
                  height: "100%",
                  backgroundColor: theme.foregroundColor,
                }}
              />
            </GridItem>
            <GridItem xs={6}>
              <Container style={{ padding: 100 }}>
                {doIShow(content, "main_headline") && (
                  <Headline
                    name="Main Headline"
                    id="main_headline"
                    style={{
                      ...style.HEADLINE,
                      ...get(content, "main_headline.style", {}),
                    }}
                  >
                    {get(content, "main_headline.html", "...")}
                  </Headline>
                )}

                <List style={style.LIST}>
                  <ListItem
                    icon={IconTypes.CheckCircleOutline}
                    iconStyle={style.LI.iconStyle}
                    style={style.LI.style}
                  >
                    <Text
                      style={{
                        ...style.HEADLINE,
                        fontSize: "16pt",
                        padding: 0,
                      }}
                    >
                      Feature
                    </Text>
                    <Text
                      style={{
                        ...style.TEXT,
                        fontSize: "11pt",
                        padding: 0,
                      }}
                    >
                      It's true. Getting results is much easier than you think.
                      The truth is
                    </Text>
                  </ListItem>
                  <ListItem
                    icon={IconTypes.CheckCircleOutline}
                    iconStyle={style.LI.iconStyle}
                    style={style.LI.style}
                  >
                    <Text
                      style={{
                        ...style.HEADLINE,
                        fontSize: "16pt",
                        padding: 0,
                      }}
                    >
                      Feature
                    </Text>
                    <Text
                      style={{
                        ...style.TEXT,
                        fontSize: "11pt",
                        padding: 0,
                      }}
                    >
                      It's true. Getting results is much easier than you think.
                      The truth is
                    </Text>
                  </ListItem>
                </List>
              </Container>
            </GridItem>
          </Grid>
        </Container>
      </Section>
    </Block>
  );
};

export default Layout;
