import * as React from "react";
import { get } from "lodash";
import { Email, AttachFile } from "@material-ui/icons";

import { style } from "./style";
import { default as defaultData } from "./data.json";

import { doIShow, combineData } from "../../utils";
import theme from "../../theme";

import {
  Block,
  Section,
  Headline,
  Text,
  Container,
  Button,
  Grid,
  GridItem,
  Icon,
} from "@sc/plugins/webcomponents/v2";
import { IconTypes } from "@sc/plugins/webcomponents/v2/Icon";

type LayoutProps = {
  data: any;
};

const Layout: React.FC<LayoutProps> = ({ data }) => {
  const initialContent = {
    main_headline: {
      html: "Headline Goes Here",
    },
    sub_headline: {
      html: "Sub Headline Text Content Goes Here",
    },
  };

  const content = combineData(initialContent, defaultData, data);

  return (
    <Block>
      <Section style={style.SECTION}>
        <Container style={style.SECTION_INNER}>
          <Grid spacing={10}>
            <GridItem xs={6}>
              <Icon type={IconTypes.Email} style={style.ICON} />
              <Headline
                name="Main Headline"
                id="main_headline"
                style={{
                  ...style.HEADLINE,
                  ...get(content, "main_headline.style", {}),
                }}
              >
                {get(content, "main_headline.html", "...")}
              </Headline>
              <Text
                name="Sub Headline"
                id="sub_headline"
                style={{
                  ...style.TEXT,
                  ...get(content, "sub_headline.style", {}),
                }}
              >
                {get(content, "sub_headline.html", "...")}
              </Text>
              <Button
                style={style.BUTTON.style}
                caption1="Get Started"
                caption1style={style.BUTTON.caption1}
              />
            </GridItem>
            <GridItem xs={6}>
              <Icon type={IconTypes.AttachFile} style={style.ICON} />
              <Headline
                name="Main Headline"
                id="main_headline"
                style={{
                  ...style.HEADLINE,
                  ...get(content, "main_headline.style", {}),
                }}
              >
                {get(content, "main_headline.html", "...")}
              </Headline>
              <Text
                name="Sub Headline"
                id="sub_headline"
                style={{
                  ...style.TEXT,
                  ...get(content, "sub_headline.style", {}),
                }}
              >
                {get(content, "sub_headline.html", "...")}
              </Text>
              <Button
                style={style.BUTTON.style}
                caption1="Get Started"
                caption1style={style.BUTTON.caption1}
              />
            </GridItem>
          </Grid>
        </Container>
      </Section>
    </Block>
  );
};

export default Layout;
