import * as React from "react";
import { get } from "lodash";

import { style } from "./style";
import { default as defaultData } from "./data.json";

import { doIShow, combineData } from "../../utils";
import theme from "../../theme";

import {
  Block,
  Section,
  Headline,
  Text,
  Container,
  Button,
  Grid,
  GridItem,
  List,
  ListItem,
} from "@sc/plugins/webcomponents/v2";
import { Icon, IconTypes } from "@sc/plugins/webcomponents/v2/Icon";
import { ListItemTypes } from "@sc/plugins/webcomponents/v2/ListItem/types";
import { ImagePlaceholder, ImagePlaceholderTypes } from "../../Placeholders";

type LayoutProps = {
  data: any;
};

const Layout: React.FC<LayoutProps> = ({ data }) => {
  const initialContent = {
    main_headline: {
      html: "Headline Goes Here",
    },
    sub_headline: {
      html: "Sub Headline Text Content Goes Here",
    },
  };

  const content = combineData(initialContent, defaultData, data);

  return (
    <Block>
      <Section style={style.SECTION}>
        <Container
          style={{
            ...style.SECTION_INNER,
            maxWidth: get(data, "section.pageMargin"),
          }}
        >
          <Grid>
            <GridItem xs={4}>
              <Container style={{ padding: 80 }}>
                <List style={style.LIST}>
                  <ListItem
                    icon={IconTypes.Chat}
                    iconStyle={style.LI.iconStyle}
                    style={style.LI.style}
                    type={ListItemTypes.BLOCK}
                  >
                    <Text
                      style={{
                        ...style.HEADLINE,
                        fontSize: "18pt",
                        padding: 0,
                      }}
                    >
                      Proven Strategy
                    </Text>
                    <Text
                      style={{
                        ...style.TEXT,
                        fontSize: "11pt",
                        padding: 0,
                      }}
                    >
                      It's true. Getting results is much easier than you think.
                      The truth is
                    </Text>
                  </ListItem>
                  <ListItem
                    icon={IconTypes.Email}
                    iconStyle={style.LI.iconStyle}
                    style={style.LI.style}
                    type={ListItemTypes.BLOCK}
                  >
                    <Text
                      style={{
                        ...style.HEADLINE,
                        fontSize: "18pt",
                        padding: 0,
                      }}
                    >
                      Proven Strategy
                    </Text>
                    <Text
                      style={{
                        ...style.TEXT,
                        fontSize: "11pt",
                        padding: 0,
                      }}
                    >
                      It's true. Getting results is much easier than you think.
                      The truth is
                    </Text>
                  </ListItem>
                </List>
              </Container>
            </GridItem>
            <GridItem xs={8}>
              <ImagePlaceholder
                style={{
                  position: "relative",
                  top: "50%",
                  transform: "translateY(-50%)",
                  // maxWidth: 275,
                  margin: "0 auto",
                }}
                type={ImagePlaceholderTypes.DESKTOP02}
              />
            </GridItem>
          </Grid>
        </Container>
      </Section>
    </Block>
  );
};

export default Layout;
