import * as React from "react";
import { get } from "lodash";

import { style } from "./style";
import { default as defaultData } from "./data.json";

import { doIShow, combineData } from "../../utils";
import theme from "../../theme";

import {
  Block,
  Section,
  Headline,
  Text,
  Container,
  Button,
  Grid,
  GridItem,
  Repeater,
} from "@sc/plugins/webcomponents/v2";
import { ImagePlaceholder, ImagePlaceholderTypes } from "../../Placeholders";

type LayoutProps = {
  data: any;
};

const Layout: React.FC<LayoutProps> = ({ data }) => {
  const initialContent = {
    main_headline: {
      html: "Headline Goes Here",
    },
    sub_headline: {
      html: "Sub Headline Text Content Goes Here",
    },
  };

  const content = combineData(initialContent, defaultData, data);

  return (
    <Block>
      <Section style={style.SECTION}>
        <Container
          style={{
            ...style.SECTION_INNER,
            maxWidth: get(data, "section.pageMargin"),
          }}
        >
          <Grid>
            <GridItem xs={5}>
              <Container style={{ padding: 80 }}>
                {doIShow(content, "main_headline") && (
                  <Headline
                    name="Main Headline"
                    id="main_headline"
                    style={{
                      ...style.HEADLINE,
                      ...get(content, "main_headline.style", {}),
                    }}
                  >
                    {get(content, "main_headline.html", "...")}
                  </Headline>
                )}
                <Headline
                  name="Main Headline"
                  id="main_headline"
                  style={{
                    ...style.ITEM_HEADLINE,
                    ...get(content, "main_headline.style", {}),
                  }}
                >
                  New Features
                </Headline>
                <Text
                  name="Sub Headline"
                  id="sub_headline"
                  style={{
                    ...style.TEXT,
                    ...get(content, "sub_headline.style", {}),
                  }}
                >
                  {get(content, "sub_headline.html", "...")}
                </Text>
                <Headline
                  name="Main Headline"
                  id="main_headline"
                  style={{
                    ...style.ITEM_HEADLINE,
                    ...get(content, "main_headline.style", {}),
                  }}
                >
                  New Features
                </Headline>
                <Text
                  name="Sub Headline"
                  id="sub_headline"
                  style={{
                    ...style.TEXT,
                    ...get(content, "sub_headline.style", {}),
                  }}
                >
                  {get(content, "sub_headline.html", "...")}
                </Text>
              </Container>
            </GridItem>
            <GridItem xs={7}>
              <Container style={{ padding: 50 }}>
                <Grid>
                  <Repeater
                    data={[
                      { type: ImagePlaceholderTypes.MOBILE01 },
                      { type: ImagePlaceholderTypes.DESKTOP01 },
                      { type: ImagePlaceholderTypes.DESKTOP02 },
                      { type: ImagePlaceholderTypes.MOBILE02 },
                    ]}
                  >
                    {({ type }) => (
                      <GridItem xs={6}>
                        <ImagePlaceholder type={type} />
                      </GridItem>
                    )}
                  </Repeater>
                </Grid>
              </Container>
            </GridItem>
          </Grid>
        </Container>
      </Section>
    </Block>
  );
};

export default Layout;
