import * as React from "react";
import { get } from "lodash";

import { style } from "./style";
import { default as defaultData } from "./data.json";

import { doIShow, combineData } from "../../utils";
import theme from "../../theme";

import {
  Block,
  Section,
  Headline,
  Text,
  Container,
  List,
  ListItem,
  Grid,
  GridItem,
  Icon,
} from "@sc/plugins/webcomponents/v2";
import { IconTypes } from "@sc/plugins/webcomponents/v2/Icon";
import { ImagePlaceholder } from "../../Placeholders";

type LayoutProps = {
  data: any;
};

const Layout: React.FC<LayoutProps> = ({ data }) => {
  const initialContent = {
    main_headline: {
      html: "Headline Goes Here",
    },
    sub_headline: {
      html: "Sub Headline Text Content Goes Here",
    },
  };

  const content = combineData(initialContent, defaultData, data);

  return (
    <Block>
      <Section style={style.SECTION}>
        <Container
          style={{
            ...style.SECTION_INNER,
            maxWidth: get(data, "section.pageMargin"),
          }}
        >
          <Grid>
            <GridItem xs={6}>
              <Container style={{ padding: "55px 110px" }}>
                <List>
                  <ListItem style={{ ...style.LI }}>Fast reply</ListItem>
                  <ListItem style={{ ...style.LI, color: "black" }}>
                    Full Service
                  </ListItem>
                  <ListItem style={{ ...style.LI }}>Online Support</ListItem>
                  <ListItem style={{ ...style.LI }}>Free trial</ListItem>
                </List>
              </Container>
            </GridItem>
            <GridItem xs={6}>
              <Container style={{ padding: 110 }}>
                <Icon type={IconTypes.Settings} style={style.ICON} />
                {doIShow(content, "main_headline") && (
                  <Headline
                    name="Main Headline"
                    id="main_headline"
                    style={{
                      ...style.HEADLINE,
                      ...get(content, "main_headline.style", {}),
                    }}
                  >
                    {get(content, "main_headline.html", "...")}
                  </Headline>
                )}
                {doIShow(content, "sub_headline") && (
                  <Text
                    name="Sub Headline"
                    id="sub_headline"
                    style={{
                      ...style.TEXT,
                      ...get(content, "sub_headline.style", {}),
                    }}
                  >
                    {get(content, "sub_headline.html", "...")}
                  </Text>
                )}
              </Container>
            </GridItem>
          </Grid>
        </Container>
      </Section>
    </Block>
  );
};

export default Layout;
