import * as React from "react";
import { get } from "lodash";

import { style } from "./style";
import { default as defaultData } from "./data.json";

import { doIShow, combineData } from "../../utils";
import theme from "../../theme";

import {
  Block,
  Section,
  Headline,
  Text,
  Container,
  Button,
  Grid,
  GridItem,
} from "@sc/plugins/webcomponents/v2";

type LayoutProps = {
  data: any;
};

const Layout: React.FC<LayoutProps> = ({ data }) => {
  const initialContent = {
    main_headline: {
      html: "Headline Goes Here",
    },
    sub_headline: {
      html: "Sub Headline Text Content Goes Here",
    },
  };

  const content = combineData(initialContent, defaultData, data);

  return (
    <Block>
      <Section style={style.SECTION}>
        <Grid>
          <GridItem xs={6}>
            <Container
              style={{
                padding: 110,
                backgroundColor: theme.backgroundColor,
              }}
            >
              {doIShow(content, "main_headline") && (
                <Headline
                  name="Main Headline"
                  id="main_headline"
                  style={{
                    ...style.HEADLINE,
                    ...get(content, "main_headline.style", {}),
                  }}
                >
                  {get(content, "main_headline.html", "...")}
                </Headline>
              )}
              {doIShow(content, "sub_headline") && (
                <Text
                  name="Sub Headline"
                  id="sub_headline"
                  style={{
                    ...style.TEXT,
                    ...get(content, "sub_headline.style", {}),
                  }}
                >
                  {get(content, "sub_headline.html", "...")}
                </Text>
              )}
              {doIShow(content, "cta_button") && (
                <Button
                  style={style.BUTTON.style}
                  caption1="Get Started"
                  caption1style={style.BUTTON.caption1}
                />
              )}
            </Container>
          </GridItem>
          <GridItem xs={6}>
            <Container
              style={{
                padding: 110,
                backgroundColor: theme.foregroundColor,
              }}
            >
              {doIShow(content, "main_headline") && (
                <Headline
                  name="Main Headline"
                  id="main_headline"
                  style={{
                    ...style.HEADLINE,
                    color: "black",
                    ...get(content, "main_headline.style", {}),
                  }}
                >
                  {get(content, "main_headline.html", "...")}
                </Headline>
              )}
              {doIShow(content, "sub_headline") && (
                <Text
                  name="Sub Headline"
                  id="sub_headline"
                  style={{
                    ...style.TEXT,
                    color: "black",
                    ...get(content, "sub_headline.style", {}),
                  }}
                >
                  {get(content, "sub_headline.html", "...")}
                </Text>
              )}
              {doIShow(content, "cta_button") && (
                <Button
                  style={{
                    ...style.BUTTON.style,
                    backgroundColor: theme.backgroundColor,
                  }}
                  caption1="Get Started"
                  caption1style={{
                    ...style.BUTTON.caption1,
                    color: theme.foregroundColor,
                  }}
                />
              )}
            </Container>
          </GridItem>
        </Grid>
      </Section>
    </Block>
  );
};

export default Layout;
