import * as React from "react";
import { get } from "lodash";

import { style } from "./style";
import { default as defaultData } from "./data.json";

import { doIShow, combineData } from "../../utils";
import theme from "../../theme";

import {
  Block,
  Section,
  Headline,
  Text,
  Container,
  Button,
  Grid,
  GridItem,
} from "@sc/plugins/webcomponents/v2";
import { ImagePlaceholder, ImagePlaceholderTypes } from "../../Placeholders";

type LayoutProps = {
  data: any;
};

const Layout: React.FC<LayoutProps> = ({ data }) => {
  const initialContent = {
    main_headline: {
      html: "Headline Goes Here",
    },
    sub_headline: {
      html: "Sub Headline Text Content Goes Here",
    },
  };

  const content = combineData(initialContent, defaultData, data);

  return (
    <Block>
      <Section style={style.SECTION}>
        <Container
          style={{
            ...style.SECTION_INNER,
            maxWidth: get(data, "section.pageMargin"),
          }}
        >
          <Grid>
            <GridItem xs={6}>
              <Container style={{ padding: 100 }}>
                {doIShow(content, "main_headline") && (
                  <Headline
                    name="Main Headline"
                    id="main_headline"
                    style={{
                      ...style.HEADLINE,
                      ...get(content, "main_headline.style", {}),
                    }}
                  >
                    {get(content, "main_headline.html", "...")}
                  </Headline>
                )}
                {doIShow(content, "pre_headline") && (
                  <Text
                    name="Pre Headline"
                    id="pre_headline"
                    style={{
                      ...style.TEXT,
                      ...get(content, "pre_headline.style", {}),
                    }}
                  >
                    {get(content, "pre_headline.html", "...")}
                  </Text>
                )}
                {doIShow(content, "cta_button") && (
                  <Button
                    style={{
                      ...style.BUTTON.style,
                      maxWidth: 150,
                      marginTop: 40,
                      backgroundColor: "transparent",
                      border: `1px solid ${theme.backgroundColor}`,
                    }}
                    caption1="View"
                    caption1style={{
                      ...style.BUTTON.caption1,
                      color: theme.backgroundColor,
                    }}
                  />
                )}
              </Container>
            </GridItem>
            <GridItem xs={6}>
              <ImagePlaceholder
                type={ImagePlaceholderTypes.NONE}
                style={{
                  height: "100%",
                  backgroundColor: theme.backgroundColor,
                }}
              />
            </GridItem>
          </Grid>
        </Container>
      </Section>
    </Block>
  );
};

export default Layout;
