import * as React from "react";
import { get } from "lodash";

import { style } from "./style";
import { default as defaultData } from "./data.json";

import { doIShow, combineData } from "../../utils";

import theme from "../../theme";

import {
  Block,
  Section,
  Headline,
  Text,
  Container,
  Button,
  Countdown,
} from "@sc/plugins/webcomponents/v2";
import { CountDownTypes } from "@sc/plugins/webcomponents/v2/Countdown/types";

type LayoutProps = {
  data: any;
};

const Layout: React.FC<LayoutProps> = ({ data }) => {
  const initialContent = {
    main_headline: {
      html: "Headline Goes Here",
    },
    sub_headline: {
      html: "Sub Headline Text Content Goes Here",
    },
  };

  const content = combineData(initialContent, defaultData, data);

  return (
    <Block>
      <Section style={style.SECTION}>
        <Container
          style={{
            ...style.SECTION_INNER,
            // maxWidth: get(data, "section.pageMargin")
            maxWidth: 800,
          }}
        >
          <Headline style={style.HEADLINE}>
            Your Chance to Grab 10 Minute Funnels at HALF-PRICE Disappears In...
          </Headline>
          <Container style={{ textAlign: "center", padding: 40 }}>
            <Countdown
              countType={CountDownTypes.EVENT}
              eventDate={Date.now() + 2 * 24 * 60 * 60 * 1000}
              style={style.COUNTDOWN.style}
              dimensionStyle={style.COUNTDOWN.dimensionStyle}
              labelStyle={style.COUNTDOWN.labelStyle}
              numberStyle={style.COUNTDOWN.numberStyle}
              dividerStyle={style.COUNTDOWN.dividerStyle}
              showDivider={false}
              actions={{}}
            />
          </Container>
          <Button
            style={style.BUTTON.style}
            caption1="Click Here to Get Your Discount"
            caption1style={style.BUTTON.caption1}
            caption2="...and complete Your order!"
            caption2style={style.BUTTON.caption2}
          />
          <Text
            style={{
              ...style.TEXT,
              fontWeight: "bold" as "bold",
              color: theme.highlightColor,
              textAlign: "center",
            }}
          >
            ** This Discount Offer & All Bonuses <u>EXPIRES TONIGHT</u> At
            Midnight **
          </Text>
        </Container>
      </Section>
    </Block>
  );
};

export default Layout;
