import * as React from "react";
import { get } from "lodash";

import { style } from "./style";
import { default as defaultData } from "./data.json";

import { doIShow, combineData } from "../../utils";

import theme from "../../theme";

import {
  Block,
  Section,
  Headline,
  Text,
  Container,
  Button,
  Grid,
  GridItem,
  ListItem,
  List,
} from "@sc/plugins/webcomponents/v2";

type LayoutProps = {
  data: any;
};

const Layout: React.FC<LayoutProps> = ({ data }) => {
  const initialContent = {
    main_headline: {
      html: "Headline Goes Here",
    },
    sub_headline: {
      html: "Sub Headline Text Content Goes Here",
    },
  };

  const content = combineData(initialContent, defaultData, data);

  return (
    <Block>
      <Section style={style.SECTION}>
        <Container
          style={{
            ...style.SECTION_INNER,
            maxWidth: get(data, "section.pageMargin"),
          }}
        >
          <Grid spacing={2}>
            <GridItem xs={5}>
              <Headline style={style.HEADLINE}>
                Free report reveals how to get the most out of your ability to
                include actual images.
              </Headline>
            </GridItem>
            <GridItem xs={7}>
              <Text style={style.TEXT}>
                It's true. Getting results is much easier than you think. The
                truth is most people simply don't know the correct steps to take
                so they become frustrated and quit
              </Text>
              <Grid spacing={10}>
                <GridItem xs={6}>
                  <Headline style={{ ...style.HEADLINE, fontSize: "16pt" }}>
                    New Things
                  </Headline>
                  <List style={style.LIST}>
                    <ListItem style={style.LI}>Architecture</ListItem>
                    <ListItem style={style.LI}>Design</ListItem>
                    <ListItem style={style.LI}>Animation</ListItem>
                  </List>
                </GridItem>
                <GridItem xs={6}>
                  <Headline style={{ ...style.HEADLINE, fontSize: "16pt" }}>
                    New Things
                  </Headline>
                  <List style={style.LIST}>
                    <ListItem style={style.LI}>Architecture</ListItem>
                    <ListItem style={style.LI}>Design</ListItem>
                    <ListItem style={style.LI}>Animation</ListItem>
                  </List>
                </GridItem>
              </Grid>
            </GridItem>
          </Grid>
        </Container>
      </Section>
    </Block>
  );
};

export default Layout;
