import * as React from "react";
import { get } from "lodash";

import { style } from "./style";
import { default as defaultData } from "./data.json";

import { doIShow, combineData } from "../../utils";

import {
  Block,
  Section,
  Headline,
  Text,
  Container,
} from "@sc/plugins/webcomponents/v2";
import { default as Icon, IconTypes } from "@sc/plugins/webcomponents/v2/Icon";
import { VideoPlaceholder } from "../../Placeholders";

type LayoutProps = {
  data: any;
};

const Layout: React.FC<LayoutProps> = ({ data }) => {
  const initialContent = {
    main_headline: {
      html: "Headline Goes Here",
    },
    sub_headline: {
      html: "Sub Headline Text Content Goes Here",
    },
  };

  const content = combineData(initialContent, defaultData, data);

  return (
    <Block>
      <Section style={style.SECTION}>
        <Container
          style={{
            ...style.SECTION_INNER,
            maxWidth: get(data, "section.pageMargin"),
          }}
        >
          <Container
            style={{
              maxWidth: 500,
              margin: "0 auto",
            }}
          >
            {doIShow(content, "main_headline") && (
              <Headline
                name="Main Headline"
                id="main_headline"
                style={{
                  ...style.HEADLINE,
                  ...get(content, "main_headline.style", {}),
                }}
              >
                {get(content, "main_headline.html", "...")}
              </Headline>
            )}
            {doIShow(content, "sub_headline") && (
              <Text
                name="Sub Headline"
                id="sub_headline"
                style={{
                  ...style.TEXT,
                  ...get(content, "sub_headline.style", {}),
                }}
              >
                {get(content, "sub_headline.html", "...")}
              </Text>
            )}
          </Container>
        </Container>
      </Section>
    </Block>
  );
};

export default Layout;
