import { get, startCase, uniqueId } from "lodash";
import {
  ILayoutSettings,
  PageSectionCategory,
} from "@sc/plugins/misc/v2/blocks/weblayouts/types";
import { ComponentTypes } from "@sc/plugins/webcomponents/v2/types";
import { ContentLayouts } from "@sc/plugins/misc/v2/blocks/weblayouts/Content/types";
import { combineData, lorem } from "../../utils";
import { default as defaultData } from "./data.json";
import { style } from "./style";
import {
  getImagePlaceholder,
  ImagePlaceholderTypes,
  getVideoPlaceholder,
  VideoPlaceholderTypes,
} from "../../Placeholders";
import theme from "../../theme";
import { IconTypes } from "@sc/plugins/webcomponents/v2/Icon";

const content = combineData(defaultData);

const settings: ILayoutSettings = {
  label: ContentLayouts.ONE,
  layout: ContentLayouts.ONE,
  previewImage: "",
  default: {
    type: ComponentTypes.SECTION,
    label: PageSectionCategory.CONTENT,
    bodyOnly: true,
    canHaveChildren: false,
    properties: {
      ...style.SECTION,
      ...style.SECTION_INNER,
    },
    children: [
      {
        type: ComponentTypes.HEADLINE,
        canHaveChildren: false,
        properties: {
          ...style.HEADLINE,
        },
        html: "Headline Goes Here",
      },
      {
        type: ComponentTypes.COLUMNS,
        canHaveChildren: false,
        properties: {
          width: "100%",
          marginTop: 40,
        },
        children: [
          {
            type: ComponentTypes.COLUMN,
            canHaveChildren: true,
            preventDelete: true,
            md: parseInt((8 * 100) / 12),
            properties: { height: "100%", padding: 0, minHeight: 20 },
            children: [
              getVideoPlaceholder({
                type: VideoPlaceholderTypes.NONE,
                style: {
                  backgroundColor: theme.foregroundColor,
                  color: theme.backgroundColor,
                },
                playIconStyle: { color: theme.backgroundColor },
              }),
            ],
          },
          {
            type: ComponentTypes.COLUMN,
            canHaveChildren: true,
            preventDelete: true,
            md: parseInt((4 * 100) / 12),
            properties: { height: "100%", padding: 0, minHeight: 20 },
            children: [
              {
                type: ComponentTypes.CONTAINER,
                canHaveChildren: true,
                properties: {
                  border: `1px solid ${theme.foregroundColor}`,
                  borderRadius: 5,
                  padding: 5,
                },
                children: [
                  {
                    type: ComponentTypes.CONTAINER,
                    canHaveChildren: true,
                    properties: {
                      margin: "0 auto",
                      display: "inline-block",
                      mobile: {
                        desktop: {
                          marginTop: -20,
                          textAlign: "left",
                        },
                        smartphone: {
                          marginTop: 0,
                          textAlign: "center",
                        },
                      },
                      backgroundColor: theme.foregroundColor,
                      padding: 10,
                      width: 180,
                      height: "auto",
                    },
                    children: [
                      {
                        type: ComponentTypes.HEADLINE,
                        canHaveChildren: false,
                        properties: {
                          ...style.HEADLINE,
                          fontSize: "18pt",
                          color: theme.backgroundColor,
                        },
                        html: `Downloads`,
                      },
                    ],
                  },
                  {
                    type: ComponentTypes.LISTITEM,
                    canHaveChildren: false,
                    html: `<p style="font-size: 18pt"><strong>Value creation worksheet</strong></p><p>_</p><p style="font-size: 11pt; padding: 0">${lorem.generateParagraphs(
                      1
                    )}</p>`,
                    properties: style.TEXT,
                    icon: IconTypes.PictureAsPdf,
                    iconStyle: {
                      fontSize: "28pt",
                      padding: 15,
                      color: theme.foregroundColor,
                    },
                  },
                ],
              },
            ],
          },
        ],
      },
    ],
  },
};

export default settings;
