import * as React from "react";
import { get } from "lodash";
import {
  faFacebookF,
  faGoogle,
  faTwitter,
  faInstagram,
} from "@fortawesome/free-brands-svg-icons";

import { style } from "./style";
import { default as defaultData } from "./data.json";

import { doIShow, combineData } from "../../utils";

import theme from "../../theme";

import {
  Block,
  Section,
  Headline,
  Text,
  Container,
  Grid,
  GridItem,
  Image,
  Navigation,
} from "@sc/plugins/webcomponents/v2";
import {
  NavigationLayouts,
  ItemTypes,
} from "@sc/plugins/webcomponents/v2/Navigation/types";

import { IconSource } from "@sc/plugins/webcomponents/v2/Icon/types";

type LayoutProps = {
  data: any;
};

const Layout: React.FC<LayoutProps> = ({ data }) => {
  const initialContent = {
    main_headline: {
      html: "Headline Goes Here",
    },
    sub_headline: {
      html: "Sub Headline Text Content Goes Here",
    },
  };

  const content = combineData(initialContent, defaultData, data);

  return (
    <Block>
      <Section style={style.SECTION}>
        <Container
          style={{
            ...style.SECTION_INNER,
            maxWidth: get(data, "section.pageMargin"),
          }}
        >
          <Grid>
            <GridItem xs>
              <Container style={{ maxWidth: 800 }}>
                <Grid style={{}}>
                  <GridItem xs={3}>
                    <Container style={{ padding: "0 40px" }}>
                      <Navigation
                        layout={NavigationLayouts.FIVE}
                        linkStyle={style.NAVIGATION.linkStyle}
                        items={[
                          { caption: "About Us", href: "./#" },
                          { caption: "Contact Us", href: "./#" },
                          { caption: "Pricing", href: "./#" },
                          { caption: "FAQs", href: "./#" },
                        ]}
                      />
                    </Container>
                  </GridItem>
                  <GridItem xs={3}>
                    <Container style={{ padding: "0 40px" }}>
                      <Navigation
                        layout={NavigationLayouts.FIVE}
                        linkStyle={style.NAVIGATION.linkStyle}
                        items={[
                          { caption: "About Us", href: "./#" },
                          { caption: "Contact Us", href: "./#" },
                          { caption: "Pricing", href: "./#" },
                          { caption: "FAQs", href: "./#" },
                        ]}
                      />
                    </Container>
                  </GridItem>
                  <GridItem xs={3}>
                    <Container style={{ padding: "0 40px" }}>
                      <Navigation
                        layout={NavigationLayouts.FIVE}
                        linkStyle={style.NAVIGATION.linkStyle}
                        items={[
                          { caption: "About Us", href: "./#" },
                          { caption: "Contact Us", href: "./#" },
                          { caption: "Pricing", href: "./#" },
                          { caption: "FAQs", href: "./#" },
                        ]}
                      />
                    </Container>
                  </GridItem>
                  <GridItem xs={3}>
                    <Container style={{ padding: "0 40px" }}>
                      <Navigation
                        layout={NavigationLayouts.FIVE}
                        linkStyle={style.NAVIGATION.linkStyle}
                        items={[
                          { caption: "About Us", href: "./#" },
                          { caption: "Contact Us", href: "./#" },
                          { caption: "Pricing", href: "./#" },
                          { caption: "FAQs", href: "./#" },
                        ]}
                      />
                    </Container>
                  </GridItem>
                </Grid>
              </Container>
            </GridItem>
            <GridItem xs={2}>
              <Headline style={style.HEADLINE}>Follow us</Headline>
              <Navigation
                layout={NavigationLayouts.SIX}
                linkStyle={{
                  padding: "0px 10px",
                  display: "inline-block",
                  color: theme.backgroundColor,
                }}
                items={[
                  {
                    type: ItemTypes.LISTITEM,
                    icon: faTwitter,
                    iconSource: IconSource.FONTAWESOME,
                    href: "./#",
                  },
                  {
                    type: ItemTypes.LISTITEM,
                    icon: faFacebookF,
                    iconSource: IconSource.FONTAWESOME,
                    href: "./#",
                  },
                  {
                    type: ItemTypes.LISTITEM,
                    icon: faGoogle,
                    iconSource: IconSource.FONTAWESOME,
                    href: "./#",
                  },
                  {
                    type: ItemTypes.LISTITEM,
                    icon: faInstagram,
                    iconSource: IconSource.FONTAWESOME,
                    href: "./#",
                  },
                ]}
              />
            </GridItem>
          </Grid>
        </Container>
      </Section>
    </Block>
  );
};

export default Layout;
