import * as React from "react";
import { get } from "lodash";
import {
  faFacebookF,
  faGoogle,
  faTwitter,
  faInstagram,
} from "@fortawesome/free-brands-svg-icons";

import { style } from "./style";
import { default as defaultData } from "./data.json";

import { doIShow, combineData } from "../../utils";

import theme from "../../theme";

import {
  Block,
  Section,
  Headline,
  Text,
  Container,
  Grid,
  GridItem,
  Image,
  Navigation,
} from "@sc/plugins/webcomponents/v2";
import {
  NavigationLayouts,
  ItemTypes,
} from "@sc/plugins/webcomponents/v2/Navigation/types";

import { IconSource } from "@sc/plugins/webcomponents/v2/Icon/types";

type LayoutProps = {
  data: any;
};

const Layout: React.FC<LayoutProps> = ({ data }) => {
  const initialContent = {
    main_headline: {
      html: "Headline Goes Here",
    },
    sub_headline: {
      html: "Sub Headline Text Content Goes Here",
    },
  };

  const content = combineData(initialContent, defaultData, data);

  return (
    <Block>
      <Section style={style.SECTION}>
        <Container
          style={{
            ...style.SECTION_INNER,
            maxWidth: get(data, "section.pageMargin"),
          }}
        >
          <Grid style={{}}>
            <GridItem xs>
              <Container style={{ padding: "0 40px" }}>
                <Headline style={style.HEADLINE}>Information</Headline>
                <Navigation
                  layout={NavigationLayouts.FIVE}
                  linkStyle={style.NAVIGATION.linkStyle}
                  items={[
                    {
                      caption: "About Us",
                      href: "./#",
                      type: ItemTypes.TEXT,
                    },
                    {
                      caption: "Contact Us",
                      href: "./#",
                      type: ItemTypes.TEXT,
                    },
                    {
                      caption: "FAQs",
                      href: "./#",
                      type: ItemTypes.TEXT,
                    },
                  ]}
                />
              </Container>
            </GridItem>
            <GridItem xs>
              <Container style={{ padding: "0 40px" }}>
                <Headline style={style.HEADLINE}>About</Headline>
                <Navigation
                  layout={NavigationLayouts.FIVE}
                  linkStyle={style.NAVIGATION.linkStyle}
                  items={[
                    { caption: "About Us", href: "./#" },
                    { caption: "Contact Us", href: "./#" },
                    { caption: "FAQs", href: "./#" },
                  ]}
                />
              </Container>
            </GridItem>
            <GridItem xs>
              <Container style={{ padding: "0 40px" }}>
                <Headline style={style.HEADLINE}>Catalog</Headline>
                <Navigation
                  layout={NavigationLayouts.FIVE}
                  linkStyle={style.NAVIGATION.linkStyle}
                  items={[
                    { caption: "About Us", href: "./#" },
                    { caption: "Contact Us", href: "./#" },
                    { caption: "FAQs", href: "./#" },
                  ]}
                />
              </Container>
            </GridItem>
            <GridItem xs>
              <Container style={{ padding: "0 40px" }}>
                <Headline style={style.HEADLINE}>Catalog</Headline>
                <Navigation
                  layout={NavigationLayouts.FIVE}
                  linkStyle={style.NAVIGATION.linkStyle}
                  items={[
                    { caption: "About Us", href: "./#" },
                    { caption: "Contact Us", href: "./#" },
                    { caption: "FAQs", href: "./#" },
                  ]}
                />
              </Container>
            </GridItem>
            <GridItem xs>
              <Container style={{ padding: "0 40px" }}>
                <Headline style={style.HEADLINE}>Catalog</Headline>
                <Navigation
                  layout={NavigationLayouts.FIVE}
                  linkStyle={style.NAVIGATION.linkStyle}
                  items={[
                    { caption: "About Us", href: "./#" },
                    { caption: "Contact Us", href: "./#" },
                    { caption: "FAQs", href: "./#" },
                  ]}
                />
              </Container>
            </GridItem>
          </Grid>

          <Navigation
            style={{ marginTop: 60 }}
            layout={NavigationLayouts.SEVEN}
            linkStyle={{
              padding: "0px 10px",
              display: "inline-block",
              // color: theme.backgroundColor,
              color: "black",
              fontFamily: theme.fontFamily,
              fontSize: "9pt",
            }}
            items={[
              {
                type: ItemTypes.LISTITEM,
                icon: faTwitter,
                iconSource: IconSource.FONTAWESOME,
                href: "./#",
                column: 1,
              },
              {
                type: ItemTypes.LISTITEM,
                icon: faFacebookF,
                iconSource: IconSource.FONTAWESOME,
                href: "./#",
                column: 1,
              },
              {
                type: ItemTypes.LISTITEM,
                icon: faGoogle,
                iconSource: IconSource.FONTAWESOME,
                href: "./#",
                column: 1,
              },
              {
                type: ItemTypes.LISTITEM,
                icon: faInstagram,
                iconSource: IconSource.FONTAWESOME,
                href: "./#",
                column: 1,
              },
              {
                type: ItemTypes.TEXT,
                href: "./#",
                caption: "Privacy Policy",
                column: 2,
              },
              {
                type: ItemTypes.TEXT,
                href: "./#",
                caption: "Terms & Conditions",
                column: 2,
              },
              {
                type: ItemTypes.TEXT,
                href: "./#",
                caption: "Site map",
                column: 2,
              },
            ]}
          />
        </Container>
      </Section>
    </Block>
  );
};

export default Layout;
