import * as React from "react";
import { get } from "lodash";

import { style } from "./style";
import { default as defaultData } from "./data.json";

import { doIShow, combineData } from "../../utils";

import theme from "../../theme";

import {
  Block,
  Section,
  Headline,
  Text,
  Container,
  Grid,
  GridItem,
  Button,
  Navigation,
} from "@sc/plugins/webcomponents/v2";
import {
  NavigationLayouts,
  ItemTypes,
} from "@sc/plugins/webcomponents/v2/Navigation/types";

import { IconSource } from "@sc/plugins/webcomponents/v2/Icon/types";

type LayoutProps = {
  data: any;
};

const Layout: React.FC<LayoutProps> = ({ data }) => {
  const initialContent = {
    main_headline: {
      html: "Headline Goes Here",
    },
    sub_headline: {
      html: "Sub Headline Text Content Goes Here",
    },
  };

  const content = combineData(initialContent, defaultData, data);

  return (
    <Block>
      <Section style={style.SECTION}>
        <Container
          style={{
            ...style.SECTION_INNER,
            maxWidth: get(data, "section.pageMargin"),
          }}
        >
          <Grid>
            <GridItem xs={6}>
              <Container style={{ maxWidth: 400 }}>
                <Headline style={style.HEADLINE}>
                  Wanna work with us? Get in touch
                </Headline>
                <Button
                  style={style.BUTTON.style}
                  caption1="Get Started"
                  caption1style={style.BUTTON.caption1}
                />
              </Container>
            </GridItem>

            <GridItem xs>
              <Container style={{ maxWidth: 800 }}>
                <Grid style={{}}>
                  <GridItem xs={4}>
                    <Container style={{ padding: "0 40px" }}>
                      <Text
                        style={{ ...style.TEXT, fontWeight: "bold" as "bold" }}
                      >
                        Information
                      </Text>
                      <Navigation
                        layout={NavigationLayouts.FIVE}
                        linkStyle={style.NAVIGATION.linkStyle}
                        items={[
                          {
                            caption: "About Us",
                            href: "./#",
                            type: ItemTypes.TEXT,
                          },
                          {
                            caption: "Contact Us",
                            href: "./#",
                            type: ItemTypes.TEXT,
                          },
                          {
                            caption: "FAQs",
                            href: "./#",
                            type: ItemTypes.TEXT,
                          },
                        ]}
                      />
                    </Container>
                  </GridItem>
                  <GridItem xs={4}>
                    <Container style={{ padding: "0 40px" }}>
                      <Text
                        style={{ ...style.TEXT, fontWeight: "bold" as "bold" }}
                      >
                        About
                      </Text>
                      <Navigation
                        layout={NavigationLayouts.FIVE}
                        linkStyle={style.NAVIGATION.linkStyle}
                        items={[
                          { caption: "About Us", href: "./#" },
                          { caption: "Contact Us", href: "./#" },
                          { caption: "FAQs", href: "./#" },
                        ]}
                      />
                    </Container>
                  </GridItem>
                  <GridItem xs={4}>
                    <Container style={{ padding: "0 40px" }}>
                      <Text
                        style={{ ...style.TEXT, fontWeight: "bold" as "bold" }}
                      >
                        Catalog
                      </Text>
                      <Navigation
                        layout={NavigationLayouts.FIVE}
                        linkStyle={style.NAVIGATION.linkStyle}
                        items={[
                          { caption: "About Us", href: "./#" },
                          { caption: "Contact Us", href: "./#" },
                          { caption: "FAQs", href: "./#" },
                        ]}
                      />
                    </Container>
                  </GridItem>
                </Grid>
              </Container>
            </GridItem>
          </Grid>
        </Container>
      </Section>
    </Block>
  );
};

export default Layout;
