import * as React from "react";
import { get } from "lodash";

import { style } from "./style";
import { default as defaultData } from "./data.json";

import { doIShow, combineData } from "../../utils";

import theme from "../../theme";

import {
  Block,
  Section,
  Headline,
  Text,
  Container,
  Button,
  FormBuilder,
} from "@sc/plugins/webcomponents/v2";
import { FormFieldTypes } from "@sc/modules/v2/CRUD/FormBuilder/types";

type LayoutProps = {
  data: any;
};

const Layout: React.FC<LayoutProps> = ({ data }) => {
  const initialContent = {
    main_headline: {
      html: "Headline Goes Here",
    },
    sub_headline: {
      html: "Sub Headline Text Content Goes Here",
    },
  };

  const content = combineData(initialContent, defaultData, data);

  return (
    <Block>
      <Section style={style.SECTION}>
        <Container
          style={{
            ...style.SECTION_INNER,
            // maxWidth: get(data, "section.pageMargin")
            maxWidth: 550,
          }}
        >
          <Headline style={style.HEADLINE}>Sign up</Headline>
          <FormBuilder
            style={{ marginTop: 30 }}
            data={[
              {
                type: FormFieldTypes.TEXT,
                name: "name",
                placeholder: "Name",
                style: style.FORM_FIELD.style,
                inputStyle: style.FORM_FIELD.inputStyle,
              },
              {
                type: FormFieldTypes.TEXT,
                name: "name",
                placeholder: "Email",
                style: style.FORM_FIELD.style,
                inputStyle: style.FORM_FIELD.inputStyle,
              },
              {
                type: FormFieldTypes.PASSWORD,
                name: "password",
                placeholder: "Password",
                style: style.FORM_FIELD.style,
                inputStyle: style.FORM_FIELD.inputStyle,
              },
              {
                type: FormFieldTypes.PASSWORD,
                name: "password_confirm",
                placeholder: "Repeat Password",
                style: style.FORM_FIELD.style,
                inputStyle: style.FORM_FIELD.inputStyle,
              },
              {
                type: FormFieldTypes.CHECKBOX,
                name: "terms",
                label: "I agree to the terms",
                placeholder: "Terms",
                style: style.FORM_FIELD.style,
                inputStyle: style.FORM_FIELD.inputStyle,
                labelStyle: style.FORM_FIELD.labelStyle,
              },
            ]}
          />

          <Button
            style={{ ...style.BUTTON.style, marginLeft: 10 }}
            caption1="Sign Up"
            caption1style={style.BUTTON.caption1}
          />
        </Container>
      </Section>
    </Block>
  );
};

export default Layout;
