import * as React from "react";
import { get, startCase, uniqueId } from "lodash";

import { style } from "./style";
import { default as defaultData } from "./data.json";

import { doIShow, combineData, lorem } from "../../utils";

import theme from "../../theme";

import {
  Block,
  Section,
  Headline,
  Text,
  Container,
  Button,
  FormBuilder,
  FormField,
  Grid,
  GridItem,
} from "@sc/plugins/webcomponents/v2";
import { FormFieldTypes } from "@sc/modules/v2/CRUD/FormBuilder/types";
type LayoutProps = {
  data: any;
};

const Layout: React.FC<LayoutProps> = ({ data }) => {
  const initialContent = {
    main_headline: {
      html: "Headline Goes Here",
    },
    sub_headline: {
      html: "Sub Headline Text Content Goes Here",
    },
  };

  const content = combineData(initialContent, defaultData, data);

  return (
    <Block>
      <Section style={style.SECTION}>
        <Container
          style={{
            ...style.SECTION_INNER,
            maxWidth: get(data, "section.pageMargin"),
          }}
        >
          <Headline style={style.HEADLINE}>
            {startCase(lorem.generateWords(5))}
          </Headline>

          <Grid spacing={2} style={{ marginTop: 20 }}>
            <GridItem xs={4}>
              <FormField
                type={FormFieldTypes.TEXT}
                inputStyle={style.FORM_FIELD.inputStyle}
                style={style.FORM_FIELD.style}
                labelStyle={style.FORM_FIELD.labelStyle}
                name="name"
                placeholder="Name"
              />
            </GridItem>
            <GridItem xs={4}>
              <FormField
                type={FormFieldTypes.TEXT}
                inputStyle={style.FORM_FIELD.inputStyle}
                style={style.FORM_FIELD.style}
                labelStyle={style.FORM_FIELD.labelStyle}
                name="email"
                placeholder="Email"
              />
            </GridItem>
            <GridItem xs={4}>
              <Button
                style={style.BUTTON.style}
                caption1={`Yes! ${startCase(lorem.generateWords(3))}`}
                caption1style={style.BUTTON.caption1}
              />
            </GridItem>
          </Grid>
        </Container>
      </Section>
    </Block>
  );
};

export default Layout;
