import * as React from "react";
import { get, startCase, uniqueId } from "lodash";

import { style } from "./style";
import { default as defaultData } from "./data.json";

import { doIShow, combineData, lorem } from "../../utils";

import theme from "../../theme";

import {
  Block,
  Section,
  Headline,
  Text,
  Container,
  Image,
  Grid,
  GridItem,
} from "@sc/plugins/webcomponents/v2";

type LayoutProps = {
  data: any;
};

const Layout: React.FC<LayoutProps> = ({ data }) => {
  const initialContent = {
    main_headline: {
      html: "Headline Goes Here",
    },
    sub_headline: {
      html: "Sub Headline Text Content Goes Here",
    },
  };

  const content = combineData(initialContent, defaultData, data);

  return (
    <Block>
      <Section style={style.SECTION}>
        <Container
          style={{
            ...style.SECTION_INNER,
            maxWidth: get(data, "section.pageMargin"),
          }}
        >
          <Grid>
            <GridItem xs={4}>
              <Container style={{ textAlign: "center" }}>
                <Image
                  style={{ maxWidth: 170, margin: "0 auto" }}
                  src="https://svgsilh.com/svg/1771694.svg"
                />
              </Container>
            </GridItem>
            <GridItem xs={8}>
              <Headline style={{ ...style.HEADLINE, marginTop: 10 }}>
                100% Money Back Guarantee
              </Headline>
              <Text style={{ ...style.TEXT }}>
                {lorem.generateSentences(3)}
              </Text>
            </GridItem>
          </Grid>
        </Container>
      </Section>
    </Block>
  );
};

export default Layout;
