import * as React from "react";
import { get } from "lodash";

import { style } from "./style";
import { default as defaultData } from "./data.json";

import { doIShow, combineData } from "../../utils";

import {
  Block,
  Section,
  Headline,
  Text,
  Container,
  Grid,
  GridItem,
  Button,
} from "@sc/plugins/webcomponents/v2";

import { VideoPlaceholder } from "../../Placeholders";

type LayoutProps = {
  data: any;
};

const Layout: React.FC<LayoutProps> = ({ data }) => {
  const initialContent = {
    main_headline: {
      html: "Headline Goes Here",
    },
    sub_headline: {
      html: "Sub Headline Text Content Goes Here",
    },
  };

  const content = combineData(initialContent, defaultData, data);

  return (
    <Block>
      <Section style={style.SECTION}>
        <Container
          style={{
            ...style.SECTION_INNER,
            maxWidth: get(data, "section.pageMargin"),
          }}
        >
          <Grid>
            <GridItem xs={12} md={5}>
              <Container style={{ paddingRight: 30 }}>
                {doIShow(content, "main_headline") && (
                  <Headline
                    name="Main Headline"
                    id="main_headline"
                    style={{
                      ...style.HEADLINE,
                      ...get(content, "main_headline.style", {}),
                      ...{ textAlign: "left" },
                    }}
                  >
                    {get(content, "main_headline.html", "...")}
                  </Headline>
                )}
                {doIShow(content, "sub_headline") && (
                  <Text
                    name="Sub Headline"
                    id="sub_headline"
                    style={{
                      ...style.TEXT,
                      ...get(content, "sub_headline.style", {}),
                      ...{ textAlign: "left" },
                    }}
                  >
                    {get(content, "sub_headline.html", "...")}
                  </Text>
                )}
                {doIShow(content, "cta_button") && (
                  <Button
                    style={style.BUTTON.style}
                    caption1="Get Started"
                    caption1style={style.BUTTON.caption1}
                  />
                )}
              </Container>
            </GridItem>
            <GridItem xs={12} md={7}>
              {doIShow(content, "hero_video") && <VideoPlaceholder />}
            </GridItem>
          </Grid>
        </Container>
      </Section>
    </Block>
  );
};

export default Layout;
