import * as React from "react";
import { get } from "lodash";

import { style } from "./style";
import { default as defaultData } from "./data.json";

import { doIShow, combineData } from "../../utils";
import theme from "../../theme";

import {
  Block,
  Section,
  Headline,
  Text,
  Container,
  Button,
  Grid,
  GridItem,
  FormField,
} from "@sc/plugins/webcomponents/v2";

type LayoutProps = {
  data: any;
};

const Layout: React.FC<LayoutProps> = ({ data }) => {
  const initialContent = {
    main_headline: {
      html: "Headline Goes Here",
    },
    sub_headline: {
      html: "Sub Headline Text Content Goes Here",
    },
  };

  const content = combineData(initialContent, defaultData, data);

  return (
    <Block>
      <Section style={style.SECTION}>
        <Grid>
          <GridItem xs={6}>
            <Container
              style={{ padding: 110, backgroundColor: theme.backgroundColor }}
            >
              {doIShow(content, "main_headline") && (
                <Headline
                  name="Main Headline"
                  id="main_headline"
                  style={{
                    ...style.HEADLINE,
                    ...get(content, "main_headline.style", {}),
                  }}
                >
                  {get(content, "main_headline.html", "...")}
                </Headline>
              )}
              {doIShow(content, "sub_headline") && (
                <Text
                  name="Sub Headline"
                  id="sub_headline"
                  style={{
                    ...style.TEXT,
                    ...get(content, "sub_headline.style", {}),
                  }}
                >
                  {get(content, "sub_headline.html", "...")}
                </Text>
              )}
              <Grid spacing={4} style={{ marginTop: 40 }}>
                <GridItem xs={8}>
                  {doIShow(content, "input") && (
                    <FormField
                      type="Text"
                      name="email"
                      placeholder="Enter Your Email"
                      style={style.FORM_FIELD.style}
                      inputStyle={style.FORM_FIELD.inputStyle}
                    />
                  )}
                </GridItem>
                <GridItem xs={4}>
                  {doIShow(content, "cta_button") && (
                    <Button
                      style={style.BUTTON.style}
                      caption1="Get Started"
                      caption1style={style.BUTTON.caption1}
                    />
                  )}
                </GridItem>
              </Grid>
            </Container>
          </GridItem>
          <GridItem xs={6}></GridItem>
        </Grid>
      </Section>
    </Block>
  );
};

export default Layout;
