import * as React from "react";
import { get } from "lodash";
import Icon from "@material-ui/core/Icon";

import { style } from "./style";
import { default as defaultData } from "./data.json";

import { doIShow, combineData } from "../../utils";

import {
  Block,
  Section,
  Headline,
  Text,
  Container,
  Button,
  Grid,
  GridItem,
} from "@sc/plugins/webcomponents/v2";

import { VideoPlaceholder, VideoPlaceholderTypes } from "../../Placeholders";
import theme from "../../theme";

type LayoutProps = {
  data: any;
};

const Layout: React.FC<LayoutProps> = ({ data }) => {
  const initialContent = {
    main_headline: {
      html: "Headline Goes Here",
    },
    sub_headline: {
      html: "Sub Headline Text Content Goes Here",
    },
  };

  const content = combineData(initialContent, defaultData, data);

  return (
    <Block>
      <Section style={style.SECTION}>
        <Container
          style={{
            ...style.SECTION_INNER,
            maxWidth: get(data, "section.pageMargin"),
          }}
        >
          <Container
            style={{
              maxWidth: 700,
              margin: "0 auto",
              textAlign: "center",
              padding: 50,
            }}
          >
            {doIShow(content, "main_headline") && (
              <Headline
                name="Main Headline"
                id="main_headline"
                style={{
                  ...style.HEADLINE,
                  ...get(content, "main_headline.style", {}),
                }}
              >
                {get(content, "main_headline.html", "...")}
              </Headline>
            )}
            {doIShow(content, "sub_headline") && (
              <Headline
                name="Sub Headline"
                id="sub_headline"
                style={{
                  ...style.SUB_HEADLINE,
                  ...get(content, "sub_headline.style", {}),
                }}
              >
                {get(content, "sub_headline.html", "...")}
              </Headline>
            )}
            {doIShow(content, "hero_video") && (
              <VideoPlaceholder
                style={style.VIDEO}
                type={VideoPlaceholderTypes.POPUP}
              />
            )}
            {doIShow(content, "cta_button") && (
              <Button
                style={style.BUTTON.style}
                caption1="Get Started"
                caption1style={style.BUTTON.caption1}
              />
            )}
          </Container>
        </Container>
      </Section>
    </Block>
  );
};

export default Layout;
