import * as React from "react";
import { get } from "lodash";

import { style } from "./style";
import { default as defaultData } from "./data.json";

import { doIShow, combineData } from "../../utils";

import theme from "../../theme";

import {
  Block,
  Section,
  Headline,
  Text,
  Container,
  Button,
  Navigation,
} from "@sc/plugins/webcomponents/v2";
import {
  NavigationLayouts,
  ItemTypes,
} from "@sc/plugins/webcomponents/v2/xNavigation/types";
import { themeSettings, folder } from "@sc/plugins/webcomponents/v2/theme";
import { IconTypes } from "@sc/plugins/webcomponents/v2/Icon";

type LayoutProps = {
  data: any;
};

const Layout: React.FC<LayoutProps> = ({ data }) => {
  const initialContent = {
    main_headline: {
      html: "Headline Goes Here",
    },
    sub_headline: {
      html: "Sub Headline Text Content Goes Here",
    },
  };

  const content = combineData(initialContent, defaultData, data);

  return (
    <Block>
      <Section style={style.SECTION}>
        <Container
          style={{
            ...style.SECTION_INNER,
            maxWidth: get(data, "section.pageMargin"),
          }}
        >
          <Navigation
            layout={NavigationLayouts.TWO}
            logo={theme.logoIcon}
            logoStyle={{ maxWidth: 55, padding: "0 40px" }}
            logoHref={`/${folder}`}
            items={[
              {
                caption: "About",
                href: "./about",
                type: ItemTypes.TEXT,
                column: 2,
              },
              {
                caption: "Features",
                href: "./features",
                type: ItemTypes.TEXT,
                column: 2,
              },
              {
                caption: "Blog",
                href: "./blog",
                type: ItemTypes.TEXT,
                column: 2,
              },
              {
                caption: "Team",
                href: "./team",
                type: ItemTypes.TEXT,
                column: 2,
              },
              {
                caption: "Account",
                href: "./account",
                type: ItemTypes.LISTITEM,
                column: 3,
                style: { padding: 10 },
                icon: IconTypes.Person,
                iconStyle: {
                  borderRadius: "50%",
                  backgroundColor: theme.backgroundColor,
                  padding: "5px 8px",
                  fontSize: "18pt",
                  color: theme.foregroundColor,
                },
                contentStyle: {
                  padding: 15,
                  position: "relative",
                  top: -5,
                  display: "inline-block",
                },
              },
              // {
              //   caption: "Button",
              //   href: "./",
              //   type: ItemTypes.BUTTON,
              //   buttonSettings: { ...style.BUTTON },
              //   column: 3
              // }
            ]}
            linkStyle={{
              color: "black",
              listStyle: "none",
              display: "inline-block",
              padding: 20,
              fontFamily: "Roboto",
            }}
            style={{ padding: 20 }}
          />
        </Container>
      </Section>
    </Block>
  );
};

export default Layout;
