import * as React from "react";
import { get } from "lodash";

import { style } from "./style";
import { default as defaultData } from "./data.json";

import { doIShow, combineData } from "../../utils";

import theme from "../../theme";

import {
  Block,
  Section,
  Headline,
  Text,
  Container,
  Button,
  Navigation,
} from "@sc/plugins/webcomponents/v2";
import {
  NavigationLayouts,
  ItemTypes,
} from "@sc/plugins/webcomponents/v2/xNavigation/types";
import { themeSettings, folder } from "@sc/plugins/webcomponents/v2/theme";
import { IconTypes } from "@sc/plugins/webcomponents/v2/Icon";

type LayoutProps = {
  data: any;
};

const Layout: React.FC<LayoutProps> = ({ data }) => {
  const initialContent = {
    main_headline: {
      html: "Headline Goes Here",
    },
    sub_headline: {
      html: "Sub Headline Text Content Goes Here",
    },
  };

  const content = combineData(initialContent, defaultData, data);

  return (
    <Block>
      <Section style={style.SECTION}>
        <Container
          style={{
            ...style.SECTION_INNER,
            maxWidth: get(data, "section.pageMargin"),
          }}
        >
          <Navigation
            layout={NavigationLayouts.THREE}
            logo={theme.logoIcon}
            logoStyle={{ maxWidth: 55, padding: "0 40px" }}
            logoHref={`/${folder}`}
            items={[
              {
                caption: "About",
                href: "./about",
                type: ItemTypes.TEXT,
              },
              {
                caption: "Features",
                href: "./features",
                type: ItemTypes.TEXT,
              },
              {
                caption: "Blog",
                href: "./blog",
                type: ItemTypes.TEXT,
              },
              { caption: "Team", href: "./team", type: ItemTypes.TEXT },
              {
                caption: "Button",
                href: "./",
                type: ItemTypes.BUTTON,
                buttonSettings: { ...style.BUTTON },
              },
            ]}
            linkStyle={{
              color: "black",
              listStyle: "none",
              display: "inline-block",
              padding: 20,
              fontFamily: "Roboto",
            }}
            hamburgerIconStyle={{ padding: 20 }}
            style={{ padding: 20 }}
          />
        </Container>
      </Section>
    </Block>
  );
};

export default Layout;
