import * as React from "react";
import { get } from "lodash";

import { style } from "./style";
import { default as defaultData } from "./data.json";

import { doIShow, combineData } from "../../utils";

import theme from "../../theme";

import {
  Block,
  Section,
  Headline,
  Text,
  Container,
  Image,
  Grid,
  GridItem,
} from "@sc/plugins/webcomponents/v2";
import { ImagePlaceholder, ImagePlaceholderTypes } from "../../Placeholders";

type LayoutProps = {
  data: any;
};

const Layout: React.FC<LayoutProps> = ({ data }) => {
  const initialContent = {
    main_headline: {
      html: "Headline Goes Here",
    },
    sub_headline: {
      html: "Sub Headline Text Content Goes Here",
    },
  };

  const content = combineData(initialContent, defaultData, data);

  return (
    <Block>
      <Section style={style.SECTION}>
        <Container
          style={{
            ...style.SECTION_INNER,
            maxWidth: get(data, "section.pageMargin"),
          }}
        >
          <Grid spacing={10}>
            <GridItem xs={6}>
              <ImagePlaceholder
                type={ImagePlaceholderTypes.NONE}
                style={{
                  height: "100%",
                  margin: 30,
                  backgroundColor: theme.backgroundColor,
                }}
              />
            </GridItem>
            <GridItem xs={6}>
              <Container style={{ padding: 30 }}>
                <Headline style={style.HEADLINE}>
                  "Hands down the best process I've seen in the last 11 years.
                  Thank you!! I really value"
                </Headline>
                <Text style={style.TEXT}>Jacob McDonald</Text>
              </Container>
            </GridItem>
          </Grid>

          <Grid
            spacing={8}
            style={{
              display: "flex",
              justifyContent: "center",
              marginTop: 40,
              // padding: simple ? "10px 0 0 0" : 30
            }}
          >
            <GridItem>
              <Image src="logos/forbes.png" />
            </GridItem>
            {/* <GridItem>
              <Image src="logos/los_angeles_times.png" />
            </GridItem> */}
            <GridItem>
              <Image src="logos/entrepreneur.png" />
            </GridItem>
            {/* <GridItem><Image src="logos/huffington_post.png" /></GridItem> */}
            <GridItem>
              <Image src="logos/usa_today.png" />
            </GridItem>
            <GridItem>
              <Image src="logos/inc.png" />
            </GridItem>
          </Grid>
        </Container>
      </Section>
    </Block>
  );
};

export default Layout;
