import * as React from "react";
import { get, startCase, uniqueId } from "lodash";

import { style } from "./style";
import { default as defaultData } from "./data.json";

import { doIShow, combineData, lorem } from "../../utils";
import { VideoPlaceholder } from "../../Placeholders";

import theme from "../../theme";

import {
  Block,
  Section,
  Headline,
  Text,
  Container,
  Grid,
  GridItem,
} from "@sc/plugins/webcomponents/v2";

type LayoutProps = {
  data: any;
};

const Layout: React.FC<LayoutProps> = ({ data }) => {
  const initialContent = {
    main_headline: {
      html: "Headline Goes Here",
    },
    sub_headline: {
      html: "Sub Headline Text Content Goes Here",
    },
  };

  const content = combineData(initialContent, defaultData, data);

  return (
    <Block>
      <Section style={style.SECTION}>
        <Container
          style={{
            ...style.SECTION_INNER,
            maxWidth: get(data, "section.pageMargin"),
          }}
        >
          <Headline style={style.HEADLINE}>
            Here's what people are saying:
          </Headline>
          <Grid spacing={2} style={{ marginTop: 40 }}>
            <GridItem xs={4}>
              <VideoPlaceholder
                style={{ color: "white", padding: 100 }}
                playIconStyle={{ fontSize: "56pt" }}
              />
              <Text style={style.TEXT}>{lorem.generateSentences(1)}</Text>
            </GridItem>
            <GridItem xs={4}>
              <VideoPlaceholder
                style={{ color: "white", padding: 100 }}
                playIconStyle={{ fontSize: "56pt" }}
              />
              <Text style={style.TEXT}>{lorem.generateSentences(1)}</Text>
            </GridItem>
            <GridItem xs={4}>
              <VideoPlaceholder
                style={{ color: "white", padding: 100 }}
                playIconStyle={{ fontSize: "56pt" }}
              />
              <Text style={style.TEXT}>{lorem.generateSentences(1)}</Text>
            </GridItem>
          </Grid>
        </Container>
      </Section>
    </Block>
  );
};

export default Layout;
