import _ from "lodash";
import SelectPagePopup from "./SelectPagePopup";
import { client } from "@sc/api/gql";
import { getCampaignObject } from "@sc/api/gql/campaigns";

export const onListItems = (hook, payload, actions) => {
  if (hook.id === "DestinationObjects" && hook.activeTab === "Common") {
    return [
      {
        type: "AnotherFunnelComponent",
        name: "Another Funnel",
        screenshot: `http://10minutefunnels.com/access/assets/images/icons/pages/AC_anotherfunnel.png`,
        width: 150,
        height: 100
      }
    ];
  }
};

export const onNodeCreate = async (hook, { item }, { createPage }) => {
  if (hook.type === "AnotherFunnelComponent") {
    const { name, screenshot } = item;

    const pageScript = `
      <script type="text/javascript">
        window.location.href = "#";
      </script>
    `;

    const response = await createPage({
      name,
      slug: Math.random()
        .toString(36)
        .replace(/[^a-z]+/g, "")
        .substr(0, 6),
      screenshot,
      theme: "none",
      type: "redirect",
      content: [
        {
          id: 2540,
          parent: false,
          properties: { height: "100%" },
          type: "Body",
          canHaveChildren: true
        }
      ],
      userId: localStorage.userId,
      pageSettings: {
        tracking: {
          head: pageScript
        }
      }
    });

    console.log({ response });

    return response;
  }
};

export const onNodePublish = async (hook, { item }, { updatePageSettings }) => {
  if (hook.type === "AnotherFunnelComponent") {
    // console.log({ item });

    // lookup slug for page id in settings,
    const { data } = await client.query({
      query: getCampaignObject,
      variables: {
        id: _.get(item, "settings.objectId")
      }
    });

    console.log({ data });

    const pageScript = `
      <script type="text/javascript">
        window.location.href = "/${_.get(data, "object.page.slug")}";
      </script>
    `;

    await updatePageSettings({
      pageId: _.get(item, "page.id"),
      pageSettings: {
        tracking: {
          head: pageScript
        }
      }
    });
  }
};

export const onNodeOpen = async (
  hook,
  { settings },
  { showPopup, updateObject, updatePageSettings, updateObjectSettings }
) => {
  if (hook.type === "AnotherFunnelComponent") {
    showPopup(SelectPagePopup, settings, {
      updateObject,
      updatePageSettings,
      updateObjectSettings
    });
  }
};
