import _ from "lodash";
import { client } from "@sc/api/gql";
import { getCampaignObject } from "@sc/api/gql/campaigns";
import CampaignSelector from "./CampaignSelector";
import OpenDestinationPageInEditorPopup from "./OpenDestinationPageInEditorPopup";

export const onListItems = (hook, payload, actions) => {
  if (hook.id === "PagesDrawerTabs") {
    return ["Existing Pages"];
  }
};

export const onComponentRender = (hook, payload, actions) => {
  if (hook.id === "PagesDrawer" && hook.activeTab === "Existing Pages") {
    return [CampaignSelector];
  }
};

export const onNodeCreate = async (
  hook,
  { item },
  { createPage, updateObjectSettings }
) => {
  if (hook.type === "PageShortcutComponent") {
    const { name, screenshot, id } = item;

    // id is the object id of the destination object (not existing obj)

    console.log({ item });

    // const url = `<%=page[${id}]%>`;

    const pageScript = `
      <script type="text/javascript">
        window.location.href = "#";
      </script>
    `;

    const response = await createPage({
      name,
      slug: Math.random()
        .toString(36)
        .replace(/[^a-z]+/g, "")
        .substr(0, 6),
      screenshot,
      theme: "none",
      type: "redirect",
      content: [
        {
          id: 2540,
          parent: false,
          properties: { height: "100%" },
          type: "Body",
          canHaveChildren: true
        }
      ],
      userId: localStorage.userId,
      pageSettings: {
        tracking: {
          head: pageScript
        }
      }
    });

    updateObjectSettings({
      objectId: id
    });

    return response;
  }
};

export const onNodePublish = async (hook, { item }, { updatePageSettings }) => {
  if (hook.type === "PageShortcutComponent") {
    console.log({ item });
    // get destination object id
    const { objectId } = item.settings;

    // get page Slug
    const { data } = await client.query({
      query: getCampaignObject,
      variables: {
        id: objectId
      }
    });

    const pageScript = `
      <script type="text/javascript">
        window.location.href = "/${_.get(data, "object.page.slug")}";
      </script>
    `;

    await updatePageSettings({
      pageId: _.get(item, "page.id"),
      pageSettings: {
        tracking: {
          head: pageScript
        }
      }
    });
  }
};

export const onNodeOpen = (hook, { settings }, { showPopup }) => {
  if (hook.type === "PageShortcutComponent") {
    showPopup(OpenDestinationPageInEditorPopup, settings);
  }
};
