import slugify from "slugify";
import ABSplitNode from './ABSplitNode'
import Properties from './Properties'

export const onNodeOpen = (hook, { showPopup }) => {
  if (hook.type === "ABSplit") {
    showPopup(Properties)
  }
}

export const onNodeCreate = async (hook, { createPage, item }) => {
  if (hook.type === "ABSplit") {

    const { name, screenshot, pageType } = item;
    const slug = slugify(name.toString().toLowerCase());

    const pageSettings = {
      tracking: {
        head: `
          <script type="text/javascript">
            window.location.href = "<%=nextPage%>";
          </script>
        `
      }
    };
    
    const variables = {
      name,
      slug: `${slug}-${Math.random()
        .toString(36)
        .substr(2, 2)}`,
      screenshot,
      theme: "all",
      type: pageType,
      content: [],
      userId: localStorage.userId,
      pageSettings,
    };

    const newPage = await createPage(variables);

    return newPage;
  }
}

export const onListItems = (hook, { items, item }) => {

  switch (hook.type) {
    case "ABSplitMenu":
      return [
        {
          id: "edit",
          name: "A/B Settings"
        },
        ...items,
      ];
    
    case "ItemDrawer":
      return [
        ...items,
        {
          type: "ABSplit",
          id: "traffic_source_facebook",
          name: "Split Test",
          screenshot: `http://10minutefunnels.com/access/assets/images/icons/pages/AC_splittesting.png`,
          width: 150,
          height: 100
        }
      ]
    
    case "CanvasObjects":
      return [
        ...items,
        {
          ...item,
          component: ABSplitNode,
        },
      ]
    
    default:
      break;
  }
}

export const onNodeTrigger = async (hook, { item, mode, triggerNextNode, triggerNode, updateActionQueue, getCampaign, getObject, getPreviousNodes, getNextNodes }) => {
  // i was triggered
  if (hook.type === "ABSplit") {
    // perform some update to the component if in editing mode
    if (mode === "edit") { }
    // perform some background function if in live mode
    else if (mode === "live") { }
    // trigger next node(s)
    triggerNextNode(item);
  }
}