import _ from "lodash";
import { client } from "@sc/api/gql";
import { getCampaignObject } from "@sc/api/gql/campaigns";

export const onListItems = (hook, payload, actions) => {
  if (hook.id === "FunnelActionObjects") {
    return [
      {
        type: "ABSplitComponent",
        name: "AB Split Testing",
        screenshot: `http://10minutefunnels.com/access/assets/images/icons/pages/AC_splittesting.png`,
        width: 150,
        height: 100
      }
    ];
  }
};

export const onNodeCreate = async (hook, { item }, { createPage }) => {
  if (hook.type === "ABSplitComponent") {
    const { name, screenshot } = item;

    const pageScript = `
      <script type="text/javascript">
        window.location.href = "<%=nextPage%>";
      </script>
    `;

    const response = await createPage({
      name,
      slug: Math.random()
        .toString(36)
        .replace(/[^a-z]+/g, "")
        .substr(0, 6),
      screenshot,
      theme: "none",
      type: "splitTestRedirect",
      content: [
        {
          id: 2540,
          parent: false,
          properties: { height: "100%" },
          type: "Body",
          canHaveChildren: true
        }
      ],
      userId: localStorage.userId,
      pageSettings: {
        tracking: {
          head: pageScript
        }
      }
    });

    console.log({ response });

    return response;
  }
};

export const onNodePublish = async (hook, { item }, { updatePageSettings }) => {
  if (hook.type === "ABSplitComponent") {
    // 1. get connected objects
    const { connectTo } = item;

    let pages = [];

    for (let i = 0; i < connectTo.length; i++) {
      const itm = connectTo[i];

      const { data } = await client.query({
        query: getCampaignObject,
        variables: {
          id: itm.id
        }
      });

      const slug = _.get(data, "object.page.slug");
      if (slug) pages.push(slug);
    }

    // 4. generate script to randomize window.location.href
    const pageScript = `
      <script type="text/javascript">
        const pages = ["${pages.join('","')}"];
        const min = 0; const max = pages.length;
        const winner = Math.floor(Math.random() * (max - min + 1)) + min;
        const visit = pages[winner];
        window.location.href = "/" + visit;
      </script>
    `;

    // 5. update the page settings
    await updatePageSettings({
      pageId: _.get(item, "page.id"),
      pageSettings: {
        tracking: {
          head: pageScript
        }
      }
    });
  }
};
