import { doUpsell, getInputVals, sendData } from "@sc/site/src/scripts";
import _ from "lodash";

const showButtonLoader = action => {
  if (_.has(action, 'updateComponentSettings')) {
    action.updateComponentSettings(action.settings.id, {
      ...action.settings,
      html: "Processing...",
      disabled: true,
      oldHtml: action.settings.html
    });
  }
};

const hideButtonLoader = action => {
  if (_.has(action, 'getComponentSettings')) {
    const oldSettings = action.getComponentSettings(action.settings.id);
    action.updateComponentSettings(action.settings.id, {
      ...action.settings,
      disabled: false,
      html: _.get(oldSettings, "oldHtml", "Continue...")
    });
  }
};

const showItem = (showId, getComponentSettings, updateComponentSettings, callback = () => null) => {

  const showIdSettings = getComponentSettings(showId);

  if (showId) {
    updateComponentSettings(showId, {
      ...showIdSettings,
      properties: {
        ..._.get(showIdSettings, "properties", false),
        display: _.get(showIdSettings, "properties.oldDisplay", "block"),
        // display: "block"
        mobile: {
          ..._.get(showIdSettings, "properties.mobile", false),
          fullscreen: {
            ..._.get(showIdSettings, "properties.mobile.fullscreen", false),
            display: _.get(showIdSettings, "properties.oldDisplay", "block")
          },
          desktop: {
            ..._.get(showIdSettings, "properties.mobile.desktop", false),
            display: _.get(showIdSettings, "properties.oldDisplay", "block")
          },
          tablet: {
            ..._.get(showIdSettings, "properties.mobile.tablet", false),
            display: _.get(showIdSettings, "properties.oldDisplay", "block")
          },
          smartphone: {
            ..._.get(showIdSettings, "properties.mobile.smartphone", false),
            display: _.get(showIdSettings, "properties.oldDisplay", "block")
          }
        }
      }
    }, callback);
  } else callback()

}

const hideItem = (hideId, getComponentSettings, updateComponentSettings, callback = () => null) => {

  if (getComponentSettings && updateComponentSettings) {
    const hideIdSettings = getComponentSettings(hideId);

    if (hideId) {
      updateComponentSettings(
        hideId,
        {
          ...hideIdSettings,
          properties: {
            ..._.get(hideIdSettings, "properties", false),
            display: "none",
            mobile: {
              ..._.get(hideIdSettings, "properties.mobile", false),
              fullscreen: {
                ..._.get(hideIdSettings, "properties.mobile.fullscreen", false),
                display: "none"
              },
              desktop: {
                ..._.get(hideIdSettings, "properties.mobile.desktop", false),
                display: "none"
              },
              tablet: {
                ..._.get(hideIdSettings, "properties.mobile.tablet", false),
                display: "none"
              },
              smartphone: {
                ..._.get(hideIdSettings, "properties.mobile.smartphone", false),
                display: "none"
              }
            }
          }
        },
        callback
      )
    } else callback()
  }
}

export default {
  triggerNextPage: action => {
    const url = _.get(_.head(document.getElementsByName("nxP")), "value");
    console.log({ url });
    window.location.href = url ? `/${url}` : "#";
  },
  submitForm: action => {
    const inputVals = getInputVals();
    const inputValsJson = JSON.stringify(inputVals);

    showButtonLoader(action);

    // send the form contents to the selected crm integration
    sendData(inputValsJson, (res = true) => {
      if (res) {
        let url = _.get(action, "payload.url", action.settings.href);
        if (action.payload.useTag) url = localStorage.getItem(url);
        window.location.href = url;
      }
    });
  },
  triggerUpsell: action => {
    const url = action.settings.href;
    if (localStorage.hasOwnProperty("orderResponse")) {
      const orderResponse = JSON.parse(localStorage.orderResponse);
      const sendableOrderResponse = _.toPairs(orderResponse).map((i, k) => ({
        name: i[0],
        value: i[1]
      }));

      const inputVals = [...sendableOrderResponse, ...getInputVals()];
      const inputValsJson = JSON.stringify(inputVals);

      showButtonLoader(action);

      doUpsell(inputValsJson, (res = true) => {
        if (res) {
          window.location.href = url;
        } else {
          hideButtonLoader(action);
        }
      });
    } else {
      hideButtonLoader(action);
      alert("Sorry, we are unable to locate your previous order!");
    }
  },
  triggerPurchase: action => {
    const inputVals = [
      ...getInputVals(),
      {
        name: "purchaseType",
        value: _.get(action, "payload.purchaseType", "default")
      },
      { name: "shoppingCartItems", value: _.get(localStorage, "cart", "[]") }
    ];

    showButtonLoader(action);

    const inputValsJson = JSON.stringify(inputVals);
    const toCheck = inputVals.filter(
      itm => itm.name !== "emP" && itm.name !== "pmP" && itm.name !== "nxP"
    );

    if (toCheck.length) {
      // send the form contents to the selected crm integration
      sendData(inputValsJson, (res = true) => {
        if (res) {
          window.location.href = action.settings.href;
        } else {
          hideButtonLoader(action);
        }
      });
    } else {
      window.location.href = action.settings.href;
    }
  },
  goToUrl: action => {
    let url = _.get(action, "payload.url", action.settings.href);
    if (action.payload.useTag) url = localStorage.getItem(url);

    window.location.href = url;
  },
  downloadFile: action => {
    let url = _.get(action, "payload.url", false);
    if (url) {
      // alert(`Download File Now! ${url} ||| ${JSON.stringify(action)}`)
      const anchor = document.createElement('a');
      anchor.href = url;
      anchor.target = '_blank';
      anchor.download = url;
      anchor.click();
    }
  },
  showAndHide: action => {
    const { payload, updateComponentSettings, getComponentSettings } = action;
    const { hideId, showId } = payload;

    hideItem(hideId, getComponentSettings, updateComponentSettings, () => {
      showItem(showId, getComponentSettings, updateComponentSettings)
    })
  },
  openPopup: action => {
    // console.log({ action })
    const { payload, updateComponentSettings = () => null, getComponentSettings = () => null } = action;
    const { showId } = payload;
    if (showId) {
      const showIdSettings = getComponentSettings(showId);

      console.log({ action, showIdSettings, showId });
      updateComponentSettings(showId, {
        ...showIdSettings,
        properties: {
          ..._.get(showIdSettings, "properties", false),
          display: _.get(showIdSettings, "properties.oldDisplay", "block"),
          mobile: {
            ..._.get(showIdSettings, "properties.mobile", false),
            fullscreen: {
              ..._.get(showIdSettings, "properties.mobile.fullscreen", false),
              display: _.get(showIdSettings, "properties.oldDisplay", "block")
            },
            desktop: {
              ..._.get(showIdSettings, "properties.mobile.desktop", false),
              display: _.get(showIdSettings, "properties.oldDisplay", "block")
            },
            tablet: {
              ..._.get(showIdSettings, "properties.mobile.tablet", false),
              display: _.get(showIdSettings, "properties.oldDisplay", "block")
            },
            smartphone: {
              ..._.get(showIdSettings, "properties.mobile.smartphone", false),
              display: _.get(showIdSettings, "properties.oldDisplay", "block")
            }
          }
        }
      });
    }
  },
  hidePopup: action => {
    const { payload, updateComponentSettings, getComponentSettings } = action;
    const { hideId } = payload;
    const hideIdSettings = getComponentSettings(hideId);

    console.log({ action, hideIdSettings, hideId });

    updateComponentSettings(hideId, {
      ...hideIdSettings,
      properties: {
        ..._.get(hideIdSettings, "properties", false),
        display: "none",
        mobile: {
          ..._.get(hideIdSettings, "properties.mobile", false),
          fullscreen: {
            ..._.get(hideIdSettings, "properties.mobile.fullscreen", false),
            display: "none"
          },
          desktop: {
            ..._.get(hideIdSettings, "properties.mobile.desktop", false),
            display: "none"
          },
          tablet: {
            ..._.get(hideIdSettings, "properties.mobile.tablet", false),
            display: "none"
          },
          smartphone: {
            ..._.get(hideIdSettings, "properties.mobile.smartphone", false),
            display: "none"
          }
        }
      }
    });
  },
  createTag: action => {
    const { payload } = action;
    const { tagName, tagValue } = payload;
    localStorage.setItem(tagName, tagValue);
  }
};
